    <?php $__env->startSection('title', 'Home'); ?>
    
    <?php $__env->startSection('content'); ?>
        <?php echo $__env->make('Frontend.landingpage.hero-section', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>
         <?php echo $__env->make('Frontend.landingpage.biayakuliah-section', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>
        <?php echo $__env->make('Frontend.landingpage.sambutan-section', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>
        <?php echo $__env->make('Frontend.landingpage.gallery-section', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>
        <?php echo $__env->make('Frontend.landingpage.berita-section', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>
    <?php $__env->stopSection(); ?>

<?php echo $__env->make('Frontend.Layouts.app', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH /home/u768956174/domains/stisipimambonjol.info/STISIP-IMAM-BONJOL/resources/views/Frontend/home.blade.php ENDPATH**/ ?>