<?php $__env->startSection('title', 'Brosur'); ?>



<?php $__env->startSection('content'); ?>
    <?php if (isset($component)) { $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\HeaderSectionPage::class, ['title' => 'Brosur STISIP IMAM BONJOL','breadcrumbHome' => 'Home','breadcrumbCurrent' => 'Brosur']); ?>
<?php $component->withName('header-section-page'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df)): ?>
<?php $component = $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df; ?>
<?php unset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df); ?>
<?php endif; ?>

    <div class="py-16">
        <div class="container mx-auto px-4 lg:px-16">
            <!-- Heading -->
            <div class="text-center mb-12">
                <p class="text-gray-600 font-dmsans text-lg">
                Unduh brosur STISIP IMAM BONJOL untuk menjelajahi program studi, fasilitas, dan layanan terbaik yang siap mendukung perjalanan akademik Anda
                </p>
            </div>

            <!-- Brosur Gallery -->
            <div class="flex flex-wrap justify-center gap-8">
                <!-- Brosur Item 1 -->
                <div class="bg-white shadow-lg rounded-lg overflow-hidden flex flex-col items-center">
                    <img src="<?php echo e(asset('images/brosur/brosur1.png')); ?>" alt="Brosur STISIP IMAM BONJOL" class="w-full h-64 object-cover">
                    <div class="p-6 text-center">
                        <h3 class="text-lg font-poppins font-bold text-primary mb-2">Brosur STISIP IMAM BONJOL 2025</h3>
                        <p class="text-sm text-gray-600 mb-4">Format JPG</p>
                        <a href="<?php echo e(asset('images/brosur/brosur1.png')); ?>" download
                        style="color:#fff"
                            class="bg-primary  py-2 px-4 rounded-md hover:bg-accent transition">
                            <i class="fas fa-download mr-2"></i>Download
                        </a>
                    </div>
                </div>

                <!-- Brosur Item 2 -->
                <div class="bg-white shadow-lg rounded-lg overflow-hidden flex flex-col items-center">
                    <img src="<?php echo e(asset('images/brosur/brosur2.png')); ?>" alt="Brosur STISIP IMAM BONJOL" class="w-full h-64 object-cover">
                    <div class="p-6 text-center">
                        <h3 class="text-lg font-poppins font-bold text-primary mb-2">Brosur STISIP IMAM BONJOL 2025</h3>
                        <p class="text-sm text-gray-600 mb-4">Format JPG</p>
                        <a href="<?php echo e(asset('images/brosur/brosur2.png')); ?>" download
                        style="color:#fff"
                            class="bg-primary  py-2 px-4 rounded-md hover:bg-accent transition">
                            <i class="fas fa-download mr-2"></i>Download
                        </a>
                    </div>
                </div>
            </div>

            <!-- Bagian Unduh Semua -->
            <div class="flex justify-center mt-12">
                <button onclick="downloadAllBrosur()" style="color:#fff"
                    class="bg-accent  py-3 px-6 rounded-md font-poppins font-bold hover:bg-accent transition">
                    <i class="fas fa-download mr-2"></i>Unduh Semua Brosur
                </button>
            </div>
        </div>
    </div>

    <script>
        function downloadAllBrosur() {
            const urls = [
                '<?php echo e(asset('images/brosur/brosur1.png')); ?>',
                '<?php echo e(asset('images/brosur/brosur2.png')); ?>'
            ];

            urls.forEach(url => {
                const link = document.createElement('a');
                link.href = url;
                link.setAttribute('download', '');
                document.body.appendChild(link);
                link.click();
                document.body.removeChild(link);
            });
        }
    </script>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('Frontend.Layouts.app2', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH /home/u768956174/domains/stisipimambonjol.info/STISIP-IMAM-BONJOL/resources/views/Frontend/brosur.blade.php ENDPATH**/ ?>