<div class="md:h-[827px] h-auto flex flex-col items-center md:flex-row justify-center md:gap-x-[100px] py-[100px] md:py-[100px] px-4 md:px-0 bg-cover bg-no-repeat bg-right md:bg-center"
    style="background-image: url('<?php echo e(asset('./images/background/bg-sambutan.png')); ?>');">
    <div class="flex justify-center md:justify-start w-full md:w-auto flex-col items-center">
    <img src="<?php echo e(asset('./images/sambutan/sambutan.png')); ?>" data-aos="fade-up"
        class="h-auto md:w-[1000px] w-[300px] md:h-[500px] max-w-[450px]" style="border-radius:25px;" alt="STISIP IMAM BONJOL">
    <p style="padding-top: 20px; font-size: 14px; color: #fff; text-align: center; font-family: 'Poppins', sans-serif;">
        <!-- <b>Dendi Afrizal, S.AB., M.Ak, </b> -->
    </p>
</div>
    <div class="flex flex-col md:items-start justify-center items-center w-full md:w-[40%] w-[100%] mt-4 md:mt-0"
        data-aos="fade-up">
        <?php if (isset($component)) { $__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\HeaderSection::class, ['subtext' => ' SAMBUTAN KETUA STISIP IMAM BONJOL','subtextColor' => '#fff','title' => '','titleColor' => '#fff']); ?>
<?php $component->withName('header-section'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe)): ?>
<?php $component = $__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe; ?>
<?php unset($__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe); ?>
<?php endif; ?>
        <p class="text-justify font-dmsans mb-4 font-inter text-sm md:text-base  normal-case w-[80%]" style="color:#fff" >
        Assalamualaikum Wr. Wb.
Alhamdulillah, Puji Syukur kami panjatkan ke hadirat Allah SWT, karena atas segala Rahmat dan Hidayah-Nya kita masih tetap dalam keadaan sehat wal’afiat.
Ketua beserta seluruh Civitas Akademika Sekolah Tinggi Ilmu Sosial dan Ilmu Politik (STISIP) Imam Bonjol dengan ini mengucapkan selamat datang di Website Sekolah Tinggi Ilmu Sosial dan Ilmu Politik (STISIP) Imam Bonjol.

Perguruan Tinggi selalu merespon perkembangan Teknologi Informasi dan Komunikasi yang semakin hari semakin berkembang pesat, saat ini kita telah berada diIndustri Digital atau Revolusi Industri 5.0 dan telah memberi dampak perubahan yang besar dalam pengelolaan Perguruan Tinggi Negeri maupun Perguruan Tinggi Swasta.

Sebagai sebuah jawaban terhadap tuntutan tersebut adalah dengan penyelenggaraan pengelolaan perguruan tinggi yang berbasis elektronik dalam semua sistem yang ada di perguruan tinggi baik akademik maupun non akademik, sehingga memberi dampak terhadap peningkatan kualitas dan kapasitas sumber daya manusia yang dihasilkan untuk bisa menjawab tantangan saat ini.

Akhir kata, semoga dengan wajah baru Website Sekolah Tinggi Ilmu Sosial dan Ilmu Politik (STISIP) Imam Bonjol ini dapat lebih mempermudah akses para mahasiswa, dosen, dan masyarakat umum yang membutuhkan informasi terkait dengan penerimaan mahasiswa baru, penyelenggaraan pendidikan dan pengajaran, dan sebagainya.

Namun demikian, tentunya media ini harus terus dievaluasi dalam rangka peningkatan kualitas agar manfaatnya dapat lebih dirasakan oleh berbagai pihak. Masukan terhadap media ini tentunya sangatlah diharapkan dalam rangka membantu proses peyempurnaan tersebut. Akhir kata kami mengucapkan terimakasih.
    </p>
        
        <?php if (isset($component)) { $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940 = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\Button::class, ['url' => '/sejarah-singkat']); ?>
<?php $component->withName('button'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>BACA SELENGKAPNYA <?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940)): ?>
<?php $component = $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940; ?>
<?php unset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940); ?>
<?php endif; ?>
    </div>
</div>
<?php /**PATH /home/u768956174/domains/stisipimambonjol.info/STISIP-IMAM-BONJOL/resources/views/Frontend/landingpage/sambutan-section.blade.php ENDPATH**/ ?>