<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="utf-8">
    <meta name="description" content="STAI Fatahillah adalah Sekolah Tinggi Agama Islam yang menawarkan program S1 Pendidikan Agama Islam (PAI) dengan kurikulum berkualitas dan berbasis nilai-nilai Islam. Dengan biaya kuliah yang terjangkau, hanya Rp350.000 per bulan, STAI Fatahillah menjadi pilihan tepat bagi calon pendidik yang ingin mendalami ilmu agama dan mencetak generasi islami. Bergabunglah dan raih masa depan cerah dengan pendidikan Islam yang unggul." />
    <meta name="keywords" content=" Kelas karyawan, Kuliah karyawan, Sekolah Tinggi Agama Islam Fatahillah, kampus Sekolah Tinggi Agama Islam Fatahillah , biaya kuliah kampus STAI Fatahillah , biaya kuliah, kelas sabtu, akreditasi STAI Fatahillah, kelas karyawan terjangkau Tanggerang , S1 Pendidikan Agama Islam, kampus murah, kampus Di Tanggerang Selatan, kampus Di Tanggerang , STAI Fatahillah, biaya kuliah, kelas sabtu, akreditasi Sekolah Tinggi Agama Islam Fatahillah ,
     Kampus Kelas Karyawan Di Tanggerang Selatan, Kuliah Sambil Kerja Di Tanggerang Selatan, Universitas Terbaik di Tanggerang Selatan untuk Karyawan, Biaya Kuliah Terjangkau di Tanggerang Selatan, Universitas Kelas Sabtu Minggu Di Tanggerang Selatan, Akreditasi Universitas Di Tanggerang Selatan,Perguruan Tinggi Swasta Murah di Tanggerang Selatan, Program S1 Pendidikan Agama Islam ,  Kampus Swasta Terbaik Tanggerang Selatan, Universitas Murah  Di Tanggerang Selatan terakreditasi Baik,
     Kampus Terjangkau di Tanggerang Selatan untuk Karyawan, , Kuliah dengan Biaya Mulai 350 Ribu di Tanggerang Selatan , Universitas dengan Kelas Online Tanggerang Selatan, Kampus Swasta Kelas Sabtu Minggu di Tanggerang Selatan, Biaya Kuliah  S1 Murah di Tanggerang , Biaya Kuliah  S1 Murah di Tanggerang Selatan, Kampus dengan Program Studi Lengkap di Tanggerang Selatan, Kampus dengan Program Studi Lengkap di Tanggerang " />
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
    
    <title><?php echo $__env->yieldContent('title'); ?> &mdash; Sekolah Tinggi Agama Islam Fatahillah (Kelas Karyawan)</title>
    <meta property="og:title" content="Sekolah Tinggi Agama Islam Fatahillah (Kelas Karyawan)">
    <meta property="og:type" content="website">
    <meta property="og:url" content="staifatahillah.info">
    <meta property="og:image" content="https://staifatahillah.info/images/background/hero1.png">
    <meta property="og:image:width" content="1200" />
    <meta property="og:image:height" content="630" />
    <meta property="og:description" content="STAI Fatahillah menawarkan S1 Pendidikan Agama Islam (PAI) dengan biaya terjangkau Rp350.000/bulan. Pilihan tepat untuk pendidikan Islam yang berkualitasS!!.">
    <meta name="twitter:card" content="summary_large_image">
    <meta name="twitter:creator" content="@_kuliahkaryawan">
    <meta name="twitter:site" content="@_kuliahkaryawan">
    <meta name="twitter:title" content="Sekolah Tinggi Agama Islam Fatahillah (Kelas Karyawan) (Kelas Karyawan)">
    <meta name="twitter:description" content="STAI Fatahillah menawarkan program S1 Pendidikan Agama Islam (PAI) program kelas karyawan dengan jadwal fleksibel, memungkinkan Anda kuliah sambil bekerja. Dengan biaya terjangkau hanya Rp350.000 per bulan, STAI Fatahillah menjadi pilihan ideal bagi yang ingin meningkatkan kompetensi di bidang pendidikan Islam tanpa mengganggu aktivitas pekerjaan. Raih gelar sarjana dengan mudah dan nyaman.">
    <meta name="twitter:domain" content="swadharma.info">
    <meta name="twitter:image:src" content="https://staifatahillah.info/images/background/hero1.png">
    <meta name="author" content="Kuliah Karyawan Team" />
    <meta http-equiv="cache-control" content="public" />
    <meta name="application-name" content="Sekolah Tinggi Agama Islam Fatahillah | Kuliah Karyawan (K2)" />
    
    <link rel="apple-touch-icon" sizes="57x57" href="/images/favicons/apple-icon-57x57.png">
    <link rel="apple-touch-icon" sizes="60x60" href="/images/favicons/apple-icon-60x60.png">
    <link rel="apple-touch-icon" sizes="72x72" href="/images/favicons/apple-icon-72x72.png">
    <link rel="apple-touch-icon" sizes="76x76" href="/images/favicons/apple-icon-76x76.png">
    <link rel="apple-touch-icon" sizes="114x114" href="/images/favicons/apple-icon-114x114.png">
    <link rel="apple-touch-icon" sizes="120x120" href="/images/favicons/apple-icon-120x120.png">
    <link rel="apple-touch-icon" sizes="144x144" href="/images/favicons/apple-icon-144x144.png">
    <link rel="apple-touch-icon" sizes="152x152" href="/images/favicons/apple-icon-152x152.png">
    <link rel="apple-touch-icon" sizes="180x180" href="/images/favicons/apple-icon-180x180.png">
    <link rel="icon" type="image/png" sizes="192x192"  href="/images/favicons/android-icon-192x192.png">
    <link rel="icon" type="image/png" sizes="32x32" href="/images/favicons/favicon-32x32.png">
    <link rel="icon" type="image/png" sizes="96x96" href="/images/favicons/favicon-96x96.png">
    <link rel="icon" type="image/png" sizes="16x16" href="/images/favicons/favicon-16x16.png">
    <link rel="manifest" href="/images/favicons/manifest.json">
    <meta name="msapplication-TileColor" content="#ffffff">
    <meta name="msapplication-TileImage" content="/images/favicons/ms-icon-144x144.png">
    <meta name="theme-color" content="#ffffff">
    
    <link href="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.css" rel="stylesheet" />

    <!-- Add Poppins font -->
    <link rel="preconnect" href="https://fonts.googleapis.com">
    <link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
    <link
        href="https://fonts.googleapis.com/css2?family=Poppins:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900&display=swap"
        rel="stylesheet">

    <script src="https://cdn.tailwindcss.com?plugins=forms,typography,aspect-ratio,line-clamp,container-queries"></script>
</head>

<body class="font-poppins h-screen flex items-center justify-center bg-cover bg-center">
    <?php echo $__env->yieldContent('content'); ?>

    
    <script src="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.js"></script>
    <!-- Font Awesome for icons (used for Twitter icon) -->
    <script src="https://kit.fontawesome.com/a076d05399.js" crossorigin="anonymous"></script>

    
    <?php echo $__env->yieldPushContent('scripts'); ?>
</body>

</html>
<?php /**PATH D:\2025-STAI-Fatahillah\resources\views/auth/app.blade.php ENDPATH**/ ?>