<?php $__env->startSection('content'); ?>
    <?php if (isset($component)) { $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\HeaderSectionPage::class, ['title' => 'Sejarah Universitas Indonesia Maju','breadcrumbHome' => 'Home','breadcrumbCurrent' => 'Sejarah Singkat']); ?>
<?php $component->withName('header-section-page'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df)): ?>
<?php $component = $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df; ?>
<?php unset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df); ?>
<?php endif; ?>

    <div data-aos="fade-up" class=" flex flex-col my-6 md:my-10 px-4 md:px-20 lg:px-32 xl:px-60">
        <!-- Gambar -->
        

        <!-- Konten Teks -->
        <div data-aos="fade-up" class="flex flex-col space-y-4 text-justify font-dmsans text-[14px] md:text-[16px]">
            <p>
            Dalam satu dekade terakhir ini telah terjadi perubahan-perubahan yang cukup penting pada tingkat global yang cukup besar pengaruhnya terhadap pembangunan nasional Indonesia. Betapa tidak, situasi global dan krisis ekonomi yang berkepanjangan menimpa berbagai dimensi kehidupan bangsa lndonesia ini diantaranya adalah pelaksanaan sistem ekonomi “pasar bebas” yang mana setiap negara harus berbenah dan mempersiapkan diri. Peluang privatisasi bertambah tinggi dan berlangsung cepat termasuk privatisasi bidang kesehatan. Pihak swasta akan memasuki bidang kesehatan melalui bidang asuransi kesehatan, rumah sakit, bisnis alat medis, makanan, obat kosmetika dan pendidikan di bidang kesehatan. Maka untuk mengimplemantasikan hal tersebut pemerintah memberikan peluang pada swasta untuk lebih berperan di dalam pembangunan kesehatan dan pendidikan.            </p>
            <p>
            Berkaitan dengan itu, Yayasan Indonesia Maju mendirikan suatu lembaga pendidikan tinggi swasta yang resmi dengan bentuk Sekotah Tinggi, yakni dengan nama Sekolah Tinggi Ilmu Kesehatan Indonesia Maju (STIKIM), merupakan perguruan tinggi swasta yang resmi berdiri pada tanggal 26 Juli 2000, dengan program studi S1-Kesehatan Masyarakat, D3 Manajemen Pelayanan RS, dan D3 Asuransi Kesehatan (Keputusan Mendiknas No.115/D/O/2000).            </p>
        </div>

        <!-- Bagian Ajakan -->
        <div data-aos="fade-up" class="flex items-center flex-col pt-10">
            <div data-aos="fade-up" class="w-full h-[1px] bg-blue-900 my-4"></div>
            <h1 data-aos="fade-up" class="text-center font-poppins text-[20px] md:text-[30px] font-bold text-primary">DAFTAR
                SEKARANG</h1>
            <p data-aos="fade-up" class="text-center mb-5 text-[12px] md:text-[14px] lg:text-[16px]">
            Raih kesuksesan akademik di Universitas Indonesia Maju! Program studi unggulan, dosen ahli, dan fasilitas canggih kami akan mendukung perjalananmu menuju masa depan yang cerah
            </p>
            <?php if (isset($component)) { $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940 = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\Button::class, ['url' => '/pendaftaran']); ?>
<?php $component->withName('button'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>DAFTAR SEKARANG <?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940)): ?>
<?php $component = $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940; ?>
<?php unset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940); ?>
<?php endif; ?>
        </div>
    </div>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('Frontend.Layouts.app2', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH D:\2025_UIMA\resources\views/Frontend/sejarah.blade.php ENDPATH**/ ?>