<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="utf-8">
    <meta name="description"
        content="Universitas PGRI Yogyakarta atau yang biasa dikenal UPY salah satu Perguruan Tinggi Swasta Terbaik di Yogyakarta, tersedia kelas karyawan dengan biaya murah dan terjangkau nulai dari  Rp 1.000.000/Bulan dengan jurusan  S1 Pendidikan Guru Sekolah Dasar, S1 Bimbingan dan Konseling, S1 PPKN, S1 Pendidikan Guru Paud, S1 Pendidikan Luar Biasa, S1 Pendidikan Matematika, S1 Pendidikan Bahasa dan Sastra Indonesia, S1 Pendidikan Sejarah, S1 Pendidikan B.Inggris, S1 Pendidikan Vokasional Teknologi Otomotif" />
    <meta name="keywords"
        content="Kelas karyawan, Kuliah karyawan, Universitas PGRI Yogyakarta, kampus UPY, biaya kuliah kampus UPY, UPY, biaya kuliah, kelas sabtu, akreditasi UPY, S1 Pendidikan Guru Sekolah Dasar, S1 Bimbingan dan Konseling, S1 PPKN, S1 Pendidikan Guru Paud, S1 Pendidikan Luar Biasa, S1 Pendidikan Matematika, S1 Pendidikan Bahasa dan Sastra Indonesia, S1 Pendidikan Sejarah, S1 Pendidikan B.Inggris, S1 Pendidikan Vokasional Teknologi Otomotif, kampus murah, kampus Yogyakarta, kampus Yogyakarta." />
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
    <meta name="google-site-verification" content="cYk75UAqQazvmINnhBZmGS7FNTQJwDab3ugNvSxp1cs" />

    <title>Universitas PGRI Yogyakarta (Kelas Karyawan)</title>
    <meta property="og:title" content="Universitas PGRI Yogyakarta (Kelas Karyawan)">
    <meta property="og:type" content="website">
    <meta property="og:url" content="https://www.upy.web.id/">
    <meta property="og:image" content="images/banner-slider/Baner-upy.png">
    <meta property="og:image:width" content="1200" />
    <meta property="og:image:height" content="630" />
    <meta property="og:description"
        content="Universitas PGRI Yogyakarta atau yang biasa dikenal UPY salah satu Perguruan Tinggi Swasta Terbaik di Yogyakarta, tersedia kelas karyawan dengan biaya murah dan terjangkau cukup Rp 1.000.000/Bulan dengan jurusan S1 Pendidikan Guru Sekolah Dasar, S1 Bimbingan dan Konseling, S1 PPKN, S1 Pendidikan Guru Paud, S1 Pendidikan Luar Biasa, S1 Pendidikan Matematika, S1 Pendidikan Bahasa dan Sastra Indonesia, S1 Pendidikan Sejarah, S1 Pendidikan B.Inggris, S1 Pendidikan Vokasional Teknologi Otomotif">
    <meta name="twitter:card" content="summary_large_image">
    <meta name="twitter:creator" content="@_kuliahkaryawan">
    <meta name="twitter:site" content="@_kuliahkaryawan">
    <meta name="twitter:title" content="Universitas PGRI Yogyakarta (Kelas Karyawan)">
    <meta name="twitter:description"
        content="Universitas PGRI Yogyakarta atau yang biasa dikenal UPY salah satu Perguruan Tinggi Swasta Terbaik di Yogyakarta, tersedia kelas karyawan dengan biaya murah dan terjangkau cukup Rp 1.000.000/Bulan dengan jurusan S1 Pendidikan Guru Sekolah Dasar, S1 Bimbingan dan Konseling, S1 PPKN, S1 Pendidikan Guru Paud, S1 Pendidikan Luar Biasa, S1 Pendidikan Matematika, S1 Pendidikan Bahasa dan Sastra Indonesia, S1 Pendidikan Sejarah, S1 Pendidikan B.Inggris, S1 Pendidikan Vokasional Teknologi Otomotif">
    <meta name="twitter:domain" content="https://upy.web.id">
    <meta name="twitter:image:src" content="images/banner-slider/Baner-upy.png">

    <link rel="apple-touch-icon" sizes="57x57" href="images/favicon/apple-icon-57x57.png">
    <link rel="apple-touch-icon" sizes="60x60" href="images/favicon/apple-icon-60x60.png">
    <link rel="apple-touch-icon" sizes="72x72" href="images/favicon/apple-icon-72x72.png">
    <link rel="apple-touch-icon" sizes="76x76" href="images/favicon/apple-icon-76x76.png">
    <link rel="apple-touch-icon" sizes="114x114" href="images/favicon/apple-icon-114x114.png">
    <link rel="apple-touch-icon" sizes="120x120" href="images/favicon/apple-icon-120x120.png">
    <link rel="apple-touch-icon" sizes="144x144" href="images/favicon/apple-icon-144x144.png">
    <link rel="apple-touch-icon" sizes="152x152" href="images/favicon/apple-icon-152x152.png">
    <link rel="apple-touch-icon" sizes="180x180" href="images/favicon/apple-icon-180x180.png">
    <link rel="icon" type="image/png" sizes="192x192" href="images/favicon/android-icon-192x192.png">
    <link rel="icon" type="image/png" sizes="32x32" href="images/favicon/favicon-32x32.png">
    <link rel="icon" type="image/png" sizes="96x96" href="images/favicon/favicon-96x96.png">
    <link rel="icon" type="image/png" sizes="16x16" href="images/favicon/favicon-16x16.png">
    <link rel="manifest" href="images/favicon/manifest.json">
    <meta name="msapplication-TileColor" content="#ffffff">
    <meta name="msapplication-TileImage" content="images/favicon/ms-icon-144x144.png">
    <meta name="theme-color" content="#ffffff">

    
    <link href="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.css" rel="stylesheet" />

    <!-- Add Poppins font -->
    <link rel="preconnect" href="https://fonts.googleapis.com">
    <link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
    <link
        href="https://fonts.googleapis.com/css2?family=Poppins:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900&display=swap"
        rel="stylesheet">

    <script src="https://cdn.tailwindcss.com?plugins=forms,typography,aspect-ratio,line-clamp,container-queries"></script>
</head>

<body class="font-poppins h-screen flex items-center justify-center bg-cover bg-center">
    <?php echo $__env->yieldContent('content'); ?>

    
    <script src="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.js"></script>
    <!-- Font Awesome for icons (used for Twitter icon) -->
    <script src="https://kit.fontawesome.com/a076d05399.js" crossorigin="anonymous"></script>

    
    <?php echo $__env->yieldPushContent('scripts'); ?>
</body>

</html>
<?php /**PATH D:\2025_UIMA\resources\views/auth/app.blade.php ENDPATH**/ ?>