<!DOCTYPE html>
<html lang="id">

<head>
<meta charset="utf-8">
    <meta name="description" content="Universitas Indonesia Maju (UIMA) adalah salah satu Perguruan Tinggi Swasta unggulan di Jakarta yang menyediakan berbagai program pendidikan berkualitas dengan biaya yang terjangkau. UIMA menawarkan program kelas karyawan dengan biaya mulai dari Rp 500.000/bulan, cocok bagi Anda yang ingin melanjutkan pendidikan tanpa mengganggu aktivitas pekerjaan. Pilihan program studi yang tersedia: D3 Periklanan, S1 Ilmu Komunikasi, S1 Hukum, S1 Administrasi Rumah Sakit (ARS), S1 Manajemen, S1 Psikologi, S1 Akuntansi, dan S1 Gizi,S1 Keselamatan Kesehatan Kerja. Dengan fasilitas modern dan dosen berpengalaman, UIMA hadir sebagai solusi pendidikan yang mendukung pengembangan karir dan keahlian Anda." />
    <meta name="keywords" content="Kelas karyawan, Kuliah karyawan, Universitas Indonesia Maju, kampus Universitas Indonesia Maju Jakarta, biaya kuliah kampus UIMA Jakarta, biaya kuliah, kelas sabtu, akreditasi UIMA Jakarta, kelas karyawan terjangkau Jakarta, D3 Periklanan, S1 Ilmu Komunikasi, S1 Hukum, S1 Administrasi Rumah Sakit (ARS), S1 Manajemen, S1 Psikologi, S1 Akuntansi, dan S1 Gizi,S1 Keselamatan Kesehatan Kerja, kampus murah, kampus Jakarta,UIMA Universitas Indonesia Maju, kampus UIMA Universitas Indonesia Maju Jakarta, biaya kuliah kampus UIMA Jakarta, biaya kuliah, kelas sabtu, akreditasi UIMA Jakarta,
     Kampus Kelas Karyawan Jakarta, Kuliah Sambil Kerja Jakarta, Universitas Terbaik Jakarta untuk Karyawan, Biaya Kuliah Terjangkau di Jakarta, Universitas Kelas Sabtu Jakarta, Akreditasi Universitas Jakarta, Perguruan Tinggi Swasta Jakarta Murah, Program D3 Periklanan Jakarta, Kuliah S1 Ilmu Komunikasi Jakarta, Kuliah S1 Hukum Murah Jakarta, Kuliah Administrasi Rumah Sakit Jakarta, S1 Manajemen Biaya Terjangkau Jakarta, S1 Psikologi Jakarta Murah, Universitas S1 Akuntansi Jakarta, S1 Gizi Kelas Karyawan Jakarta, Kuliah S1 Keselamatan dan Kesehatan Kerja (K3), Kampus Swasta Terbaik Jakarta, Universitas Murah Jakarta dengan Akreditasi Baik,
     UIMA Universitas Indonesia Maju, Kampus Terjangkau Jakarta untuk Karyawan, Kuliah dengan Biaya Mulai 500 Ribu di Jakarta, Universitas dengan Kelas Online Jakarta, Kampus Swasta Kelas Sabtu Minggu Jakarta, Biaya Kuliah D3 dan S1 Murah di Jakarta, Kampus dengan Program Studi Lengkap Jakarta" />
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
    
    <title>Universitas Indonesia Maju (Kelas Karyawan)</title>
    <meta property="og:title" content="Universitas Indonesia Maju (Kelas Karyawan)">
    <meta property="og:type" content="website">
    <meta property="og:url" content="muliadarma.info">
    <meta property="og:image" content="https://stie.muliadarma.info/images/banner-slider/Banner-stiemuliadarma.png">
    <meta property="og:image:width" content="1200" />
    <meta property="og:image:height" content="630" />
    <meta property="og:description" content="Universitas Indonesia Maju (UIMA) adalah Perguruan Tinggi Swasta terbaik di Jakarta, menyediakan pendidikan berkualitas dengan biaya terjangkau. UIMA menawarkan program kuliah reguler dan kelas karyawan fleksibel. Dengan fasilitas modern, tenaga pengajar profesional, dan suasana belajar kondusif, UIMA hadir sebagai solusi pendidikan. Program studi: D3 Periklanan, S1 Ilmu Komunikasi, S1 Hukum, S1 Administrasi Rumah Sakit (ARS), S1 Manajemen, S1 Psikologi, S1 Akuntansi, S1 Gizi, dan S1 Keselamatan dan Kesehatan Kerja (K3). Biaya kuliah mulai Rp 500.000/bulan. UIMA fokus mencetak individu kompeten, kreatif, dan siap bersaing.">
    <meta name="twitter:card" content="summary_large_image">
    <meta name="twitter:creator" content="@_kuliahkaryawan">
    <meta name="twitter:site" content="@_kuliahkaryawan">
    <meta name="twitter:title" content="Universitas Indonesia Maju (Kelas Karyawan)">
    <meta name="twitter:description" content="Kelas Karyawan Universitas Indonesia Maju (UIMA) adalah solusi bagi Anda yang ingin melanjutkan pendidikan tanpa meninggalkan pekerjaan. Program ini memiliki jadwal fleksibel, termasuk kuliah malam atau hari Sabtu. Biaya kuliah sangat terjangkau, mulai dari Rp 500.000/bulan. Program studi yang tersedia: D3 Periklanan, S1 Ilmu Komunikasi, S1 Hukum, S1 Administrasi Rumah Sakit (ARS), S1 Manajemen, S1 Psikologi, S1 Akuntansi, S1 Gizi, dan S1 Keselamatan dan Kesehatan Kerja (K3). Dengan fasilitas modern, dosen berpengalaman, dan suasana akademik mendukung, UIMA membantu Anda meraih gelar pendidikan tinggi sambil tetap bekerja.">
    <meta name="twitter:domain" content="muliadarma.info">
    <meta name="twitter:image:src" content="https://stie.muliadarma.info/images/banner-slider/Banner-stiemuliadarma.png">
    <meta name="author" content="Kuliah Karyawan Team" />
    <meta http-equiv="cache-control" content="public" />
    <meta name="application-name" content="Universitas Indonesia Maju | Kuliah Karyawan (K2)" />

    <link rel="apple-touch-icon" sizes="57x57" href="/images/favicons/apple-icon-57x57.png">
    <link rel="apple-touch-icon" sizes="60x60" href="/images/favicons/apple-icon-60x60.png">
    <link rel="apple-touch-icon" sizes="72x72" href="/images/favicons/apple-icon-72x72.png">
    <link rel="apple-touch-icon" sizes="76x76" href="/images/favicons/apple-icon-76x76.png">
    <link rel="apple-touch-icon" sizes="114x114" href="/images/favicons/apple-icon-114x114.png">
    <link rel="apple-touch-icon" sizes="120x120" href="/images/favicons/apple-icon-120x120.png">
    <link rel="apple-touch-icon" sizes="144x144" href="/images/favicons/apple-icon-144x144.png">
    <link rel="apple-touch-icon" sizes="152x152" href="/images/favicons/apple-icon-152x152.png">
    <link rel="apple-touch-icon" sizes="180x180" href="/images/favicons/apple-icon-180x180.png">
    <link rel="icon" type="image/png" sizes="192x192"  href="/images/favicons/android-icon-192x192.png">
    <link rel="icon" type="image/png" sizes="32x32" href="/images/favicons/favicon-32x32.png">
    <link rel="icon" type="image/png" sizes="96x96" href="/images/favicons/favicon-96x96.png">
    <link rel="icon" type="image/png" sizes="16x16" href="/images/favicons/favicon-16x16.png">
    <link rel="manifest" href="/images/favicons/manifest.json">
    <meta name="msapplication-TileColor" content="#ffffff">
    <meta name="msapplication-TileImage" content="/images/favicons/ms-icon-144x144.png">
    <meta name="theme-color" content="#ffffff">
    

    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.css" rel="stylesheet" />
    <link href="https://fonts.googleapis.com/css2?family=Poppins:wght@400;600&family=DM+Sans:wght@400;700&display=swap"
        rel="stylesheet">
    <link href="./css/app.css" rel="stylesheet">
    <link href="<?php echo e(asset('css/app.css')); ?>" rel="stylesheet">
    
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.css" />
    
    <link href="https://cdn.jsdelivr.net/npm/aos@2.3.4/dist/aos.css" rel="stylesheet">
    
    <?php echo $__env->yieldPushContent('prpend-style'); ?>
    <?php echo $__env->yieldPushContent('addon-style'); ?>

</head>

<body>

    
    <?php echo $__env->make('Frontend.Template.navbar', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>

    
    <div class="h-auto flex flex-col items-center justify-center md:gap-x-[100px] py-8 py-[100px] px-4 md:px-0 bg-cover bg-no-repeat bg-right md:bg-center-top"
        style="background-image: url('<?php echo e(asset('./images/background/bg-blue.png')); ?>');">
        <?php echo $__env->yieldContent('content'); ?>
    </div>

    <div class="fixed flex-row items-center bottom-4 right-4 z-50 md:bottom-10 md:right-10 flex ">
        <!-- Animated WhatsApp Button -->
        <div
            class="slide-text whatsapp-button overflow-hidden transition-all duration-500 ease-in-out bg-[#40C351] h-[40px] py-2 px-4 font-poppins text-white rounded-full mb-2">
            <h1 class="whatsapp-button-text ">ingin bertanya ? yuk di click !</h1>
        </div>

        <!-- WhatsApp Icon -->
        <a href="https://wa.me/6287890198284?text=Halo%20Admin%2C%20saya%20mau%20bertanya%20%0ASumber%20%3A%20<?php echo e(url()->current()); ?>"
            target="_blank" rel="noopener noreferrer">
            <img src="<?php echo e(asset('images/logo/wa.jpg')); ?>" alt="WhatsApp" class="w-12 h-12 md:w-[70px] md:h-[70px]">
        </a>
    </div>

    
    <?php echo $__env->make('Frontend.Template.footer', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>



    
    <?php echo $__env->yieldPushContent('prpend-script'); ?>
    <?php echo $__env->yieldPushContent('addon-script'); ?>



    
    <script src="https://www.google.com/recaptcha/api.js"></script>
    
    <script src="https://cdn.jsdelivr.net/npm/aos@2.3.4/dist/aos.js"></script>
    
    <script src="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.js"></script>
    <script src="./js/app.js"></script>
    <script src="<?php echo e(asset('./js/app.js')); ?>"></script>
</body>

</html>
<?php /**PATH /home/u4591423/public_html/PUBLIC_DOMAIN/2025_UIMA/resources/views/Frontend/Layouts/app2.blade.php ENDPATH**/ ?>