<div class="relative w-full h-screen bg-center bg-cover bg-no-repeat flex flex-col items-center justify-center overflow-hidden" 
     style="background-color:#019934;" 
     data-aos="fade-up">
  
     <picture style="width: 100%; height: 100%; ">
    <source class="w-full h-full object-cover" srcset="/images/background/hero2.png" media="(max-width: 768px)">
    <img class="w-full h-full object-cover" src="/images/background/hero1.png" alt="Banner">
  </picture>

</div>

<div class="w-full h-[40px] py-6 flex items-center bg-accent text-white overflow-hidden" data-aos="fade-down">
    <div class="w-full whitespace-nowrap animate-marquee flex items-center">
        <span class="font-poppins mx-4 text-[40px] font-bold" data-aos="flip-left" style="color:#fff" >STISIP IMAM BONJOL PADANG</span>
        <img src="<?php echo e(asset('./images/logo/logo1.png')); ?>" alt="Logo" class="h-[40px] w-auto mx-4" style="border-radius: 50px;"
            data-aos="flip-left">
        <span class="font-poppins mx-4 text-[40px] font-bold" data-aos="flip-left" style="color:#fff">STISIP IMAM BONJOL PADANG</span>
        <img src="<?php echo e(asset('./images/logo/logo1.png')); ?>" alt="Logo" class="h-[40px] w-auto mx-4" style="border-radius: 50px;"
            data-aos="flip-left">
        <span class="font-poppins mx-4 text-[40px] font-bold" data-aos="flip-left" style="color:#fff">STISIP IMAM BONJOL PADANG</span>
        <img src="<?php echo e(asset('./images/logo/logo1.png')); ?>" alt="Logo" class="h-[40px] w-auto mx-4" style="border-radius: 50px;"
            data-aos="flip-left">
        <span class="font-poppins mx-4 text-[40px] font-bold" data-aos="flip-left" style="color:#fff">STISIP IMAM BONJOL PADANG</span>
        <img src="<?php echo e(asset('./images/logo/logo1.png')); ?>" alt="Logo" class="h-[40px] w-auto mx-4" style="border-radius: 50px;"
            data-aos="flip-left">
        <span class="font-poppins mx-4 text-[40px] font-bold" data-aos="flip-left" style="color:#fff">STISIP IMAM BONJOL PADANG</span>
        <img src="<?php echo e(asset('./images/logo/logo1.png')); ?>" alt="Logo" class="h-[40px] w-auto mx-4" style="border-radius: 50px;"
            data-aos="flip-left">
        <span class="font-poppins mx-4 text-[40px] font-bold" data-aos="flip-left" style="color:#fff">STISIP IMAM BONJOL PADANG</span>
        <img src="<?php echo e(asset('./images/logo/logo1.png')); ?>" alt="Logo" class="h-[40px] w-auto mx-4" style="border-radius: 50px;"
            data-aos="flip-left">
        <span class="font-poppins mx-4 text-[40px] font-bold" data-aos="flip-left" style="color:#fff">STISIP IMAM BONJOL PADANG</span>
    </div>
</div>
<?php /**PATH D:\2025-STISIP-IMAM-BONJOL\resources\views/Frontend/landingpage/hero-section.blade.php ENDPATH**/ ?>