<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="utf-8">
    <meta name="description" content="nstitut Teknologi dan Bisnis Swadharma (ITBS) adalah perguruan tinggi modern yang berfokus pada pendidikan teknologi dan bisnis untuk mencetak lulusan berkualitas tinggi di era digital. ITBS menawarkan program studi S1 Teknik Informatika, Sistem Informasi, Sains Data, Akuntansi, dan Bisnis Digital, yang dirancang untuk memenuhi kebutuhan industri dan perkembangan zaman.Dengan biaya pendidikan yang terjangkau, hanya Rp600.000 per bulan, ITBS memberikan akses kepada fasilitas modern, kurikulum berbasis kompetensi, serta bimbingan dari dosen profesional. ITBS adalah pilihan tepat untuk generasi muda yang ingin mengembangkan keahlian di bidang teknologi dan bisnis sambil mempersiapkan diri menghadapi tantangan dunia kerja." />
    <meta name="keywords" content=" Kelas karyawan, Kuliah karyawan, Institut Teknologi Dan Bisnis Swadharma, kampus Institut Teknologi Dan Bisnis Swadharma , biaya kuliah kampus ITB Swadharma , biaya kuliah, kelas sabtu, akreditasi ITB Swadharma, kelas karyawan terjangkau Banten, S1 Bisnis Digital, S1 Informatika, S1 Sistem Informasi, S1 Akuntansi, S1 Sains Data, kampus murah, kampus Di Jakarta, kampus Di Jakarta, ITB Swadharma, biaya kuliah, kelas sabtu, akreditasi Institut Teknologi Dan Bisnis Swadharma ,
     Kampus Kelas Karyawan Jakarta, Kuliah Sambil Kerja Jakarta, Universitas Terbaik di Jakarta untuk Karyawan, Biaya Kuliah Terjangkau di Jakarta, Universitas Kelas Sabtu Minggu Di Jakarta, Akreditasi Universitas Di Jakarta,Perguruan Tinggi Swasta Murah di Jakarta, Program S1 Akuntansi , Program S1 Sains Data, Program S1 Bisnis Digital, Program S1 Informatika, Program S1 Sistem Informasi,  Kampus Swasta Terbaik Jakarta, Universitas Murah  Di Jakarta terakreditasi Baik,
     Kampus Terjangkau di Jakarta untuk Karyawan, , Kuliah dengan Biaya Mulai 600 Ribu di Jakarta , Universitas dengan Kelas Online Jakarta, Kampus Swasta Kelas Sabtu Minggu di Jakarta, Biaya Kuliah  S1 Murah di banten, Biaya Kuliah  S1 Murah di Jakarta, Kampus dengan Program Studi Lengkap di Jakarta, Kampus dengan Program Studi Lengkap di banten" />
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
    
    <title> Institut Teknologi dan Bisnis Swadharma (Kelas Karyawan)</title>
    <meta property="og:title" content="Institut Teknologi dan Bisnis Swadharma (Kelas Karyawan)">
    <meta property="og:type" content="website">
    <meta property="og:url" content="swadharma.info">
    <meta property="og:image" content="https://swadharma.info/images/background/hero1.png">
    <meta property="og:image:width" content="1200" />
    <meta property="og:image:height" content="630" />
    <meta property="og:description" content="Institut Teknologi dan Bisnis Swadharma (ITBS) menawarkan program unggulan S1 Teknik Informatika, Sistem Informasi, Sains Data, Akuntansi, dan Bisnis Digital dengan biaya hanya Rp600.000 per bulan. Bergabunglah untuk menjadi profesional di era digital dengan pendidikan berkualitas dan terjangkau!!.">
    <meta name="twitter:card" content="summary_large_image">
    <meta name="twitter:creator" content="@_kuliahkaryawan">
    <meta name="twitter:site" content="@_kuliahkaryawan">
    <meta name="twitter:title" content="Institut Teknologi dan Bisnis Swadharma (Kelas Karyawan) (Kelas Karyawan)">
    <meta name="twitter:description" content="Kelas Karyawan ITBS dirancang khusus untuk para pekerja yang ingin melanjutkan pendidikan tanpa mengganggu aktivitas kerja. Dengan program S1 Teknik Informatika, Sistem Informasi, Sains Data, Akuntansi, dan Bisnis Digital, ITBS memberikan fleksibilitas jadwal kuliah dan biaya terjangkau, hanya Rp600.000 per bulan. Tingkatkan karier Anda bersama ITBS dengan pendidikan berkualitas yang sesuai kebutuhan era digital!!.">
    <meta name="twitter:domain" content="swadharma.info">
    <meta name="twitter:image:src" content="https://swadharma.info/images/background/hero1.png">
    <meta name="author" content="Kuliah Karyawan Team" />
    <meta http-equiv="cache-control" content="public" />
    <meta name="application-name" content="Institut Teknologi dan Bisnis Swadharma | Kuliah Karyawan (K2)" />
    
    <link rel="apple-touch-icon" sizes="57x57" href="/images/favicons/apple-icon-57x57.png">
    <link rel="apple-touch-icon" sizes="60x60" href="/images/favicons/apple-icon-60x60.png">
    <link rel="apple-touch-icon" sizes="72x72" href="/images/favicons/apple-icon-72x72.png">
    <link rel="apple-touch-icon" sizes="76x76" href="/images/favicons/apple-icon-76x76.png">
    <link rel="apple-touch-icon" sizes="114x114" href="/images/favicons/apple-icon-114x114.png">
    <link rel="apple-touch-icon" sizes="120x120" href="/images/favicons/apple-icon-120x120.png">
    <link rel="apple-touch-icon" sizes="144x144" href="/images/favicons/apple-icon-144x144.png">
    <link rel="apple-touch-icon" sizes="152x152" href="/images/favicons/apple-icon-152x152.png">
    <link rel="apple-touch-icon" sizes="180x180" href="/images/favicons/apple-icon-180x180.png">
    <link rel="icon" type="image/png" sizes="192x192"  href="/images/favicons/android-icon-192x192.png">
    <link rel="icon" type="image/png" sizes="32x32" href="/images/favicons/favicon-32x32.png">
    <link rel="icon" type="image/png" sizes="96x96" href="/images/favicons/favicon-96x96.png">
    <link rel="icon" type="image/png" sizes="16x16" href="/images/favicons/favicon-16x16.png">
    <link rel="manifest" href="/images/favicons/manifest.json">
    <meta name="msapplication-TileColor" content="#ffffff">
    <meta name="msapplication-TileImage" content="/images/favicons/ms-icon-144x144.png">
    <meta name="theme-color" content="#ffffff">
    
    <link href="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.css" rel="stylesheet" />

    <!-- Add Poppins font -->
    <link rel="preconnect" href="https://fonts.googleapis.com">
    <link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
    <link
        href="https://fonts.googleapis.com/css2?family=Poppins:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900&display=swap"
        rel="stylesheet">

    <script src="https://cdn.tailwindcss.com?plugins=forms,typography,aspect-ratio,line-clamp,container-queries"></script>
</head>

<body class="font-poppins h-screen flex items-center justify-center bg-cover bg-center">
    <?php echo $__env->yieldContent('content'); ?>

    
    <script src="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.js"></script>
    <!-- Font Awesome for icons (used for Twitter icon) -->
    <script src="https://kit.fontawesome.com/a076d05399.js" crossorigin="anonymous"></script>

    
    <?php echo $__env->yieldPushContent('scripts'); ?>
</body>

</html>
<?php /**PATH D:\2025-ITBSWADARMA\resources\views/auth/app.blade.php ENDPATH**/ ?>