<!DOCTYPE html>
<html lang="id">

<head>
<meta charset="utf-8">
    <meta charset="utf-8">
    <meta name="description" content="Institut Teknologi dan Bisnis Banten (ITB Banten) menawarkan program studi berkualitas di bidang teknologi dan bisnis, antara lain S1 Bisnis Digital, S1 Informatika, S1 Sistem Informasi, D3 Akuntansi, dan D3 Keuangan dan Perbankan. Dengan biaya kuliah mulai dari Rp 450.000, ITB Banten menyediakan pendidikan praktis dengan dosen berkompeten dan fasilitas lengkap untuk mempersiapkan mahasiswa menghadapi dunia profesional. Bergabunglah dan raih masa depan cerah bersama kami!" />
    <meta name="keywords" content=" Kelas karyawan, Kuliah karyawan, Institut Teknologi Dan Bisnis Banten, kampus Institut Teknologi Dan Bisnis Banten , biaya kuliah kampus ITB BANTEN , biaya kuliah, kelas sabtu, akreditasi ITB BANTEN, kelas karyawan terjangkau Banten, S1 Bisnis Digital, S1 Informatika, S1 Sistem Informasi, D3 Akuntansi, D3 Keuangan Dan Perbankan, kampus murah, kampus Di Serang, kampus Di banten, ITB BANTEN, biaya kuliah, kelas sabtu, akreditasi Institut Teknologi Dan Bisnis Banten ,
     Kampus Kelas Karyawan Serang, Kampus Kelas Karyawan Banten, Kuliah Sambil Kerja Serang, Kuliah Sambil Kerja Banten, Universitas Terbaik di Serang untuk Karyawan, Universitas Terbaik di Banten untuk Karyawan, Biaya Kuliah Terjangkau di Serang, Biaya Kuliah Terjangkau di Banten, Universitas Kelas Sabtu Banten, Universitas Kelas Sabtu Serang, Akreditasi Universitas Di Serang, Akreditasi Universitas Di Banten, Perguruan Tinggi Swasta Murah di Serang, Perguruan Tinggi Swasta Murah di Banten , Program D3 Akuntansi , Program D3 Keuangan Dan perbankan, Program S1 Bisnis Digital, Program S1 Informatika, Program S1 Sistem Informasi, Kampus Swasta Terbaik Banten, Kampus Swasta Terbaik serang, Universitas Murah  Di Banten terakreditasi Baik, Universitas Murah  Di Serang terakreditasi Baik,
     Kampus Terjangkau di banten untuk Karyawan, Kampus Terjangkau di serang untuk Karyawan, , Kuliah dengan Biaya Mulai 400 Ribu di banten , Kuliah dengan Biaya Mulai 400 Ribu di serang, Universitas dengan Kelas Online Serang, Universitas dengan Kelas Online Banten, Kampus Swasta Kelas Sabtu Minggu di Banten, Kampus Swasta Kelas Sabtu Minggu di seramg, Biaya Kuliah  S1 Murah di banten, Biaya Kuliah  S1 Murah di serang, Kampus dengan Program Studi Lengkap di serang, Kampus dengan Program Studi Lengkap di banten" />
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
    
    <title><?php echo $__env->yieldContent('title'); ?> &mdash; Institut Teknologi dan Bisnis Banten (Kelas Karyawan)</title>
    <meta property="og:title" content="Institut Teknologi dan Bisnis Banten (Kelas Karyawan)">
    <meta property="og:type" content="website">
    <meta property="og:url" content="institutbanten.info">
    <meta property="og:image" content="https://institutbanten.info/images/background/hero1.png">
    <meta property="og:image:width" content="1200" />
    <meta property="og:image:height" content="630" />
    <meta property="og:description" content="Institut Teknologi dan Bisnis Banten (ITB Banten) adalah perguruan tinggi yang menyediakan program studi unggulan di bidang teknologi dan bisnis, termasuk S1 Bisnis Digital, S1 Informatika, S1 Sistem Informasi, D3 Akuntansi, dan D3 Keuangan dan Perbankan. Dengan biaya kuliah mulai dari Rp 450.000, ITB Banten menawarkan pendidikan yang berkualitas dengan pengajaran dari dosen berpengalaman dan fasilitas yang mendukung untuk membekali mahasiswa dengan keterampilan yang relevan dengan kebutuhan industri. Bergabung dengan ITB Banten, dan siapkan diri Anda untuk karier sukses di masa depan!.">
    <meta name="twitter:card" content="summary_large_image">
    <meta name="twitter:creator" content="@_kuliahkaryawan">
    <meta name="twitter:site" content="@_kuliahkaryawan">
    <meta name="twitter:title" content="Institut Teknologi dan Bisnis Banten (Kelas Karyawan) (Kelas Karyawan)">
    <meta name="twitter:description" content="Kelas Karyawan Institut Teknologi dan Bisnis Banten (ITB Banten) menawarkan program studi fleksibel untuk para profesional, termasuk S1 Bisnis Digital, S1 Informatika, S1 Sistem Informasi, D3 Akuntansi, dan D3 Keuangan dan Perbankan. Dengan biaya kuliah mulai dari Rp 450.000, ITB Banten menyediakan pendidikan berkualitas yang dapat disesuaikan dengan jadwal kerja Anda. Dapatkan pengalaman belajar praktis dengan fasilitas lengkap dan dosen berkompeten, sambil tetap melanjutkan karier Anda!.">
    <meta name="twitter:domain" content="institutbanten.info">
    <meta name="twitter:image:src" content="https://institutbanten.info/images/background/hero1.png">
    <meta name="author" content="Kuliah Karyawan Team" />
    <meta http-equiv="cache-control" content="public" />
    <meta name="application-name" content="Institut Teknologi dan Bisnis Banten | Kuliah Karyawan (K2)" />

    <link rel="apple-touch-icon" sizes="57x57" href="/images/favicons/apple-icon-57x57.png">
    <link rel="apple-touch-icon" sizes="60x60" href="/images/favicons/apple-icon-60x60.png">
    <link rel="apple-touch-icon" sizes="72x72" href="/images/favicons/apple-icon-72x72.png">
    <link rel="apple-touch-icon" sizes="76x76" href="/images/favicons/apple-icon-76x76.png">
    <link rel="apple-touch-icon" sizes="114x114" href="/images/favicons/apple-icon-114x114.png">
    <link rel="apple-touch-icon" sizes="120x120" href="/images/favicons/apple-icon-120x120.png">
    <link rel="apple-touch-icon" sizes="144x144" href="/images/favicons/apple-icon-144x144.png">
    <link rel="apple-touch-icon" sizes="152x152" href="/images/favicons/apple-icon-152x152.png">
    <link rel="apple-touch-icon" sizes="180x180" href="/images/favicons/apple-icon-180x180.png">
    <link rel="icon" type="image/png" sizes="192x192"  href="/images/favicons/android-icon-192x192.png">
    <link rel="icon" type="image/png" sizes="32x32" href="/images/favicons/favicon-32x32.png">
    <link rel="icon" type="image/png" sizes="96x96" href="/images/favicons/favicon-96x96.png">
    <link rel="icon" type="image/png" sizes="16x16" href="/images/favicons/favicon-16x16.png">
    <link rel="manifest" href="/images/favicons/manifest.json">
    <meta name="msapplication-TileColor" content="#ffffff">
    <meta name="msapplication-TileImage" content="/images/favicons/ms-icon-144x144.png">
    <meta name="theme-color" content="#ffffff">
    

    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.css" rel="stylesheet" />
    <link href="https://fonts.googleapis.com/css2?family=Poppins:wght@400;600&family=DM+Sans:wght@400;700&display=swap"
        rel="stylesheet">
    <link href="./css/app.css" rel="stylesheet">
    <link href="<?php echo e(asset('css/app.css')); ?>" rel="stylesheet">
    
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.css" />
    
    <link href="https://cdn.jsdelivr.net/npm/aos@2.3.4/dist/aos.css" rel="stylesheet">
    
    <?php echo $__env->yieldPushContent('prpend-style'); ?>
    <?php echo $__env->yieldPushContent('addon-style'); ?>

</head>

<body>

    
    <?php echo $__env->make('Frontend.Template.navbar', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>

    
    <div class="h-auto flex flex-col items-center justify-center md:gap-x-[100px] py-8 py-[100px] px-4 md:px-0 bg-cover bg-no-repeat bg-right md:bg-center-top"
        style="background-image: url('<?php echo e(asset('./images/background/bg-blue.png')); ?>');">
        <?php echo $__env->yieldContent('content'); ?>
    </div>

    <div class="fixed flex-row items-center bottom-4 right-4 z-50 md:bottom-10 md:right-10 flex ">
        <!-- Animated WhatsApp Button -->
        <div
            class="slide-text whatsapp-button overflow-hidden transition-all duration-500 ease-in-out bg-[#40C351] h-[40px] py-2 px-4 font-poppins text-white rounded-full mb-2">
            <h1 class="whatsapp-button-text ">ingin bertanya ? yuk di click !</h1>
        </div>

        <!-- WhatsApp Icon -->
        <a href="https://wa.me/6287890198284?text=Halo%20Admin%2C%20saya%20mau%20bertanya%20%0ASumber%20%3A%20<?php echo e(url()->current()); ?>"
            target="_blank" rel="noopener noreferrer">
            <img src="<?php echo e(asset('images/logo/wa.jpg')); ?>" alt="WhatsApp" class="w-12 h-12 md:w-[70px] md:h-[70px]">
        </a>
    </div>

    
    <?php echo $__env->make('Frontend.Template.footer', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>



    
    <?php echo $__env->yieldPushContent('prpend-script'); ?>
    <?php echo $__env->yieldPushContent('addon-script'); ?>



    
    <script src="https://www.google.com/recaptcha/api.js"></script>
    
    <script src="https://cdn.jsdelivr.net/npm/aos@2.3.4/dist/aos.js"></script>
    
    <script src="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.js"></script>
    <script src="./js/app.js"></script>
    <script src="<?php echo e(asset('./js/app.js')); ?>"></script>
<script>
    // Script untuk membuka popup
    const openPopup = document.getElementById('openPopup'); // Tombol "Daftar Sekarang"
    const popup = document.getElementById('popup'); // Popup elemen

    openPopup.addEventListener('click', () => {
        popup.style.display = 'flex'; // Tampilkan popup
    });

    // Script untuk menutup popup
    const closePopup = document.getElementById('closePopup'); // Tombol "Tutup"
    closePopup.addEventListener('click', () => {
        popup.style.display = 'none'; // Sembunyikan popup
    });

    // Verifikasi reCAPTCHA
    let isRecaptchaVerified = false;

    function verifyRecaptcha() {
        isRecaptchaVerified = true; // Tandai reCAPTCHA sebagai diverifikasi
        document.querySelector('.open-btn').disabled = false; // Aktifkan tombol "Daftar"
    }

    // Event listener untuk tombol "Daftar"
    document.querySelector('.open-btn').addEventListener('click', (e) => {
        if (!isRecaptchaVerified) {
            e.preventDefault(); // Blokir pengiriman jika reCAPTCHA belum diverifikasi
            alert('Silahkan centang reCAPTCHA terlebih dahulu!');
            return;
        }

        alert('Form berhasil dikirim!');
        // Tambahkan logika submit form Anda di sini
    });
</script>
</body>

</html>
<?php /**PATH D:\2025-ITBBANTEN\resources\views/Frontend/Layouts/app2.blade.php ENDPATH**/ ?>