<?php $__env->startSection('content'); ?>
    <?php if (isset($component)) { $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\HeaderSectionPage::class, ['title' => 'Visi Misi Universitas Islam Depok','breadcrumbHome' => 'Home','breadcrumbCurrent' => 'Visi Misi']); ?>
<?php $component->withName('header-section-page'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df)): ?>
<?php $component = $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df; ?>
<?php unset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df); ?>
<?php endif; ?>

    <!-- Content Section -->
    <div class=" py-10 ">
        <div data-aos="fade-up" class="container mx-auto px-4 lg:px-16 space-y-12">
            <!-- Visi -->
            <div data-aos="fade-up" class="bg-white shadow-xl shadow rounded-lg p-6">
                <h2 data-aos="fade-up" class="text-xl font-poppins font-semibold text-primary mb-3">Visi</h2>
                <p data-aos="fade-up" class="text-gray-700 font-dmsans">
                Pada tahun 2030 menjadi Perguruan Tinggi Agama islam yang menyelenggarakan program Sarjana dan Pascasarjana, yang unggul dan terdepan dalam penyelenggaraan tri dharma perguruan tinggi untuk menghasilkan lulusan yang cerdas dan berakhlak mulia serta berwawasan keumatan dan benagsaan.
                </p>
            </div>

            <!-- Misi -->
            <div data-aos="fade-up" class="bg-white shadow-xl shadow rounded-lg p-6">
                <h2 data-aos="fade-up" class="text-xl font-poppins font-semibold text-primary mb-3">Misi</h2>
                <ul data-aos="fade-up" class="list-disc pl-5 space-y-3 text-gray-700 font-dmsans">
                    <li>
                    Menyelenggarakan pendidikan untuk menghasilkan lulusan yang memiliki kemampuan akademik dan/atau profesional di bidang ilmu agama islam yang mampu mengembangkan serta menerapkannya dalam kehidupan sehari-hari.
                    </li>
                    <li>
                    Menyelenggarakan pendidikan untuk menghasilkan lulusan yang berakhlak mulia, memiliki semangat kemandirian dan kewirausahaan, keumatan dan kebangsaan, sehingga berpotensi menjadi pemimpin umat dan bangsa.
                    </li>
                    <li>
                    Melakukan penelitian guna menghasilkan temuan-temuan baru di bidang ilmu agama islam, baik penelitian teks, maupun penelitian konteks.
                    </li>
                    <li>
                    Mengembangkan dan menyebarkan ilmu agama islam, sehingga menjadi refrensi bagi masyarakat yang akan mempelajarinya.
                    </li>
                </ul>
            </div>

            <!-- Call to Action -->
            <div data-aos="fade-up" class="text-center shadow-xl">
                <div data-aos="fade-up" class="bg-accent py-8 rounded-lg">
                    <h2 data-aos="fade-up" class="text-xl font-poppins font-bold text-white mb-3">Bergabunglah bersama Universitas Islam Depok dan wujudkan masa depan cerah
                    </h2>
                    <p data-aos="fade-up" class="text-white font-dmsans mb-5">Dengan pendidikan berkualitas, dosen berpengalaman, dan fasilitas modern, kami mendukung setiap langkah Anda menuju kesuksesan.</p>
                    <a href="/pendaftaran" data-aos="fade-up"
                        class="bg-white text-primary font-poppins font-medium py-2 px-6 rounded-full shadow-md hover:bg-gray-100 transition">
                        Daftar Sekarang
                    </a>
                </div>
            </div>
        </div>
    </div>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('Frontend.Layouts.app2', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH D:\web-kampus-main\resources\views/Frontend/visimisi.blade.php ENDPATH**/ ?>