<?php

namespace Faker\Provider\el_CY;

class Person extends \Faker\Provider\Person
{
    /**
     * @var array
     *
     * @see http://www.mof.gov.cy/mof/cystat/statistics.nsf/populationcondition_22main_gr/populationcondition_22main_gr?OpenForm&sub=2&sel=2
     */
    protected static $firstNameMale = [
        'Άγγελος', 'Άδωνης', 'Άκης', 'Άνθιμος', 'Άρης',
        'Έκτορας',
        'Αβραάμ', 'Αγάπιος', 'Αγαθοκλής', 'Αδαμάντιος', 'Αθανάσιος', 'Αιμίλιος', 'Αλέκος', 'Αλέξανδρος', 'Αλέξης', 'Αλκιβιάδης', 'Αναστάσιος', 'Ανδρέας', 'Ανδρόνικος', 'Ανθούλης', 'Αντώνης', 'Απόστολος', 'Αρέστης', 'Αργύρης', 'Αριστείδης', 'Αριστόδημος', 'Αυγουστής', 'Αυξέντης', 'Αχιλλέας',
        'Βίκτωρας', 'Βαλεντίνος', 'Βαρνάβας', 'Βασίλης', 'Βλαδίμηρος', 'Βρυώνης',
        'Γαβριήλ', 'Γεννάδιος', 'Γεράσιμος', 'Γιάγκος', 'Γιώργος', 'Γλαύκος', 'Γρηγόρης',
        'Δαμιανός', 'Δανιήλ', 'Δημήτρης', 'Δημοσθένης', 'Διομήδης', 'Διονύσης', 'Δώρος',
        'Ειρηναίος', 'Εμανουήλ', 'Ερρίκος', 'Ερωτόκριτος', 'Ευάγγελος', 'Ευαγόρας', 'Ευγένιος', 'Ευθύμιος', 'Ευριπίδης', 'Ευστάθιος', 'Ευτύχιος', 'Εφραίμ',
        'Ζήνωνας', 'Ζαχαρίας',
        'Ηλίας', 'Ηράκλης', 'Ηρόδοτος',
        'Θεμιστοκλής', 'Θεοδόσης', 'Θεοφάνης', 'Θεοχάρης', 'Θεόδουλος', 'Θεόδωρος', 'Θεόφιλος', 'Θρασύβουλος', 'Θωμάς',
        'Ιάκωβος', 'Ιάκωβος', 'Ιάσωνας', 'Ιορδάνης', 'Ιωάννης', 'Ιωακείμ', 'Ιωνάς', 'Ιωσήφ',
        'Κλεάνθης', 'Κλείτος', 'Κοσμάς', 'Κυριάκος', 'Κύπρος', 'Κώστας',
        'Λάζαρος', 'Λάκης', 'Λάμπρος', 'Λέανδρος', 'Λευτέρης', 'Λεωνίδας', 'Λεόντιος', 'Λεύκιος', 'Λουκάς', 'Λοϊζος',
        'Μάκης', 'Μάμας', 'Μάξιμος', 'Μάριος', 'Μανώλης', 'Μαρίνος', 'Ματθαίος', 'Μενέλαος', 'Μηνάς', 'Μιλτιάδης', 'Μιχάλης', 'Μωυσής', 'Μόδεστος',
        'Νέστορας', 'Νεκτάριος', 'Νεοκλής', 'Νεόφυτος', 'Νικήτας', 'Νικόλας', 'Ντένης', 'Ντίνος',
        'Ξάνθος', 'Ξένιος',
        'Οδυσσέας', 'Ονησιφόρος', 'Ορέστης',
        'Πάρης', 'Πέτρος', 'Παναγιώτης', 'Παντελής', 'Παρασκευάς', 'Πασχάλης', 'Παύλος', 'Περικλής', 'Πιερής', 'Πολύβιος', 'Πολύδωρος', 'Πολύκαρπος', 'Προκόπης', 'Πρόδρομος',
        'Ρένος', 'Ραφαήλ', 'Ρολάνδος',
        'Σάββας', 'Σέργιος', 'Σεβαστιανός', 'Σολωμός', 'Σοφοκλής', 'Σοφρώνης', 'Σπυρίδωνας', 'Στέφανος', 'Σταύρος', 'Στυλιανός', 'Συμεών', 'Σωκράτης', 'Σωτήρης', 'Σόλωνας',
        'Τηλέμαχος', 'Τιμόθεος', 'Τρύφωνας',
        'Φίλιππος', 'Φαίδωνας', 'Φειδίας', 'Φλώρος', 'Φοίβος', 'Φρίξος', 'Φώτης',
        'Χαράλαμπος', 'Χαρίλαος', 'Χρίστος', 'Χριστοφής', 'Χριστόδουλος', 'Χριστόφορος', 'Χρυσήλιος', 'Χρυσόστομος', 'Χρύσανθος',
        'Όμηρος',
    ];

    /**
     * @var array
     *
     * @see http://www.mof.gov.cy/mof/cystat/statistics.nsf/populationcondition_22main_gr/populationcondition_22main_gr?OpenForm&sub=2&sel=2
     */
    protected static $firstNameFemale = [
        'Ελση',
        'Άλκηστις', 'Άννα', 'Άννα Μαρία', 'Έφη', 'Ήβη', 'Αίγλη', 'Αίμιλη', 'Αγάθη', 'Αγάπη', 'Αγγέλα', 'Αγλαϊα', 'Αγνή', 'Αδαμάντια', 'Αθανασία', 'Αθηνά', 'Αλέξια', 'Αλίκη', 'Αλεξάνδρα', 'Αμαλία', 'Αναστασία', 'Ανδρομάχη', 'Ανδρονίκη', 'Ανδρούλα', 'Ανθή', 'Ανθούλα', 'Αννέτα', 'Αννίτα', 'Αντιγόνη', 'Αντωνία', 'Αποστολία', 'Αργυρώ', 'Αρετή', 'Αριάδνη', 'Αριστη', 'Αριστοτέλης', 'Αρτεμισία', 'Ασπασία', 'Αστέρω', 'Αυγή', 'Αυγούστα', 'Αφροδίτη',
        'Βέρα', 'Βίκη', 'Βαλέρια', 'Βαλεντίνα', 'Βανθούλα', 'Βαρβάρα', 'Βασιλική', 'Βερονίκη', 'Βικτώρια', 'Βιολέτα',
        'Γαβριέλα', 'Γαλάτεια', 'Γεωργία', 'Γεωργιάνα', 'Γιολάντα', 'Γιούλα', 'Γλυκερία', 'Γρηγόρια', 'Δάφνη',
        'Δέσποινα', 'Δήμητρα', 'Δήμος', 'Δανάη', 'Δημητριάνα', 'Διαμαντώ', 'Δώρα',
        'Εβελίνα', 'Ειρήνη', 'Ελένη', 'Ελίζα', 'Ελίνα', 'Ελεονώρα', 'Ελευθερία', 'Ελισάβετ', 'Ελλάδα', 'Ελπίδα', 'Ελπινίκη', 'Ερίκα', 'Ερασμία', 'Ερατώ', 'Ερμιόνη', 'Ευαγγελία', 'Ευανθία', 'Ευγενία', 'Ευδοκία', 'Ευθυμία', 'Ευρυδίκη', 'Ευσταθία', 'Ευτυχία', 'Ευφροσύνη', 'Εύα', 'Εύη',
        'Ζήνα', 'Ζαχαρούλα', 'Ζηνοβία', 'Ζωή',
        'Ηλέκτρα', 'Ηλιάδα', 'Ηλιάνα', 'Ηρώ',
        'Θάλεια', 'Θέκλα', 'Θέλμα', 'Θέμιδα', 'Θεά', 'Θεανώ', 'Θεογνωσία', 'Θεοδοσία', 'Θεοδώρα', 'Θεονίτσα', 'Θεοπίστη', 'Θεοφανώ',
        'Ιουλία', 'Ιρίνα', 'Ισαβέλα', 'Ισμήνη', 'Ιφιγένεια', 'Ιωάννα',
        'Κάλλια', 'Κίκα', 'Καλλισθένη', 'Καλλιόπη', 'Καρολίνα', 'Κατερίνα', 'Κλαίρη', 'Κλειώ', 'Κλεονίκη', 'Κλεοπάτρα', 'Κορίνα', 'Κορνήλια', 'Κυπρούλα', 'Κυριακή', 'Κωνσταντίνα',
        'Λάουρα', 'Λένα', 'Λένος', 'Λίλια', 'Λίνα', 'Λίτσα', 'Λαρίσα', 'Λευκή', 'Λητώ', 'Λουκία', 'Λουϊζα', 'Λυγία', 'Λύδια',
        'Μάγια', 'Μάρθα', 'Μάρκος', 'Μέλανη', 'Μίνα', 'Μαγδαληνή', 'Μαρία', 'Μαρίλια', 'Μαρίνα', 'Μαργαρίτα', 'Μαριάμ', 'Μαριάννα', 'Μαριλένα', 'Μαρκέλλα', 'Μελίνα', 'Μελπομένη', 'Μερόπη', 'Μηλίτσα', 'Μιράντα', 'Μιχαέλλα', 'Μυριάνθη', 'Μυροφόρα', 'Μυρτώ', 'Μόνικα', 'Μύρια',
        'Νάγια', 'Νάντια', 'Νάσια', 'Νάσω', 'Νάτια', 'Νέαρχος', 'Νίκη', 'Νίνα', 'Νίτσα', 'Νατάσα', 'Ναταλία', 'Ναυσικά', 'Νεκταρία', 'Νεοφύτα', 'Νεφέλη', 'Νικολέττα', 'Νιόβη', 'Ντίνα', 'Ντανιέλα', 'Νταϊανα',
        'Ξάνθη', 'Ξένια', 'Ξενοφών',
        'Ολίβια', 'Ολυμπιάδα', 'Ονούφριος', 'Ορθοδοξία', 'Ουρανία',
        'Παναγιώτα', 'Παντελίτσα', 'Παρασκευή', 'Παρθενόπη', 'Παυλίνα', 'Περσεφόνη', 'Πετρούλα', 'Πηνελόπη', 'Πολυξένη', 'Πωλίνα', 'Πόλα', 'Πόπη',
        'Ρέα', 'Ρίτα', 'Ραάνια', 'Ραφαέλα', 'Ρεββέκα', 'Ροδοθέα', 'Ροδούλα', 'Ρούλα',
        'Σάντρα', 'Σάρα', 'Σαββούλα', 'Σαλώμη', 'Σιμόνα', 'Σουζάνα', 'Σοφία', 'Σούλα', 'Σπυρούλα', 'Στάλω', 'Στέφανη', 'Σταυρούλα', 'Στυλιανή', 'Σωτηρούλα', 'Σόνια', 'Σύλβια',
        'Τάκης', 'Τάνια', 'Τίνα', 'Τατιάνα', 'Τερέζα', 'Τούλα', 'Τόνια',
        'Φαίδρα', 'Φιλιώ', 'Φλωρεντία', 'Φλώρα', 'Φοίβη', 'Φρειδερίκη', 'Φωτεινή',
        'Χαρίκλεια', 'Χαραλαμπία', 'Χαριτίνη', 'Χλόη', 'Χρίστια', 'Χριστίνα', 'Χριστιάνα', 'Χριστοδούλα', 'Χριστοθέα', 'Χριστούλα', 'Χρυσάνθη', 'Χρυσή', 'Χρυσοβαλάντω', 'Χρυσούλα', 'Χρυστάλλα', 'Χρυσταλλένη', 'Χρύσα', 'Χρύσω',
        'Όλγα',
    ];

    /**
     * @var array
     *
     * @see http://www.mof.gov.cy/mof/cystat/statistics.nsf/populationcondition_22main_gr/populationcondition_22main_gr?OpenForm&sub=2&sel=2
     */
    protected static $lastName = [
        'Άκη', 'Αγαθοκλέους', 'Αθανάσιου', 'Αλέκου', 'Αλεξάνδρου', 'Αλκιβιάδη', 'Αναστασίου', 'Ανδρέου', 'Ανδρονίκου', 'Αντωνίου', 'Αργύρη', 'Αριστείδη', 'Αριστοδήμου', 'Αυγουστή', 'Αυξεντίου', 'Αχιλλέα',
        'Βίκτωρα', 'Βαλεντίνου', 'Βαρνάβα', 'Βασίλη',
        'Γαβριήλ', 'Γεράσιμου', 'Γεωργίου', 'Γιάγκου', 'Γλαύκου', 'Γρηγορίου',
        'Δαμιανού', 'Δανιήλ', 'Δημητρίου', 'Δημοσθένους', 'Διομήδη', 'Διονυσίου',
        'Ερωτοκρίτου', 'Ευαγγέλου', 'Ευαγόρα', 'Ευγενίου', 'Ευθύμιου', 'Ευριπίδη', 'Ευστάθιου', 'Ευτύχιου',
        'Ζήνωνα', 'Ζαχαρία',
        'Ηλία', 'Ηρακλέους',
        'Θεμιστοκλέους', 'Θεοδούλου', 'Θεοδόση', 'Θεοδώρου', 'Θεοδώρου', 'Θεοφάνους', 'Θεοχάρους', 'Θεόφιλου', 'Θρασύβουλου', 'Θωμά',
        'Ιάσωνα', 'Ιακώβου', 'Ιορδάνου', 'Ιωάννη', 'Ιωακείμ', 'Ιωνά', 'Ιωσήφ',
        'Κλεάνθη', 'Κλείτου', 'Κοσμά', 'Κυριάκου', 'Κωνσταντίνου', 'Κύπρου', 'Κώστα',
        'Λάμπρου', 'Λεάνδρου', 'Λεοντίου', 'Λευτέρη', 'Λεωνίδα', 'Λουκά', 'Λοϊζου',
        'Μάμα', 'Μανώλη', 'Μαρίνου', 'Μιλτιάδη', 'Μιχαήλ', 'Μωυσέως',
        'Νεκτάριου', 'Νεοκλέους', 'Νεοφύτου', 'Νικήτα', 'Νικολάου',
        'Ομήρου', 'Ορέστη',
        'Πάρη', 'Πέτρου', 'Παναγιώτη', 'Παντελής', 'Παρασκευά', 'Πασχάλη', 'Παύλου', 'Περικλέους', 'Πιερή', 'Πολύβιου', 'Πολύδωρου', 'Πολύκαρπου', 'Προδρόμου', 'Προκόπη',
        'Ραφαήλ',
        'Σάββα', 'Σολωμός', 'Σοφοκλέους', 'Σοφρωνίου', 'Σπυρίδωνος', 'Στέφανου', 'Σταύρου', 'Στυλιανού', 'Συμεών', 'Σωκράτη', 'Σωτηρίου', 'Σόλωνα',
        'Τηλεμάχου', 'Τιμοθέου', 'Τρύφωνος',
        'Φίλιππου', 'Φαίδωνος', 'Φειδία', 'Φοίβου', 'Φώτη',
        'Χαραλάμπους', 'Χαριλάου', 'Χρίστου', 'Χριστοδούλου', 'Χριστοφή', 'Χριστοφόρου', 'Χρυσόστομος', 'Χρύσανθου',
    ];

    protected static $titleMale = ['κος.', 'κ.'];
    protected static $titleFemale = ['δις.', 'δνις.', 'κα.'];
}
