@section('title', 'VisiMisi')

@extends('Frontend.Layouts.app2')
@section('content')
    <x-header-section-page title="Visi Misi STISIP IMAM BONJOL" breadcrumb-home="Home" breadcrumb-current="Visi Misi" />

    <!-- Content Section -->
    <div class=" py-10 ">
        <div data-aos="fade-up" class="container mx-auto px-4 lg:px-16 space-y-12">
            <!-- Visi -->
            <div data-aos="fade-up" class="bg-white shadow-xl shadow rounded-lg p-6">
                <h2 data-aos="fade-up" class="text-xl font-poppins font-semibold text-primary mb-3">Visi</h2>
                <p data-aos="fade-up" class="text-gray-700 font-dmsans">
                “Menjadi Sekolah Tinggi unggul dan terpercaya di bidang ilmu sosial dan ilmu politik yang mengedepankan nilai-nilai kearifan lokal, berwawasan global dan berbasis perkembangan sistem informasi, komunikasi dan teknologi di Sumatera Barat pada tahun 2033”
                </p>
            </div>

            <!-- Misi -->
            <div data-aos="fade-up" class="bg-white shadow-xl shadow rounded-lg p-6">
                <h2 data-aos="fade-up" class="text-xl font-poppins font-semibold text-primary mb-3">Misi</h2>
                <ul data-aos="fade-up" class="list-disc pl-5 space-y-3 text-gray-700 font-dmsans">
                <li>
                Menyelenggarakan kegiatan pendidikan dan pengajaran yang berkualitas dan mampu mendorong pengembangan pola pikir inovatif, kreatif serta berdaya saing dibidang Ilmu Sosial dan Ilmu Politik
                </li>
                <li>
                Melaksanakan penelitian yang berkualitas dalam pengembangan Ilmu Sosial dan Ilmu Politik dengan mengedepankan nilai-nilai kearifan lokal dan dinamika global.
                </li>
                 <li>
                 Melaksanakan pengabdian yang bermutu dan berkontribusi terhadap pemecahan masalah-masalah sosial dan politik di masyarakat sebagai sarana aktualisasi ilmu.
                </li>
                <li>
                Menyelenggarakan tata kelola sekolah tinggi yang efektif dan efisien (good governance university) untuk menudung pelaksanaan kegiatan Tri Dharma Perguruan Tinggi
                </li>
                <li>
                Membangun kerjasama dengan berbagai stakeholder dalam bidang pendidikan, penelitian dan pengabdian masyarakat ditingkat lokal dan nasional secara efektif, efisien dan berkesinambungan untuk pengembangan dan keberlangsungan pendidikan
                </li>
                
               
                </ul>
            </div>

            <!-- Call to Action -->
            <div data-aos="fade-up" class="text-center shadow-xl">
                <div data-aos="fade-up" class="bg-accent py-8 rounded-lg" style="color:#fff">
                    <h2 data-aos="fade-up" class="text-xl font-poppins font-bold  mb-3">Bergabunglah dengan STISIP IMAM BONJOL
                    </h2>
                    <p data-aos="fade-up" class=" font-dmsans mb-5">Wujudkan impianmu dan raih masa depan cerah bersama STISIP IMAM BONJOL!.</p>
                    <a href="/pendaftaran" data-aos="fade-up"
                        class="bg-white text-primary font-poppins font-medium py-2 px-6 rounded-full shadow-md hover:bg-gray-100 transition">
                        Daftar Sekarang
                    </a>
                </div>
            </div>
        </div>
    </div>
@endsection
