<nav class="navbar">
    <a href="#" class="sidebar-toggler">
        <i data-feather="menu"></i>
    </a>
    <div class="navbar-content">
        <form class="search-form">
            <div class="input-group">
                <div class="input-group-text">
                    <i data-feather="search"></i>
                </div>
                <input type="text" class="form-control" id="navbarForm" placeholder="Search here...">
            </div>
        </form>
        <ul class="navbar-nav">
            

            <li class="nav-item dropdown">
                <a class="nav-link dropdown-toggle" href="#" id="profileDropdown" role="button"
                    data-bs-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                    <img class="ht-auto rounded-circle" width="30" height="30"
                        src="<?php echo e(Auth::user()->gambar ? asset('storage/userImage/' . Auth::user()->gambar) : asset('assets/user/profil.jpg')); ?>"
                        alt="profile">
                </a>
                <div class="dropdown-menu p-0" aria-labelledby="profileDropdown">
                    <div class="d-flex flex-column align-items-center border-bottom px-5 py-3">
                        <div class="mb-3">
                            <img class="rounded-circle" width="80" height="80"
                                src="<?php echo e(Auth::user()->gambar ? asset('storage/userImage/' . Auth::user()->gambar) : asset('assets/user/profil.jpg')); ?>"
                                alt="">
                        </div>
                        <div class="text-center">
                            <p class="tx-16 fw-bolder"><?php echo e(Auth::user()->name); ?></p>
                            <p class="tx-12 text-muted"><?php echo e(Auth::user()->email); ?></p>
                        </div>
                    </div>
                    <ul class="list-unstyled p-1">
                        <li class="dropdown-item py-2 <?php echo e(request()->routeIs('profile') ? 'bg-primary' : ''); ?>"
                            onclick="window.location.href='<?php echo e(route('profile')); ?>'" style="cursor: pointer;">
                            <a href="<?php echo e(route('profile')); ?>" class="text-body ms-0 text-white">
                                <i class="me-2 icon-md" data-feather="user"></i>
                                <span>Profile</span>
                            </a>
                        </li>

                        <li class="dropdown-item py-2 <?php echo e(request()->routeIs('changePassword') ? 'bg-primary' : ''); ?>"
                            onclick="window.location.href='<?php echo e(route('changePassword')); ?>'" style="cursor: pointer;">
                            <a href="<?php echo e(route('changePassword')); ?>" class="text-body ms-0 text-white">
                                <i class="me-2 icon-md" data-feather="user"></i>
                                <span>Change Password</span>
                            </a>
                        </li>

                        <li class="dropdown-item py-2"
                            onclick="event.preventDefault(); this.querySelector('form').submit();"
                            style="cursor: pointer;">
                            <form method="POST" action="<?php echo e(route('logout')); ?>" style="display: inline;">
                                <?php echo csrf_field(); ?>
                                <a href="#" class="text-body ms-0" onclick="event.preventDefault();">
                                    <i class="me-2 icon-md" data-feather="log-out"></i>
                                    <span>Log Out</span>
                                </a>
                            </form>
                        </li>
                    </ul>
                </div>
            </li>
        </ul>
    </div>
</nav>
<?php /**PATH D:\2025_STIMIK-PGR_ARUNGBINANG\resources\views/dashboard/header.blade.php ENDPATH**/ ?>