<!DOCTYPE html>
<html lang="id">

<head>
    <meta charset="utf-8">
    <meta name="description" content="STIKES Pembina Palembang adalah pilihan tepat bagi Anda yang ingin berkarier di bidang kesehatan. Kami menawarkan program studi S1 Kesehatan Masyarakat, D3 Kebidanan, D3 Keperawatan dengan kurikulum berbasis kompetensi dan tenaga pengajar profesional. Biaya kuliah terjangkau dengan opsi cicilan mulai dari Rp450.000 per bulan, memudahkan Anda meraih pendidikan berkualitas tanpa beban finansial. Segera bergabung dan wujudkan masa depan cerah di dunia kesehatan bersama STIKES Pembina Palembang." />
    <meta name="keywords" content="edunitas, Kelas karyawan, Kuliah karyawan, STIKES Pembina Palembang, kampus STIKES Pembina Palembang , biaya kuliah kampus STIKES Pembina , biaya kuliah, kelas sabtu, akreditasi STIKES Pembina, kelas karyawan terjangkau Palembang , S1 Kesehatan Masyarakat, D3 Kebidanan, dan D3 Keperawatan, kampus murah, kampus Di Palembang , kampus Di Palembang , STIKES Pembina, biaya kuliah, kelas sabtu, akreditasi STIKES Pembina Palembang ,
     Kampus Kelas Karyawan Di Palembang , Kuliah Sambil Kerja Di Palembang , Universitas Terbaik di Palembang  untuk Karyawan, Biaya Kuliah Terjangkau di Palembang , Universitas Kelas Sabtu Minggu Di Palembang , Akreditasi Universitas Di Palembang ,Perguruan Tinggi Swasta Murah di Palembang , Program S1 Kesehatan Masyarakat, Program D3 Kebidanan, Program D3 Keperawatan ,  Kampus Swasta Terbaik Palembang , Universitas Murah  Di Palembang  terakreditasi Baik,
     Kampus Terjangkau di Palembang  untuk Karyawan, , Kuliah dengan Biaya Mulai 450 Ribu di Palembang  , Universitas dengan Kelas Online Palembang , Kampus Swasta Kelas Sabtu Minggu di Palembang , Biaya Kuliah  S1 Murah di Palembang , Biaya Kuliah  S1 Murah di Palembang , Kampus dengan Program Studi Lengkap di Palembang , Kampus dengan Program Studi Lengkap di Palembang " />
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
    
    <title><?php echo $__env->yieldContent('title'); ?> &mdash; STIKES Pembina Palembang (Kelas Karyawan)</title>
    <meta property="og:title" content="STIKES Pembina Palembang (Kelas Karyawan)">
    <meta property="og:type" content="website">
    <meta property="og:url" content="STIKES Pembina Palembang (Kelas Karyawan)">
    <meta property="og:image" content="https://stikespembina.info/images/background/hero1.png">
    <meta property="og:image:width" content="1200" />
    <meta property="og:image:height" content="630" />
    <meta property="og:description" content="STIKES Pembina Palembang membuka pendaftaran untuk S1 Kesehatan Masyarakat, D3 Kebidanan, dan D3 Keperawatan dengan biaya terjangkau. Cicilan mulai Rp450.000/bulan. Daftar sekarang untuk masa depan cerah di bidang kesehatan!!.">
    <meta name="twitter:card" content="summary_large_image">
    <meta name="twitter:creator" content="@_kuliahkaryawan">
    <meta name="twitter:site" content="@_kuliahkaryawan">
    <meta name="twitter:title" content="STIKES Pembina Palembang (Kelas Karyawan) (Kelas Karyawan)">
    <meta name="twitter:description" content="STIKES Pembina Palembang membuka kelas karyawan untuk S1 Kesehatan Masyarakat, D3 Kebidanan, dan D3 Keperawatan. Kuliah fleksibel tanpa mengganggu pekerjaan, dengan biaya terjangkau dan cicilan mulai Rp450.000 per bulan. Wujudkan karier di dunia kesehatan sekarang.">
    <meta name="twitter:domain" content="stikespembina.info">
    <meta name="twitter:image:src" content="https://stikespembina.info/images/background/hero1.png">
    <meta name="author" content="Kuliah Karyawan Team" />
    <meta http-equiv="cache-control" content="public" />
    <meta name="application-name" content="STIKES Pembina Palembang | Kuliah Karyawan (K2)" />

    <link rel="apple-touch-icon" sizes="57x57" href="/images/favicons/apple-icon-57x57.png">
    <link rel="apple-touch-icon" sizes="60x60" href="/images/favicons/apple-icon-60x60.png">
    <link rel="apple-touch-icon" sizes="72x72" href="/images/favicons/apple-icon-72x72.png">
    <link rel="apple-touch-icon" sizes="76x76" href="/images/favicons/apple-icon-76x76.png">
    <link rel="apple-touch-icon" sizes="114x114" href="/images/favicons/apple-icon-114x114.png">
    <link rel="apple-touch-icon" sizes="120x120" href="/images/favicons/apple-icon-120x120.png">
    <link rel="apple-touch-icon" sizes="144x144" href="/images/favicons/apple-icon-144x144.png">
    <link rel="apple-touch-icon" sizes="152x152" href="/images/favicons/apple-icon-152x152.png">
    <link rel="apple-touch-icon" sizes="180x180" href="/images/favicons/apple-icon-180x180.png">
    <link rel="icon" type="image/png" sizes="192x192"  href="/images/favicons/android-icon-192x192.png">
    <link rel="icon" type="image/png" sizes="32x32" href="/images/favicons/favicon-32x32.png">
    <link rel="icon" type="image/png" sizes="96x96" href="/images/favicons/favicon-96x96.png">
    <link rel="icon" type="image/png" sizes="16x16" href="/images/favicons/favicon-16x16.png">
    <link rel="manifest" href="/images/favicons/manifest.json">
    <meta name="msapplication-TileColor" content="#ffffff">
    <meta name="msapplication-TileImage" content="/images/favicons/ms-icon-144x144.png">
    <meta name="theme-color" content="#ffffff">


    <link href="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.css" rel="stylesheet" />
    <link href="https://fonts.googleapis.com/css2?family=Poppins:wght@400;600&family=DM+Sans:wght@400;700&display=swap"
        rel="stylesheet">
    <link href="./css/app.css" rel="stylesheet">
    
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.css" />
    
    <link href="https://cdn.jsdelivr.net/npm/aos@2.3.4/dist/aos.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.2/css/all.min.css">

    
    <?php echo $__env->yieldPushContent('prpend-style'); ?>
    <?php echo $__env->yieldPushContent('addon-style'); ?>

</head>

<body>

    
    <?php echo $__env->make('Frontend.Template.navbar', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>

    
    <?php echo $__env->yieldContent('content'); ?>
    <div class="fixed flex-row items-center bottom-4 right-4 z-50 md:bottom-10 md:right-10 flex ">
        <!-- Animated WhatsApp Button -->
        <div style="color:#fff;"
            class="slide-text whatsapp-button overflow-hidden shadow-2xl transition-all duration-500 ease-in-out bg-[#40C351] h-[40px] py-2 px-4 font-poppins text-white rounded-full mb-2">
            <h1 class="whatsapp-button-text ">ingin bertanya ? yuk di click !</h1>
        </div>

        <!-- WhatsApp Icon -->
        <a href="https://wa.me/6289504586704?text=Halo%20Admin%2C%20saya%20mau%20bertanya%20%0ASumber%20%3A%20<?php echo e(url()->current()); ?>" 
            target="_blank" rel="noopener noreferrer">
            <img src="<?php echo e(asset('images/logo/wa.jpg')); ?>" alt="WhatsApp" class="w-12 h-12 md:w-[70px] md:h-[70px]" >
        </a>

    </div>

    
    <?php echo $__env->make('Frontend.Template.footer', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>

    
    <?php echo $__env->yieldPushContent('prpend-script'); ?>
    <?php echo $__env->yieldPushContent('addon-script'); ?>
    </script>
    
    <script src="https://cdn.jsdelivr.net/npm/aos@2.3.4/dist/aos.js"></script>
    
    <script src="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.js"></script>
    <script src="./js/app.js"></script>
    <!-- disabled -->
  <script> document.addEventListener('contextmenu', function(event) { event.preventDefault(); alert('Right Click Disabled.'); }); </script>
</body>

</html>
<?php /**PATH D:\2025-STIKES-PEMBINA\resources\views/Frontend/Layouts/app.blade.php ENDPATH**/ ?>