<!DOCTYPE html>
<html lang="id">

<head>
<meta charset="utf-8">
    <meta charset="utf-8">
    <meta name="description" content="STMIK PGRI ARUNGBINANG, perguruan tinggi swasta unggulan di Kebumen, memberikan kemudahan bagi Anda yang ingin melanjutkan studi di tengah kesibukan. Kampus ini menyediakan program D3 Manajemen Informatika dan S1 Teknologi Informasi, dengan kelas karyawan yang fleksibel dan biaya yang terjangkau, mulai dari Rp 400.000/bulan. Dengan fasilitas modern dan dosen berkualitas, STMIK PGRI ARUNGBINANG berkomitmen mendukung kesuksesan Anda di era digital." />
    <meta name="keywords" content="Universita Sebelas Marat, UNS, Universitas Diponegoro, UNDIP, Universitas Negeri Semarang, UNES, Kelas karyawan, Kuliah karyawan, STMIK PGRI ARUNGBINANG, kampus STMIK PGRI ARUNGBINANG kebumen, biaya kuliah kampus STMIK PGRI ARUNGBINANG kebumen, biaya kuliah, kelas sabtu, akreditasi STMIK PGRI ARUNGBINANG kebumen, kelas karyawan terjangkau Kebumen, D3 Manajemen Informatika, S1 Teknologi Informasi, kampus murah, kampus Kebumen, STMIK PGRI ARUNGBINANG, biaya kuliah, kelas sabtu, akreditasi STMIK PGRI ARUNGBINANG Kebumen,
     Kampus Kelas Karyawan Kebumen, Kuliah Sambil Kerja Kebumen, Universitas Terbaik Kebumen untuk Karyawan, Biaya Kuliah Terjangkau di Kebumen, Universitas Kelas Sabtu Kebumen, Akreditasi Universitas Kebumen, Perguruan Tinggi Swasta Kebumen Murah, Program D3 Manajemen Informatika, Kuliah S1 Teknologi Informasi Kebumen , Kampus Swasta Terbaik Kebumen, Universitas Murah Kebumen dengan Akreditasi Baik,
     Kampus Terjangkau Kebumen untuk Karyawan, Kuliah dengan Biaya Mulai 400 Ribu di Kebumen, Universitas dengan Kelas Online Kebumen, Kampus Swasta Kelas Sabtu Minggu Kebumen, Biaya Kuliah D3 dan S1 Murah di Kebumen, Kampus dengan Program Studi Lengkap Kebumen" />
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
    
    <title>STMIK PGRI ARUNGBINANG (Kelas Karyawan)</title>
    <meta property="og:title" content="STMIK PGRI ARUNGBINANG (Kelas Karyawan)">
    <meta property="og:type" content="website">
    <meta property="og:url" content="stmikpgri-arungbinang.info">
    <meta property="og:image" content="https://stmikpgri-arungbinang.info//images/banner-slider/Banner-stmikpgri-arungbinang.png">
    <meta property="og:image:width" content="1200" />
    <meta property="og:image:height" content="630" />
    <meta property="og:description" content="STMIK PGRI ARUNGBINANG adalah perguruan tinggi swasta terkemuka di Kebumen yang berfokus pada pengembangan pendidikan di bidang teknologi dan informatika. Dengan pilihan program studi D3 Manajemen Informatika dan S1 Teknologi Informasi, kampus ini dirancang untuk mencetak lulusan yang kompeten dan siap bersaing di era digital.STMIK PGRI ARUNGBINANG menawarkan program kelas karyawan dengan biaya terjangkau, mulai dari Rp 400.000 per bulan, sehingga memungkinkan para profesional untuk melanjutkan pendidikan tanpa mengganggu aktivitas pekerjaan. Didukung oleh fasilitas modern, lingkungan belajar yang kondusif, dan tenaga pengajar berpengalaman, STMIK PGRI ARUNGBINANG menjadi pilihan strategis untuk meningkatkan kompetensi dan membangun karir di dunia teknologi.">
    <meta name="twitter:card" content="summary_large_image">
    <meta name="twitter:creator" content="@_kuliahkaryawan">
    <meta name="twitter:site" content="@_kuliahkaryawan">
    <meta name="twitter:title" content="STMIK PGRI ARUNGBINANG (Kelas Karyawan)">
    <meta name="twitter:description" content="Kelas Karyawan STMIK PGRI ARUNGBINANG adalah solusi ideal bagi Anda yang ingin melanjutkan pendidikan tinggi tanpa harus meninggalkan pekerjaan. Program ini dirancang khusus untuk memberikan fleksibilitas waktu, sehingga Anda dapat menyeimbangkan antara studi dan aktivitas profesional. Dengan biaya yang terjangkau, mulai dari Rp 400.000 per bulan, Kelas Karyawan menawarkan kesempatan untuk mengikuti program studi unggulan seperti D3 Manajemen Informatika dan S1 Teknologi Informasi. Kurikulum yang disusun relevan dengan kebutuhan industri, didukung oleh dosen berpengalaman dan fasilitas modern, memastikan Anda mendapatkan pendidikan berkualitas yang mendukung perkembangan karir.">
    <meta name="twitter:domain" content="stmikpgri-arungbinang.info">
    <meta name="twitter:image:src" content="https://stmikpgri-arungbinang.info//images/banner-slider/Banner-stmikpgri-arungbinang.png">
    <meta name="author" content="Kuliah Karyawan Team" />
    <meta http-equiv="cache-control" content="public" />
    <meta name="application-name" content="STMIK PGRI ARUNGBINANG | Kuliah Karyawan (K2)" />

    <link rel="apple-touch-icon" sizes="57x57" href="/images/favicons/apple-icon-57x57.png">
    <link rel="apple-touch-icon" sizes="60x60" href="/images/favicons/apple-icon-60x60.png">
    <link rel="apple-touch-icon" sizes="72x72" href="/images/favicons/apple-icon-72x72.png">
    <link rel="apple-touch-icon" sizes="76x76" href="/images/favicons/apple-icon-76x76.png">
    <link rel="apple-touch-icon" sizes="114x114" href="/images/favicons/apple-icon-114x114.png">
    <link rel="apple-touch-icon" sizes="120x120" href="/images/favicons/apple-icon-120x120.png">
    <link rel="apple-touch-icon" sizes="144x144" href="/images/favicons/apple-icon-144x144.png">
    <link rel="apple-touch-icon" sizes="152x152" href="/images/favicons/apple-icon-152x152.png">
    <link rel="apple-touch-icon" sizes="180x180" href="/images/favicons/apple-icon-180x180.png">
    <link rel="icon" type="image/png" sizes="192x192"  href="/images/favicons/android-icon-192x192.png">
    <link rel="icon" type="image/png" sizes="32x32" href="/images/favicons/favicon-32x32.png">
    <link rel="icon" type="image/png" sizes="96x96" href="/images/favicons/favicon-96x96.png">
    <link rel="icon" type="image/png" sizes="16x16" href="/images/favicons/favicon-16x16.png">
    <link rel="manifest" href="/images/favicons/manifest.json">
    <meta name="msapplication-TileColor" content="#ffffff">
    <meta name="msapplication-TileImage" content="/images/favicons/ms-icon-144x144.png">
    <meta name="theme-color" content="#ffffff">
    

    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.css" rel="stylesheet" />
    <link href="https://fonts.googleapis.com/css2?family=Poppins:wght@400;600&family=DM+Sans:wght@400;700&display=swap"
        rel="stylesheet">
    <link href="./css/app.css" rel="stylesheet">
    <link href="<?php echo e(asset('css/app.css')); ?>" rel="stylesheet">
    
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.css" />
    
    <link href="https://cdn.jsdelivr.net/npm/aos@2.3.4/dist/aos.css" rel="stylesheet">
    
    <?php echo $__env->yieldPushContent('prpend-style'); ?>
    <?php echo $__env->yieldPushContent('addon-style'); ?>

</head>

<body>

    
    <?php echo $__env->make('Frontend.Template.navbar', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>

    
    <div class="h-auto flex flex-col items-center justify-center md:gap-x-[100px] py-8 py-[100px] px-4 md:px-0 bg-cover bg-no-repeat bg-right md:bg-center-top"
        style="background-image: url('<?php echo e(asset('./images/background/bg-grey.png')); ?>');">
        <?php echo $__env->yieldContent('content'); ?>
    </div>

    <div class="fixed flex-row items-center bottom-4 right-4 z-50 md:bottom-10 md:right-10 flex ">
        <!-- Animated WhatsApp Button -->
        <div
            class="slide-text whatsapp-button overflow-hidden transition-all duration-500 ease-in-out bg-[#40C351] h-[40px] py-2 px-4 font-poppins text-white rounded-full mb-2">
            <h1 class="whatsapp-button-text ">ingin bertanya ? yuk di click !</h1>
        </div>

        <!-- WhatsApp Icon -->
        <a href="https://wa.me/6287890198284?text=Halo%20Admin%2C%20saya%20mau%20bertanya%20%0ASumber%20%3A%20<?php echo e(url()->current()); ?>"
            target="_blank" rel="noopener noreferrer">
            <img src="<?php echo e(asset('images/logo/wa.jpg')); ?>" alt="WhatsApp" class="w-12 h-12 md:w-[70px] md:h-[70px]">
        </a>
    </div>

    
    <?php echo $__env->make('Frontend.Template.footer', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>



    
    <?php echo $__env->yieldPushContent('prpend-script'); ?>
    <?php echo $__env->yieldPushContent('addon-script'); ?>



    
    <script src="https://www.google.com/recaptcha/api.js"></script>
    
    <script src="https://cdn.jsdelivr.net/npm/aos@2.3.4/dist/aos.js"></script>
    
    <script src="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.js"></script>
    <script src="./js/app.js"></script>
    <script src="<?php echo e(asset('./js/app.js')); ?>"></script>
</body>

</html>
<?php /**PATH /home/u4591423/public_html/PUBLIC_DOMAIN/2025_STIMIK-PGR_ARUNGBINANG/resources/views/Frontend/Layouts/app2.blade.php ENDPATH**/ ?>