<!DOCTYPE html>
<html lang="id">

<head>
    <!-- Meta tags -->
    <meta name="description" content="STISIP Imam Bonjol Padang menawarkan program studi S1 Ilmu Administrasi Negara dan Ilmu Pemerintahan dengan biaya kuliah terjangkau sebesar Rp550.000 per bulan. Kampus ini menyediakan pendidikan berkualitas yang mempersiapkan mahasiswa untuk berkarir di sektor pemerintahan dan administrasi publik. Dengan fasilitas lengkap dan pengajaran yang berorientasi pada praktik, STISIP Imam Bonjol Padang menjadi pilihan tepat bagi mereka yang ingin mengembangkan keterampilan dalam manajemen pemerintahan dan kebijakan publik.">
    <meta name="keywords" content="edunitas, Kelas karyawan, Kuliah karyawan, STISIP Imam Bonjol Padang, kampus STISIP Imam Bonjol Padang , biaya kuliah kampus STISIP Imam Bonjol , biaya kuliah, kelas sabtu, akreditasi STISIP Imam Bonjol, kelas karyawan terjangkau Padang , S1 Ilmu Administrasi Negara, S1 Ilmu Pemerintahan, kampus murah Di Padang , kampus Di Padang , STISIP Imam Bonjol, biaya kuliah, kelas sabtu, akreditasi STISIP Imam Bonjol Padang ,
     Kampus Kelas Karyawan Di Padang , Kuliah Sambil Kerja Di Padang , Universitas Terbaik di Padang  untuk Karyawan, Biaya Kuliah Terjangkau di Padang , Universitas Kelas Sabtu Minggu Di Padang , Akreditasi Universitas Di Padang ,Perguruan Tinggi Swasta Murah di Padang , Program S1 Ilmu Administrasi Negara, Program S1 Ilmu Pemerintahan ,  Kampus Swasta Terbaik Padang , Universitas Murah  Di Padang  terakreditasi Baik,
     Kampus Terjangkau di Padang  untuk Karyawan, , Kuliah dengan Biaya Mulai 550 Ribu di Padang  , Universitas dengan Kelas Online Padang , Kampus Swasta Kelas Sabtu Minggu di Padang , Biaya Kuliah  S1 Murah di Padang , Biaya Kuliah  S1 Murah di Padang , Kampus dengan Program Studi Lengkap di Padang , Kampus dengan Program Studi Lengkap di Padang " />
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
    
    <title>@yield('title') &mdash; SEKOLAH TINGGI ILMU SOSIAL DAN POLITIK IMAM BONJOL PADANG (Kelas Karyawan)</title>
    <meta property="og:title" content="STISIP Imam Bonjol Padang (Kelas Karyawan)">
    <meta property="og:type" content="website">
    <meta property="og:url" content="STISIP Imam Bonjol Padang (Kelas Karyawan)">
    <meta property="og:image" content="https://stisipimambonjol.info/images/background/hero1.png">
    <meta property="og:image:width" content="1200" />
    <meta property="og:image:height" content="630" />
    <meta property="og:description" content="STISIP Imam Bonjol Padang menawarkan program S1 Ilmu Administrasi Negara dan Ilmu Pemerintahan dengan biaya kuliah terjangkau Rp550.000 per bulan. Kampus ini memberikan pendidikan berkualitas untuk mempersiapkan mahasiswa dalam karir di pemerintahan dan administrasi publik. Dengan pengajaran berbasis praktik dan fasilitas lengkap, STISIP Imam Bonjol Padang adalah pilihan ideal bagi yang ingin berkarir di sektor pemerintahan.">
    <meta name="twitter:card" content="summary_large_image">
    <meta name="twitter:creator" content="@_kuliahkaryawan">
    <meta name="twitter:site" content="@_kuliahkaryawan">
    <meta name="twitter:title" content="STISIP Imam Bonjol Padang (Kelas Karyawan) (Kelas Karyawan)">
    <meta name="twitter:description" content="STISIP Imam Bonjol Padang menawarkan program S1 Ilmu Administrasi Negara dan Ilmu Pemerintahan untuk kelas karyawan dengan biaya kuliah terjangkau Rp550.000 per bulan. Program ini dirancang untuk memberikan keterampilan di bidang pemerintahan dan administrasi publik, cocok bagi mereka yang bekerja sambil melanjutkan pendidikan.">
    <meta name="twitter:domain" content="stisipimambonjol.info">
    <meta name="twitter:image:src" content="https://stisipimambonjol.info/images/background/hero1.png">
    <meta name="author" content="Kuliah Karyawan Team" />
    <meta http-equiv="cache-control" content="public" />
    <meta name="application-name" content="STISIP Imam Bonjol Padang | Kuliah Karyawan (K2)" />

    <link rel="apple-touch-icon" sizes="57x57" href="/images/favicons/apple-icon-57x57.png">
    <link rel="apple-touch-icon" sizes="60x60" href="/images/favicons/apple-icon-60x60.png">
    <link rel="apple-touch-icon" sizes="72x72" href="/images/favicons/apple-icon-72x72.png">
    <link rel="apple-touch-icon" sizes="76x76" href="/images/favicons/apple-icon-76x76.png">
    <link rel="apple-touch-icon" sizes="114x114" href="/images/favicons/apple-icon-114x114.png">
    <link rel="apple-touch-icon" sizes="120x120" href="/images/favicons/apple-icon-120x120.png">
    <link rel="apple-touch-icon" sizes="144x144" href="/images/favicons/apple-icon-144x144.png">
    <link rel="apple-touch-icon" sizes="152x152" href="/images/favicons/apple-icon-152x152.png">
    <link rel="apple-touch-icon" sizes="180x180" href="/images/favicons/apple-icon-180x180.png">
    <link rel="icon" type="image/png" sizes="192x192"  href="/images/favicons/android-icon-192x192.png">
    <link rel="icon" type="image/png" sizes="32x32" href="/images/favicons/favicon-32x32.png">
    <link rel="icon" type="image/png" sizes="96x96" href="/images/favicons/favicon-96x96.png">
    <link rel="icon" type="image/png" sizes="16x16" href="/images/favicons/favicon-16x16.png">
    <link rel="manifest" href="/images/favicons/manifest.json">
    <meta name="msapplication-TileColor" content="#ffffff">
    <meta name="msapplication-TileImage" content="/images/favicons/ms-icon-144x144.png">
    <meta name="theme-color" content="#ffffff">

    <script>
        var url = '{{ url('Frontend/js/widgetWhatsApp.js') }}';
        var s = document.createElement('script');
        s.type = 'text/javascript';
        s.async = true;
        s.src = url;
        var options = {
            "enabled": true,
            "chatButtonSetting": {
                "backgroundColor": "#4dc247",
                "ctaText": "Kontak Kami",
                "borderRadius": "25",
                "marginLeft": "0",
                "marginBottom": "30",
                "marginRight": "50",
                "position": "right"
            },
            "brandSetting": {
                "brandName": "Insan Tera Semenjana",
                "brandSubTitle": "Yayasan Insan Tera Semenjana",
                "brandImg": "assets/apple-touch-icon.png",
                "welcomeText": "Halo ! Ada yang bisa admin bantu ?",
                "messageText": "Halo Kak, Saya Mau Bertanya, Sumber : Website Insan Tera Semenjana",
                "backgroundColor": "#166f63",
                "ctaText": "Start Chat",
                "borderRadius": "25",
                "autoShow": false,
                "phoneNumber": "6287717173410"
            }
        };
        s.onload = function() {
            CreateWhatsappChatWidget(options);
        };
        var x = document.getElementsByTagName('script')[0];
        x.parentNode.insertBefore(s, x);
    </script>

    {{-- Style --}}
    @stack('prpend-style')
    @stack('addon-style')

</head>

<body>

    {{-- Navbar --}}
    @include('Frontend.Template.navbar')

    <x-topBar title="Pendaftaran Online" />
    {{-- Page Content --}}
    @yield('content')

    {{-- Footer --}}
    @include('Frontend.Template.footer')

    {{-- Script --}}
    @stack('prpend-script')
    @stack('addon-script')
<!-- disabled -->
<script> document.addEventListener('contextmenu', function(event) { event.preventDefault(); alert('Right Click Disabled.'); }); </script>
</body>

</html>
