<div class="md:h-[827px] h-auto flex flex-col items-center md:flex-row justify-center md:gap-x-[100px] py-[100px] md:py-[100px] px-4 md:px-0 bg-cover bg-no-repeat bg-right md:bg-center"
    style="background-image: url('<?php echo e(asset('./images/background/biayajurusan.png')); ?>');">
    <div class="flex justify-center md:justify-start w-full md:w-auto">
        <img src="<?php echo e(asset('./images/sambutan/REKTOR-uid.png')); ?>" data-aos="fade-up"
            class="h-auto md:w-[1000px] w-[300px] md:h-[500px] max-w-[450px]" alt="">
    </div>
    <div class="flex flex-col md:items-start justify-center items-center w-full md:w-[40%] w-[100%] mt-4 md:mt-0"
        data-aos="fade-up">
        <?php if (isset($component)) { $__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\HeaderSection::class, ['subtext' => 'REKTOR Universitas Islam Depok','subtextColor' => '#6b7280','title' => 'Sambuatan Rektor Universitas Islam Depok','titleColor' => '#FFC324']); ?>
<?php $component->withName('header-section'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe)): ?>
<?php $component = $__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe; ?>
<?php unset($__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe); ?>
<?php endif; ?>
        <p class="text-justify font-dmsans mb-4 font-inter text-sm md:text-base text-white normal-case w-[80%]">
        Universitas Islam Depok UID Alkarimiyah adalah wujud komitmen untuk menghasilkan kualitas sumber daya manusia (SDM) yang cerdas, religius, dan kompeten di bidangnya. Sebagai perguruan tinggi lokal yang memiliki standar global, UID Alkarimiyah terus berkembang dengan tujuan mencetak lulusan yang siap menghadapi tantangan dunia profesional yang semakin kompleks. Dengan program-program pendidikan unggulan, didukung oleh pengajaran dari dosen berkompeten dan fasilitas modern, universitas ini telah berhasil menghasilkan ribuan civitas akademika yang tidak hanya memiliki keahlian yang mumpuni, tetapi juga memiliki nilai-nilai spiritual yang kuat.        <p class="text-justify mb-4 font-inter text-sm md:text-base text-white normal-case w-[80%]">Mari bergabung
        Kami percaya bahwa kualitas pendidikan tidak hanya terukur dari kemampuan intelektual semata, namun juga dari kecakapan dalam menghadapi perubahan zaman dan tantangan global. Oleh karena itu, UID Alkarimiyah mengedepankan pembelajaran yang berbasis pada pengembangan karakter, inovasi, serta keterampilan praktis yang relevan dengan perkembangan industri. Universitas ini menjadi tempat di mana para mahasiswa dapat mengasah potensi diri mereka, serta memperoleh ilmu dan keterampilan yang dibutuhkan untuk bersaing di dunia kerja baik di tingkat nasional maupun internasional.!</p>

        <?php if (isset($component)) { $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940 = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\Button::class, ['url' => '/sejarah-singkat']); ?>
<?php $component->withName('button'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>BACA SELENGKAPNYA <?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940)): ?>
<?php $component = $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940; ?>
<?php unset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940); ?>
<?php endif; ?>
    </div>
</div>
<?php /**PATH D:\web-kampus-main\resources\views/Frontend/landingpage/sambutan-section.blade.php ENDPATH**/ ?>