<?php $__env->startSection('title', 'Program Studi'); ?>


<?php $__env->startSection('content'); ?>
<div class=" md:h-[957px] h-auto flex flex-col items-center md:flex-row justify-center md:justify-start py-8 md:py-[100px] px-4 md:px-[200px] md:bg-center bg-right-top bg-cover bg-no-repeat"
    style="background-image: url('<?php echo e(asset('./images/background/bg-1.png')); ?>');">
    <div class="  flex flex-col md:items-start justify-center items-center w-full md:w-[40%] w-[100%] mt-4 md:mt-0"
        data-aos="fade-up">

        <?php if (isset($component)) { $__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\HeaderSection::class, ['subtext' => 'BIAYA & PROGRAM STUDI STISIP IMAM BONJOL','subtextColor' => '#28631b','title' => ' ','titleColor' => '#124185']); ?>
<?php $component->withName('header-section'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe)): ?>
<?php $component = $__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe; ?>
<?php unset($__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe); ?>
<?php endif; ?>
        <div class="swiper mySwiper md:w-[1300px] w-full">
            <div class="swiper-wrapper space-x-[10px] pb-[20px] md:ps-[20px]">

                <div
                    class="swiper-slide bg-white shadow-lg rounded-lg p-5 w-full sm:w-[280px] md:w-[320px] flex flex-col space-y-4">
                    <!-- Judul -->
                    <h3 class="text-lg font-semibold text-primary font-poppins">S1 Ilmu Administrasi Negara</h3>

                    <!-- Detail Biaya -->
                    <div class="text-sm font-dmsans text-gray-600 space-y-1">
                    <p>Biaya Registrasi Pendaftaran: <span class="text-primary font-medium">Rp. 150.000</span></p>
                    <p>Biaya  Awal: <span class="text-primary font-medium">Rp. 800.000</span></p>
                    <p>Biaya Bulanan: <span class="text-primary font-medium">Rp. 550.000</span></p>

                    </div>

                    <!-- Tombol -->
                    <div class="flex justify-between items-center mt-3 gap-3">
                        <a href="/pendaftaran" style="color:#fff"
                            class="bg-primary hover:bg-secondary  font-medium py-2 px-3 rounded-md text-sm transition-all w-full text-center">Daftar
                            Sekarang</a>
                        <a href="/brosur" style="color:#fff"
                            class="bg-yellow-400 hover:bg-primary  font-medium py-2 px-3 rounded-md text-sm transition-all w-full text-center">Informasi</a>
                    </div>
                </div>

                <div
                    class="swiper-slide bg-white shadow-lg rounded-lg p-5 w-full sm:w-[280px] md:w-[320px] flex flex-col space-y-4">
                    <!-- Judul -->
                    <h3 class="text-lg font-semibold text-primary font-poppins">S1 Ilmu Pemerintahan</h3>

                    <!-- Detail Biaya -->
                    <div class="text-sm font-dmsans text-gray-600 space-y-1">
                    <p>Biaya Registrasi Pendaftaran: <span class="text-primary font-medium">Rp. 150.000</span></p>
                    <p>Biaya  Awal: <span class="text-primary font-medium">Rp. 800.000</span></p>
                    <p>Biaya Bulanan: <span class="text-primary font-medium">Rp. 550.000</span></p>

                    </div>

                    <!-- Tombol -->
                    <div class="flex justify-between items-center mt-3 gap-3">
                        <a href="/pendaftaran" style="color:#fff"
                            class="bg-primary hover:bg-secondary  font-medium py-2 px-3 rounded-md text-sm transition-all w-full text-center">Daftar
                            Sekarang</a>
                        <a href="/brosur" style="color:#fff"
                            class="bg-yellow-400 hover:bg-primary  font-medium py-2 px-3 rounded-md text-sm transition-all w-full text-center">Informasi</a>
                    </div>
                </div>

                
        
            </div>
            <br><br>
            <div class="swiper-pagination"></div>
        </div>


        <div data-aos="fade-up"
            class="flex md:items-center justify-center items-center flex-col md:w-[1200px] w-full pt-5">
            <div data-aos="fade-up" class="w-full h-[1px] bg-blue-900 my-4"></div>
            <p data-aos="fade-up"
                class="text-center md:text-start mb-5 text-[14px] font-dmsans md:text-[14px] lg:text-[16px]">
                Bersama STISIP IMAM BONJOL, kami hadir untuk membangun masa depan gemilang melalui program studi terbaik, pengajaran berkualitas, dan fasilitas modern yang dirancang untuk mendukung langkah suksesmu.                        </p>

            <?php if (isset($component)) { $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940 = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\Button::class, ['url' => '/pendaftaran']); ?>
<?php $component->withName('button'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>PENDAFTARAN ONLINE <?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940)): ?>
<?php $component = $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940; ?>
<?php unset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940); ?>
<?php endif; ?>
        </div>
    </div>
</div>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('Frontend.Layouts.app', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH /home/u768956174/domains/stisipimambonjol.info/STISIP-IMAM-BONJOL/resources/views/Frontend/biayakuliah.blade.php ENDPATH**/ ?>