<?php $__env->startSection('title', 'Konfirmasi'); ?>


<?php $__env->startSection('content'); ?>
    <?php if (isset($component)) { $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\HeaderSectionPage::class, ['title' => 'Konfirmasi Pendaftaran STISIP IMAM BONJOL','breadcrumbHome' => 'Home','breadcrumbCurrent' => 'Konfirmasi Pendaftaran']); ?>
<?php $component->withName('header-section-page'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df)): ?>
<?php $component = $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df; ?>
<?php unset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df); ?>
<?php endif; ?>

    <div class="bg-gray-50 py-10">
        <div class="container mx-auto px-4 lg:px-20 max-w-screen-lg">
            <div class="bg-white shadow-lg rounded-lg overflow-hidden border-t-4 border-primary">
                <!-- Header -->
                <div class="bg-primary  p-6 text-center"  style="color:#fff">
                    <h1 class="text-2xl font-poppins font-bold">Terima Kasih Telah Mendaftar</h1>
                    <p class="text-sm mt-2 font-dmsans">
                        Kami telah mengirimkan email konfirmasi ke alamat Anda. Silakan periksa Inbox atau folder Spam.
                    </p>
                </div>

                <!-- Body Content -->
                <div class="p-8 font-dmsans text-primary">
                    <!-- Nomor Pendaftaran -->
                    <div class="text-center mb-6">
                        <p class="text-lg font-poppins">Nomor Pendaftaran Anda:</p>
                        <p class="text-3xl font-bold text-accent">PO_<?php echo e($registration->daftar_id); ?></p>
                    </div>

                    <!-- Informasi Biaya -->
                    <div class="mb-6">
                        <h3 class="text-lg font-semibold font-poppins">Informasi Biaya Pendaftaran:</h3>
                        <ul class="list-disc list-inside text-sm mt-2">
                        <li><strong>S1:</strong> Rp. 150.000,-</li>
                        </ul>
                    </div>

                    <!-- Pembayaran -->
                    <div class="mb-6">
                        <h3 class="text-lg font-semibold font-poppins">Rekening Pembayaran:</h3>
                        <p class="mt-2 text-sm">
                            <strong>Bank BNI</strong><br>
                            No Rekening: <strong>8282823886</strong><br>
                            a.n. <strong>Edukasi Indonesia Jaya</strong>
                        </p>
                    </div>

                    <!-- Cara Konfirmasi -->
                    <div class="mb-6">
                        <h3 class="text-lg font-semibold font-poppins">Cara Konfirmasi Pembayaran:</h3>
                        <div class="bg-gray-100 p-4 rounded-lg mt-2">
                            <p class="text-sm font-medium">1. Simpan bukti transfer Anda.</p>
                            <p class="text-sm font-medium mt-2">2. Pilih salah satu cara konfirmasi:</p>
                            <ul class="list-disc list-inside mt-2 text-sm"><br>
                                <li>
                            
                                    <a href="https://api.whatsapp.com/send?phone=6287890198284&text=Halo%20Admin%20Saya%20Sudah%20Daftar%20Online%20di%20STISIP IMAM BONJOL." data-aos="fade-up"  
                                    style="color:#fff; background-color:#40c351;"
                                    class=" text-sm font-poppins py-2 px-4 rounded-lg shadow-md hover:bg-accent transition">
                                    Konfirmasi Via WhatsApp
                                </a>
                                </li><br>
                                <li>Hubungi petugas di kampus.</li>
                            </ul>
                        </div>
                        <div class="mb-6">
                            <h3 class="text-lg font-semibold font-poppins">Cetak Formulir Pendaftaran:</h3>
                            <div class="bg-gray-100 p-4 rounded-lg mt-2">
                                <form method="POST" action="app/formulir.php" data-aos="fade-up"
                                class="flex items-center justify-between">
                                <?php echo csrf_field(); ?>
                                <input type="hidden" name="id" value="<?php echo e($registration->daftar_id); ?>">
                                <p data-aos="fade-up" class="text-sm font-medium">Klik tombol di bawah ini untuk
                                    mencetak formulir
                                    pendaftaran Anda.</p>
                                <a href="<?php echo e(route('cetak.confirm', $registration->daftar_id)); ?>" data-aos="fade-up"  style="color:#fff"
                                    class="bg-primary text-sm font-poppins py-2 px-4 rounded-lg shadow-md hover:bg-accent transition">
                                    Cetak Formulir
                                </a>
                            </form>
                            </div>
                        </div>

                    </div>

                    <!-- Wawancara -->
                    <div class="text-center mt-6">
                        <p class="text-sm font-dmsans">
                            Kami akan menghubungi Anda untuk wawancara melalui nomor WhatsApp:
                            <span class="font-semibold text-accent"><?php echo e($registration->no_wa); ?></span>
                        </p>
                    </div>
                </div>

                <!-- Footer -->
                <div class="bg-gray-100 p-6 text-center">
                    <img src="<?php echo e(asset('./images/logo/logo1.png')); ?>" alt="STISIP IMAM BONJOL" class="mx-auto w-32 mb-4" style="border-radius: 100px;" >
                    <p class="text-sm font-poppins text-gray-600">STISIP IMAM BONJOL</p>
                </div>
            </div>
        </div>
    </div>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('Frontend.Layouts.app2', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH D:\2025-STISIP-IMAM-BONJOL\resources\views/Frontend/confirm.blade.php ENDPATH**/ ?>