<div class="relative h-[1080px] bg-center bg-cover bg-no-repeat flex flex-col items-center justify-center overflow-hidden bg-hero"
    style="background-color:rgb(70, 6, 218);" 
    data-aos="fade-up">
</div>

<div class="w-full h-[40px] py-6 flex items-center bg-accent text-white overflow-hidden" data-aos="fade-down">
    <div class="w-full whitespace-nowrap animate-marquee flex items-center">
        <span class="font-poppins mx-4 text-[40px] font-bold" data-aos="flip-left" style="color:#fff" >Institut Teknologi Dan Bisnis BANTEN</span>
        <img src="<?php echo e(asset('./images/logo/logo-itbbanten.png')); ?>" alt="Logo" class="h-[40px] w-auto mx-4"
            data-aos="flip-left">
        <span class="font-poppins mx-4 text-[40px] font-bold" data-aos="flip-left" style="color:#fff">Institut Teknologi Dan Bisnis BANTEN</span>
        <img src="<?php echo e(asset('./images/logo/logo-itbbanten.png')); ?>" alt="Logo" class="h-[40px] w-auto mx-4"
            data-aos="flip-left">
        <span class="font-poppins mx-4 text-[40px] font-bold" data-aos="flip-left" style="color:#fff">Institut Teknologi Dan Bisnis BANTEN</span>
        <img src="<?php echo e(asset('./images/logo/logo-itbbanten.png')); ?>" alt="Logo" class="h-[40px] w-auto mx-4"
            data-aos="flip-left">
        <span class="font-poppins mx-4 text-[40px] font-bold" data-aos="flip-left" style="color:#fff">Institut Teknologi Dan Bisnis BANTEN</span>
        <img src="<?php echo e(asset('./images/logo/logo-itbbanten.png')); ?>" alt="Logo" class="h-[40px] w-auto mx-4"
            data-aos="flip-left">
        <span class="font-poppins mx-4 text-[40px] font-bold" data-aos="flip-left" style="color:#fff">Institut Teknologi Dan Bisnis BANTEN</span>
        <img src="<?php echo e(asset('./images/logo/logo-itbbanten.png')); ?>" alt="Logo" class="h-[40px] w-auto mx-4"
            data-aos="flip-left">
        <span class="font-poppins mx-4 text-[40px] font-bold" data-aos="flip-left" style="color:#fff">Institut Teknologi Dan Bisnis BANTEN</span>
        <img src="<?php echo e(asset('./images/logo/logo-itbbanten.png')); ?>" alt="Logo" class="h-[40px] w-auto mx-4"
            data-aos="flip-left">
        <span class="font-poppins mx-4 text-[40px] font-bold" data-aos="flip-left" style="color:#fff">Institut Teknologi Dan Bisnis BANTEN</span>
    </div>
</div>
<?php /**PATH D:\2025-ITBBANTEN\resources\views/Frontend/landingpage/hero-section.blade.php ENDPATH**/ ?>