<!-- <div class=" md:h-[957px] h-auto flex flex-col items-center md:flex-row justify-center md:justify-start py-8 md:py-[100px] px-4 md:px-[200px] md:bg-center bg-right-top bg-cover bg-no-repeat"
    style="background-image: url('<?php echo e(asset('./images/background/bg-blue.png')); ?>');">
    <div class="  flex flex-col md:items-start justify-center items-center w-full md:w-[40%] w-[100%] mt-4 md:mt-0"
        data-aos="fade-up">

        <?php if (isset($component)) { $__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\HeaderSection::class, ['subtext' => 'BIAYA & JURUSAN','subtextColor' => '#6b7280','title' => 'Biaya dan Jurusan Universitas Indonesia Maju','titleColor' => '#222764']); ?>
<?php $component->withName('header-section'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe)): ?>
<?php $component = $__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe; ?>
<?php unset($__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe); ?>
<?php endif; ?>
        <div class="swiper mySwiper md:w-[1300px] w-full">
            <div class="swiper-wrapper space-x-[10px] pb-[20px] md:ps-[20px]">
            <section>
                    <div id="text-page">
                        <?php echo $beranda->isi; ?> 
                    </div>
                </section>
                </div>

            </div>
            <br><br>
            <div class="swiper-pagination"></div>
        </div>


        <div data-aos="fade-up"
            class="flex md:items-center justify-center items-center flex-col md:w-[1200px] w-full pt-5">
            <div data-aos="fade-up" class="w-full h-[1px] bg-blue-900 my-4"></div>
            <p data-aos="fade-up"
                class="text-center md:text-start mb-5 text-[14px] font-dmsans md:text-[14px] lg:text-[16px]">
                Universitas Indonesia, langkah pertama menuju masa depan gemilang! Program unggulan, pengajaran berkualitas, dan fasilitas terbaik untuk mendukung impian kariermu!
            </p>

            <?php if (isset($component)) { $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940 = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\Button::class, ['url' => '/pendaftaran']); ?>
<?php $component->withName('button'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>PENDAFTARAN ONLINE <?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940)): ?>
<?php $component = $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940; ?>
<?php unset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940); ?>
<?php endif; ?>
        </div>
    </div>
</div> -->


<br><br> <br><br> <br><br>
<div class=" md:h-[957px] h-auto flex flex-col items-center md:flex-row justify-center md:justify-start py-8 md:py-[100px] px-4 md:px-[200px] md:bg-center bg-right-top bg-cover bg-no-repeat">
    <div class="  flex flex-col md:items-start justify-center items-center w-full md:w-[40%] w-[100%] mt-4 md:mt-0"
        data-aos="fade-up">

        <?php if (isset($component)) { $__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\HeaderSection::class, ['subtext' => 'BIAYA & JURUSAN','subtextColor' => '#6b7280','title' => 'Biaya dan Jurusan Universitas Indonesia Maju','titleColor' => '#222764']); ?>
<?php $component->withName('header-section'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe)): ?>
<?php $component = $__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe; ?>
<?php unset($__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe); ?>
<?php endif; ?>
        <div class="swiper mySwiper md:w-[1300px] w-full">
            <div class="swiper-wrapper space-x-[10px] pb-[20px] md:ps-[20px]">
                <section>
                    <div id="text-page">
                        <?php echo $beranda->isi; ?> 
                    </div>
                </section>
               

            </div>
            <br>
            
        </div>


        <div data-aos="fade-up"
            class="flex md:items-center justify-center items-center flex-col md:w-[1200px] w-full pt-5">
            <div data-aos="fade-up" class="w-full h-[1px] bg-blue-900 my-4"></div>
            <p data-aos="fade-up"
                class="text-center md:text-start mb-5 text-[14px] font-dmsans md:text-[14px] lg:text-[16px]">
                Universitas Indonesia, langkah pertama menuju masa depan gemilang! Program unggulan, pengajaran berkualitas, dan fasilitas terbaik untuk mendukung impian kariermu!
            </p>

            <?php if (isset($component)) { $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940 = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\Button::class, ['url' => '/pendaftaran']); ?>
<?php $component->withName('button'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>PENDAFTARAN ONLINE <?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940)): ?>
<?php $component = $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940; ?>
<?php unset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940); ?>
<?php endif; ?>
        </div>
       
    </div>
</div>
 <br><br> <br><br> <br><br><?php /**PATH /home/u4591423/public_html/PUBLIC_DOMAIN/2025_UIMA/resources/views/Frontend/landingpage/biayakuliah-section.blade.php ENDPATH**/ ?>