<div class="md:h-[827px] h-auto flex flex-col items-center md:flex-row justify-center md:gap-x-[100px] py-[100px] md:py-[100px] px-4 md:px-0 bg-cover bg-no-repeat bg-right md:bg-center"
    style="background-image: url('<?php echo e(asset('./images/background/bg-sambutan.png')); ?>');">
    <div class="flex justify-center md:justify-start w-full md:w-auto flex-col items-center">
    <img src="<?php echo e(asset('./images/sambutan/rektor-itbbanten.PNG')); ?>" data-aos="fade-up"
        class="h-auto md:w-[1000px] w-[300px] md:h-[500px] max-w-[450px]" style="border-radius:25px;" alt="Rektor Institut Banten">
    <p style="padding-top: 20px; font-size: 14px; color: #fff; text-align: center; font-family: 'Poppins', sans-serif;">
        <b>Dendi Afrizal, S.AB., M.Ak, </b>
    </p>
</div>
    <div class="flex flex-col md:items-start justify-center items-center w-full md:w-[40%] w-[100%] mt-4 md:mt-0"
        data-aos="fade-up">
        <?php if (isset($component)) { $__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\HeaderSection::class, ['subtext' => ' SAMBUTAN REKTOR ITB BANTEN','subtextColor' => '#fff','title' => '','titleColor' => '#fff']); ?>
<?php $component->withName('header-section'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe)): ?>
<?php $component = $__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe; ?>
<?php unset($__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe); ?>
<?php endif; ?>
        <p class="text-justify font-dmsans mb-4 font-inter text-sm md:text-base  normal-case w-[80%]" style="color:#fff" >
        Assalamu'alaikum warahmatullahi wabarakatuh, Salam sejahtera bagi kita semua.
</p>
        <p class="text-justify mb-4 font-inter text-sm md:text-base  normal-case w-[80%]" style="color:#fff">
        Sungguh merupakan kebahagiaan tersendiri bagi kami dapat menghadirkan informasi mengenai lembaga pendidikan kami. selama ini kami telah membantu mahasiswa dan alumni untuk meraih cita-cita kesuksesan dan menjadi profesional di bidangnya. Kami memiliki tanggung jawab untuk menyampaikan informasi ini seluas-luasnya agar anda dan para lulusan SLTA/Sederajat tidak keliru dalam menentukan pilihan tempat kuliah. kami mengharapkan anda mendapat pendidikan terbaik yang dapat dimanfaatkan sepenuhnya dalam pengembangan karir dan peningkatan kualitas hidup anda. kuliah bukan hanya sekedar mendapat gelar, tetapi juga skill dan karir yang cemerlang.
<p class="text-justify mb-4 font-inter text-sm md:text-base  normal-case w-[80%]" style="color:#fff">
Institut Teknologi dan Bisnis Banten (Institut Banten) hadir sebagai solusi bagi anda yang ingin kuliah dan cepat kerja. kami terus meningkatkan kualitas pendidikan dengan cara menyesuaikan dan mengikuti perkembangan dunia kerja (link and match). Program pendidikan yang kami selenggarakan menjamin lulusan kami tidak menganggur. itulah yang menyebabkan daya saing lulusan Institut Banten selama ini tetap tinggi dan sulit untuk ditiru oleh lembaga pendidikan lainnya. Terbukti Alumni kami lebih cepat kerja. Kami mengajak anda bergabung bersama kami untuk meraih sukses dan menjadi profesional. WE BUILD SUCCESS AND PROFESSIONAL!
</p>

        <?php if (isset($component)) { $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940 = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\Button::class, ['url' => '/sejarah-singkat']); ?>
<?php $component->withName('button'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>BACA SELENGKAPNYA <?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940)): ?>
<?php $component = $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940; ?>
<?php unset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940); ?>
<?php endif; ?>
    </div>
</div>
<?php /**PATH D:\2025-ITBBANTEN\resources\views/Frontend/landingpage/sambutan-section.blade.php ENDPATH**/ ?>