<?php

namespace Faker\Provider\vi_VN;

class Color extends \Faker\Provider\Color
{
    protected static $safeColorNames = [
        'đen', 'xanh', 'ô liu',
        'tím ', 'vôi', 'xanh', 'bạc',
        'xám', 'vàng', 'trắng',
    ];

    protected static $allColorNames = [
        'Hổ phách', 'Ametit', 'Xanh berin',
        'Xanh da trời', 'Be', 'Nâu sẫm',
        'Đen', 'Xanh lam', 'Nâu',
        'Da bò', 'Cam cháy', 'Hồng y',
        'Đỏ yên chi', 'Men ngọc', 'Anh đào',
        'Xanh hoàng hôn', 'Xanh nõn chuối', 'Xanh cô ban',
        'Đồng', 'San hô', 'Kem',
        'Đỏ thắm', 'Xanh lơ', 'Lục bảo',
        'Vàng kim loại', 'Xám', 'Xanh lá cây',
        'Vòi voi', 'Chàm', 'Ngọc thạch',
        'Kaki', 'Oải hương', 'Vàng chanh',
        'Hồng sẫm', 'Hạt dẻ', 'Cẩm quỳ',
        'Hoa cà', 'Lam sẫm', 'Ochre',
        'Ô liu', 'Da cam', 'Lan tím',
        'Lòng đào', 'Dừa cạn', 'Hồng',
        'Mận', 'Xanh thủy tinh', 'Hồng đất',
        'Tía', 'Đỏ', 'Cá hồi',
        'Đỏ tươi', 'Nâu đen',
        'Bạc', 'Nâu tanin', 'Mòng két',
        'Xanh Thổ', 'Đỏ son', 'Tím',
        'Xanh crôm', 'Trắng', 'Vàng',
    ];
}
