<?php

namespace Faker\Provider\pl_PL;

class Color extends \Faker\Provider\Color
{
    protected static $safeColorNames = [
        'czarny', 'brązowy', 'zielony', 'granatowy', 'oliwkowy',
        'fioletowy', 'morski', 'limonkowy', 'niebieski', 'srebrny',
        'szary', 'żółty', 'fuksja', 'cyjanowy', 'biały', 'czerwony',
        'różowy', 'pomarańczowy', 'purpurowy', 'złoty',
    ];

    protected static $allColorNames = [
        'akwamaryna', 'alabastrowy', 'amarantowy', 'ametystowy', 'antracytowy',
        'atramentowy', 'bahama yellow', 'bananowy', 'beżowy', 'biały', 'biskupi',
        'bordo', 'brzoskwiniowy', 'brązowy', 'brunatny', 'buraczkowy', 'burgund',
        'bursztynowy', 'bury', 'butelkowy', 'błękitny', 'ceglasty', 'chabrowy',
        'chamois', 'cielisty', 'ciemnozielony', 'cyjan', 'cyklamen', 'cynamonowy',
        'cynobrowy', 'cytrynowy', 'czarny', 'czekoladowy', 'czerwony', 'ecru', 'feldgrau',
        'fioletowy', 'fiołkowy', 'fokstrot', 'fluoroscencyjny', 'fuksja', 'gliniasty',
        'gołębi', 'grafitowy', 'granatowy', 'groszkowy', 'gruszkowy', 'heban', 'herbaciany',
        'indygo', 'izabelowy', 'jagodowy', 'jaśminowy', 'kakaowy', 'kanarkowy', 'kardynalski',
        'karmazynowy', 'karminowy', 'kasztanowy', 'kawowy', 'khaki', 'kobaltowy', 'koniakowy',
        'koralowy', 'kość słoniowa', 'kraplak', 'kremowy', 'krwisty', 'kukurydziany', 'lawendowy',
        'lapis-lazuli', 'lazurowy', 'leszczynowy', 'lila', 'lila róż', 'liliowy',
        'lagunowy', 'łososiowy', 'magenta', 'mahoń', 'majtkowy', 'makowy', 'malachitowy',
        'malinowy', 'marchewkowy', 'marengo', 'marmurkowaty', 'maślany', 'miedziany', 'miętowy',
        'minia', 'miodowy', 'mleczny', 'modrakowy', 'modry', 'morelowy', 'morski', 'mysi', 'mosiądzowy',
        'niebieski', 'oberżynowy', 'ochra', 'oliwkowy', 'ołowiany', 'oranż', 'orzechowy', 'palisander',
        'papieski', 'papuzi', 'patynowy', 'pąsowy', 'perłowy', 'piaskowy', 'pistacjowy', 'piwny',
        'platynowy', 'płowy', 'pomarańczowy', 'popielaty', 'porcelanowy', 'poziomkowy', 'ptasi',
        'purpurowy', 'rdzawy', 'rezedowy', 'róż indyjski', 'róż pompejański', 'róż wenecki', 'różowy', 'rubinowy',
        'rudy', 'sadza angielska', 'seledynowy', 'sepia', 'siarkowy', 'siny', 'siwy', 'sjena palona',
        'słomkowy', 'smolisty', 'spiżowy', 'srebrny', 'stalowy', 'stare złoto', 'szafirowy', 'szafranowy',
        'szary', 'szkarłatny', 'szmaragdowy', 'śliwkowy', 'tabaczkowy', 'tango', 'trawiasty', 'truskawkowy',
        'turkusowy', 'tycjan', 'ugier', 'ultramaryna', 'umbra', 'winny', 'wiśniowy', 'woskowy', 'wrzosowy',
        'zielony', 'ziemisty', 'złocisty', 'złoty', 'żółty',
    ];
}
