<!DOCTYPE html>
<html lang="id">

<head>
    <meta charset="utf-8">
    <meta name="description" content="STISIP Imam Bonjol Padang menawarkan program studi S1 Ilmu Administrasi Negara dan Ilmu Pemerintahan dengan biaya kuliah terjangkau sebesar Rp550.000 per bulan. Kampus ini menyediakan pendidikan berkualitas yang mempersiapkan mahasiswa untuk berkarir di sektor pemerintahan dan administrasi publik. Dengan fasilitas lengkap dan pengajaran yang berorientasi pada praktik, STISIP Imam Bonjol Padang menjadi pilihan tepat bagi mereka yang ingin mengembangkan keterampilan dalam manajemen pemerintahan dan kebijakan publik.">
    <meta name="keywords" content="edunitas, Kelas karyawan, Kuliah karyawan, STISIP Imam Bonjol Padang, kampus STISIP Imam Bonjol Padang , biaya kuliah kampus STISIP Imam Bonjol , biaya kuliah, kelas sabtu, akreditasi STISIP Imam Bonjol, kelas karyawan terjangkau Padang , S1 Ilmu Administrasi Negara, S1 Ilmu Pemerintahan, kampus murah Di Padang , kampus Di Padang , STISIP Imam Bonjol, biaya kuliah, kelas sabtu, akreditasi STISIP Imam Bonjol Padang ,
     Kampus Kelas Karyawan Di Padang , Kuliah Sambil Kerja Di Padang , Universitas Terbaik di Padang  untuk Karyawan, Biaya Kuliah Terjangkau di Padang , Universitas Kelas Sabtu Minggu Di Padang , Akreditasi Universitas Di Padang ,Perguruan Tinggi Swasta Murah di Padang , Program S1 Ilmu Administrasi Negara, Program S1 Ilmu Pemerintahan ,  Kampus Swasta Terbaik Padang , Universitas Murah  Di Padang  terakreditasi Baik,
     Kampus Terjangkau di Padang  untuk Karyawan, , Kuliah dengan Biaya Mulai 550 Ribu di Padang  , Universitas dengan Kelas Online Padang , Kampus Swasta Kelas Sabtu Minggu di Padang , Biaya Kuliah  S1 Murah di Padang , Biaya Kuliah  S1 Murah di Padang , Kampus dengan Program Studi Lengkap di Padang , Kampus dengan Program Studi Lengkap di Padang " />
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
    
    <title><?php echo $__env->yieldContent('title'); ?> &mdash; SEKOLAH TINGGI ILMU SOSIAL DAN POLITIK IMAM BONJOL PADANG (Kelas Karyawan)</title>
    <meta property="og:title" content="STISIP Imam Bonjol Padang (Kelas Karyawan)">
    <meta property="og:type" content="website">
    <meta property="og:url" content="STISIP Imam Bonjol Padang (Kelas Karyawan)">
    <meta property="og:image" content="https://stisipimambonjol.info/images/background/hero1.png">
    <meta property="og:image:width" content="1200" />
    <meta property="og:image:height" content="630" />
    <meta property="og:description" content="STISIP Imam Bonjol Padang menawarkan program S1 Ilmu Administrasi Negara dan Ilmu Pemerintahan dengan biaya kuliah terjangkau Rp550.000 per bulan. Kampus ini memberikan pendidikan berkualitas untuk mempersiapkan mahasiswa dalam karir di pemerintahan dan administrasi publik. Dengan pengajaran berbasis praktik dan fasilitas lengkap, STISIP Imam Bonjol Padang adalah pilihan ideal bagi yang ingin berkarir di sektor pemerintahan.">
    <meta name="twitter:card" content="summary_large_image">
    <meta name="twitter:creator" content="@_kuliahkaryawan">
    <meta name="twitter:site" content="@_kuliahkaryawan">
    <meta name="twitter:title" content="STISIP Imam Bonjol Padang (Kelas Karyawan) (Kelas Karyawan)">
    <meta name="twitter:description" content="STISIP Imam Bonjol Padang menawarkan program S1 Ilmu Administrasi Negara dan Ilmu Pemerintahan untuk kelas karyawan dengan biaya kuliah terjangkau Rp550.000 per bulan. Program ini dirancang untuk memberikan keterampilan di bidang pemerintahan dan administrasi publik, cocok bagi mereka yang bekerja sambil melanjutkan pendidikan.">
    <meta name="twitter:domain" content="stisipimambonjol.info">
    <meta name="twitter:image:src" content="https://stisipimambonjol.info/images/background/hero1.png">
    <meta name="author" content="Kuliah Karyawan Team" />
    <meta http-equiv="cache-control" content="public" />
    <meta name="application-name" content="STISIP Imam Bonjol Padang | Kuliah Karyawan (K2)" /> 

    <link rel="apple-touch-icon" sizes="57x57" href="/images/favicons/apple-icon-57x57.png">
    <link rel="apple-touch-icon" sizes="60x60" href="/images/favicons/apple-icon-60x60.png">
    <link rel="apple-touch-icon" sizes="72x72" href="/images/favicons/apple-icon-72x72.png">
    <link rel="apple-touch-icon" sizes="76x76" href="/images/favicons/apple-icon-76x76.png">
    <link rel="apple-touch-icon" sizes="114x114" href="/images/favicons/apple-icon-114x114.png">
    <link rel="apple-touch-icon" sizes="120x120" href="/images/favicons/apple-icon-120x120.png">
    <link rel="apple-touch-icon" sizes="144x144" href="/images/favicons/apple-icon-144x144.png">
    <link rel="apple-touch-icon" sizes="152x152" href="/images/favicons/apple-icon-152x152.png">
    <link rel="apple-touch-icon" sizes="180x180" href="/images/favicons/apple-icon-180x180.png">
    <link rel="icon" type="image/png" sizes="192x192"  href="/images/favicons/android-icon-192x192.png">
    <link rel="icon" type="image/png" sizes="32x32" href="/images/favicons/favicon-32x32.png">
    <link rel="icon" type="image/png" sizes="96x96" href="/images/favicons/favicon-96x96.png">
    <link rel="icon" type="image/png" sizes="16x16" href="/images/favicons/favicon-16x16.png">
    <link rel="manifest" href="/images/favicons/manifest.json">
    <meta name="msapplication-TileColor" content="#ffffff">
    <meta name="msapplication-TileImage" content="/images/favicons/ms-icon-144x144.png">
    <meta name="theme-color" content="#ffffff">
    

    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.css" rel="stylesheet" />
    <link href="https://fonts.googleapis.com/css2?family=Poppins:wght@400;600&family=DM+Sans:wght@400;700&display=swap"
        rel="stylesheet">
    <link href="./css/app.css" rel="stylesheet">
    <link href="<?php echo e(asset('css/app.css')); ?>" rel="stylesheet">
    
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.css" />
    
    <link href="https://cdn.jsdelivr.net/npm/aos@2.3.4/dist/aos.css" rel="stylesheet">
    
    <?php echo $__env->yieldPushContent('prpend-style'); ?>
    <?php echo $__env->yieldPushContent('addon-style'); ?>

</head>

<body>

    
    <?php echo $__env->make('Frontend.Template.navbar', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>

    
    <div class="h-auto flex flex-col items-center justify-center md:gap-x-[100px] py-8 py-[100px] px-4 md:px-0 bg-cover bg-no-repeat bg-right md:bg-center-top"
        style="background-image: url('<?php echo e(asset('./images/background/bg-1.png')); ?>');">
        <?php echo $__env->yieldContent('content'); ?>
    </div>

    <div class="fixed flex-row items-center bottom-4 right-4 z-50 md:bottom-10 md:right-10 flex ">
        <!-- Animated WhatsApp Button -->
        <div style="color:#fff;"
            class="slide-text whatsapp-button overflow-hidden transition-all duration-500 ease-in-out bg-[#40C351] h-[40px] py-2 px-4 font-poppins text-white rounded-full mb-2">
            <h1 class="whatsapp-button-text ">ingin bertanya ? yuk di click !</h1>
        </div>

        <!-- WhatsApp Icon -->
        <a href="https://wa.me/6289504586704?text=Halo%20Admin%2C%20saya%20mau%20bertanya%20%0ASumber%20%3A%20<?php echo e(url()->current()); ?>"
            target="_blank" rel="noopener noreferrer">
            <img src="<?php echo e(asset('images/logo/wa.jpg')); ?>" alt="WhatsApp" class="w-12 h-12 md:w-[70px] md:h-[70px]">
        </a>
    </div>

    
    <?php echo $__env->make('Frontend.Template.footer', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>



    
    <?php echo $__env->yieldPushContent('prpend-script'); ?>
    <?php echo $__env->yieldPushContent('addon-script'); ?>



    
    <script src="https://www.google.com/recaptcha/api.js"></script>
    
    <script src="https://cdn.jsdelivr.net/npm/aos@2.3.4/dist/aos.js"></script>
    
    <script src="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.js"></script>
    <script src="./js/app.js"></script>
    <script src="<?php echo e(asset('./js/app.js')); ?>"></script>
    <script>
document.addEventListener("DOMContentLoaded", () => {
    const modal = document.getElementById("recaptcha-modal");
    const container = document.getElementById("recaptcha-container");
    const openModalButton = document.getElementById("open-recaptcha-modal");
    const closeModalButton = document.getElementById("recaptcha-close");
    const form = document.querySelector("form");
    let recaptchaWidgetId;

    // Periksa apakah tombol "Daftar Sekarang" ditemukan
    if (!openModalButton) {
        console.error("Tombol 'Daftar Sekarang' tidak ditemukan!");
        return;
    }

    // Initialize reCAPTCHA
    grecaptcha.ready(() => {
        recaptchaWidgetId = grecaptcha.render("recaptcha-container", {
            sitekey: "6LdFv9sqAAAAAHpf1LMtxBI3wbRnitJC_r2oz-HE",
            size: "normal",
            callback: onRecaptchaSuccess,
        });
    });

    // Buka Modal saat tombol "Daftar Sekarang" diklik
    openModalButton.addEventListener("click", () => {
        console.log("Membuka modal...");
        modal.classList.add("active");
        modal.classList.remove("hidden");
        grecaptcha.reset(recaptchaWidgetId); // Reset reCAPTCHA agar bisa digunakan ulang
    });

    // Tutup Modal saat tombol "Batal" diklik
    closeModalButton.addEventListener("click", () => {
        console.log("Menutup modal...");
        modal.classList.remove("active");
        setTimeout(() => {
            modal.classList.add("hidden");
        }, 300); // Delay agar animasi transisi berjalan
    });

    // Handle reCAPTCHA Success
    function onRecaptchaSuccess(token) {
        console.log("Token berhasil diterima:", token);
        modal.classList.remove("active");
        setTimeout(() => {
            modal.classList.add("hidden");
        }, 300);

        // Tambahkan token reCAPTCHA ke dalam form sebelum submit
        const hiddenInput = document.createElement("input");
        hiddenInput.type = "hidden";
        hiddenInput.name = "g-recaptcha-response";
        hiddenInput.value = token;
        form.appendChild(hiddenInput);

        // Submit form
        form.submit();
    }
});
</script>
<!-- disabled -->
<script> document.addEventListener('contextmenu', function(event) { event.preventDefault(); alert('Right Click Disabled.'); }); </script>
</body>

</html>
<?php /**PATH /home/u4591423/public_html/PUBLIC_DOMAIN/2025-STISIP-IMAM-BONJOL/resources/views/Frontend/Layouts/app2.blade.php ENDPATH**/ ?>