<!DOCTYPE html>
<html lang="id">

<head>
    <meta charset="utf-8">
    <meta name="description" content="Institut Teknologi dan Bisnis Diniyyah Lampung (INSTIDLA) adalah perguruan tinggi yang menawarkan program studi di bidang kewirausahaan, manajemen ritel, dan rekayasa perangkat lunak (RPL). Program studi ini dirancang untuk mempersiapkan mahasiswa dengan keterampilan praktis yang dibutuhkan di dunia kerja. Biaya pendidikan dimulai dari Rp 420.000 per bulan, menjadikannya pilihan terjangkau bagi yang ingin berkarir di bidang bisnis dan teknologi. INSTIDLA juga menekankan pengembangan karakter serta nilai-nilai agama dalam pendidikan.." />
    <meta name="keywords" content=" Kelas karyawan, Kuliah karyawan, Institut Teknologi Dan Bisnis Diniyyah Lampung, kampus Institut Teknologi Dan Bisnis Diniyyah Lampung , biaya kuliah kampus INSTIDLA , biaya kuliah, kelas sabtu, akreditasi INSTIDLA Lampung, kelas karyawan terjangkau Lampung, S1 kewirausahaan, S1 manajemen ritel, S1 rekayasa perangkat lunak (RPL), kampus murah, kampus Lampung, INSTIDLA, biaya kuliah, kelas sabtu, akreditasi Institut Teknologi Dan Bisnis Diniyyah Lampung Lampung,
     Kampus Kelas Karyawan Lampung, Kuliah Sambil Kerja Lampung, Universitas Terbaik Lampung untuk Karyawan, Biaya Kuliah Terjangkau di Lampung, Universitas Kelas Sabtu Lampung, Akreditasi Universitas Lampung, Perguruan Tinggi Swasta Lampung Murah, Program D3 Manajemen Informatika, Kuliah S1 Teknologi Informasi Lampung , Kampus Swasta Terbaik Lampung, Universitas Murah Lampung dengan Akreditasi Baik,
     Kampus Terjangkau Lampung untuk Karyawan, Kuliah dengan Biaya Mulai 400 Ribu di Lampung, Universitas dengan Kelas Online Lampung, Kampus Swasta Kelas Sabtu Minggu Lampung, Biaya Kuliah  S1 Murah di Lampung, Kampus dengan Program Studi Lengkap Lampung" />
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
    
    <title><?php echo $__env->yieldContent('title'); ?> &mdash; INSTIDLA (Kelas Karyawan)</title>
    <meta property="og:title" content="STMIK PGRI ARUNGBINANG (Kelas Karyawan)">
    <meta property="og:type" content="website">
    <meta property="og:url" content="stmikpgri-arungbinang.info">
    <meta property="og:image" content="https://stmikpgri-arungbinang.info/images/background/hero1.png">
    <meta property="og:image:width" content="1200" />
    <meta property="og:image:height" content="630" />
    <meta property="og:description" content="STMIK PGRI ARUNGBINANG adalah perguruan tinggi swasta terkemuka di Lampung yang berfokus pada pengembangan pendidikan di bidang teknologi dan informatika. Dengan pilihan program studi D3 Manajemen Informatika dan S1 Teknologi Informasi, kampus ini dirancang untuk mencetak lulusan yang kompeten dan siap bersaing di era digital.STMIK PGRI ARUNGBINANG menawarkan program kelas karyawan dengan biaya terjangkau, mulai dari Rp 400.000 per bulan, sehingga memungkinkan para profesional untuk melanjutkan pendidikan tanpa mengganggu aktivitas pekerjaan. Didukung oleh fasilitas modern, lingkungan belajar yang kondusif, dan tenaga pengajar berpengalaman, STMIK PGRI ARUNGBINANG menjadi pilihan strategis untuk meningkatkan kompetensi dan membangun karir di dunia teknologi.">
    <meta name="twitter:card" content="summary_large_image">
    <meta name="twitter:creator" content="@_kuliahkaryawan">
    <meta name="twitter:site" content="@_kuliahkaryawan">
    <meta name="twitter:title" content="STMIK PGRI ARUNGBINANG (Kelas Karyawan)">
    <meta name="twitter:description" content="Kelas Karyawan STMIK PGRI ARUNGBINANG adalah solusi ideal bagi Anda yang ingin melanjutkan pendidikan tinggi tanpa harus meninggalkan pekerjaan. Program ini dirancang khusus untuk memberikan fleksibilitas waktu, sehingga Anda dapat menyeimbangkan antara studi dan aktivitas profesional. Dengan biaya yang terjangkau, mulai dari Rp 400.000 per bulan, Kelas Karyawan menawarkan kesempatan untuk mengikuti program studi unggulan seperti D3 Manajemen Informatika dan S1 Teknologi Informasi. Kurikulum yang disusun relevan dengan kebutuhan industri, didukung oleh dosen berpengalaman dan fasilitas modern, memastikan Anda mendapatkan pendidikan berkualitas yang mendukung perkembangan karir.">
    <meta name="twitter:domain" content="stmikpgri-arungbinang.info">
    <meta name="twitter:image:src" content="https://stmikpgri-arungbinang.info/images/background/hero1.png">
    <meta name="author" content="Kuliah Karyawan Team" />
    <meta http-equiv="cache-control" content="public" />
    <meta name="application-name" content="STMIK PGRI ARUNGBINANG | Kuliah Karyawan (K2)" />

    <link rel="apple-touch-icon" sizes="57x57" href="/images/favicons/apple-icon-57x57.png">
    <link rel="apple-touch-icon" sizes="60x60" href="/images/favicons/apple-icon-60x60.png">
    <link rel="apple-touch-icon" sizes="72x72" href="/images/favicons/apple-icon-72x72.png">
    <link rel="apple-touch-icon" sizes="76x76" href="/images/favicons/apple-icon-76x76.png">
    <link rel="apple-touch-icon" sizes="114x114" href="/images/favicons/apple-icon-114x114.png">
    <link rel="apple-touch-icon" sizes="120x120" href="/images/favicons/apple-icon-120x120.png">
    <link rel="apple-touch-icon" sizes="144x144" href="/images/favicons/apple-icon-144x144.png">
    <link rel="apple-touch-icon" sizes="152x152" href="/images/favicons/apple-icon-152x152.png">
    <link rel="apple-touch-icon" sizes="180x180" href="/images/favicons/apple-icon-180x180.png">
    <link rel="icon" type="image/png" sizes="192x192"  href="/images/favicons/android-icon-192x192.png">
    <link rel="icon" type="image/png" sizes="32x32" href="/images/favicons/favicon-32x32.png">
    <link rel="icon" type="image/png" sizes="96x96" href="/images/favicons/favicon-96x96.png">
    <link rel="icon" type="image/png" sizes="16x16" href="/images/favicons/favicon-16x16.png">
    <link rel="manifest" href="/images/favicons/manifest.json">
    <meta name="msapplication-TileColor" content="#ffffff">
    <meta name="msapplication-TileImage" content="/images/favicons/ms-icon-144x144.png">
    <meta name="theme-color" content="#ffffff">


    <link href="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.css" rel="stylesheet" />
    <link href="https://fonts.googleapis.com/css2?family=Poppins:wght@400;600&family=DM+Sans:wght@400;700&display=swap"
        rel="stylesheet">
    <link href="./css/app.css" rel="stylesheet">
    
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.css" />
    
    <link href="https://cdn.jsdelivr.net/npm/aos@2.3.4/dist/aos.css" rel="stylesheet">

    
    <?php echo $__env->yieldPushContent('prpend-style'); ?>
    <?php echo $__env->yieldPushContent('addon-style'); ?>

</head>

<body>

    
    <?php echo $__env->make('Frontend.Template.navbar', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>

    
    <?php echo $__env->yieldContent('content'); ?>
    <div class="fixed flex-row items-center bottom-4 right-4 z-50 md:bottom-10 md:right-10 flex ">
        <!-- Animated WhatsApp Button -->
        <div
            class="slide-text whatsapp-button overflow-hidden shadow-2xl transition-all duration-500 ease-in-out bg-[#40C351] h-[40px] py-2 px-4 font-poppins text-white rounded-full mb-2">
            <h1 class="whatsapp-button-text ">ingin bertanya ? yuk di click !</h1>
        </div>

        <!-- WhatsApp Icon -->
        <a href="https://wa.me/6289504586704?text=Halo%20Admin%2C%20saya%20mau%20bertanya%20%0ASumber%20%3A%20<?php echo e(url()->current()); ?>"
            target="_blank" rel="noopener noreferrer">
            <img src="<?php echo e(asset('images/logo/wa.jpg')); ?>" alt="WhatsApp" class="w-12 h-12 md:w-[70px] md:h-[70px]">
        </a>

    </div>

    
    <?php echo $__env->make('Frontend.Template.footer', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>

    
    <?php echo $__env->yieldPushContent('prpend-script'); ?>
    <?php echo $__env->yieldPushContent('addon-script'); ?>
    </script>
    
    <script src="https://cdn.jsdelivr.net/npm/aos@2.3.4/dist/aos.js"></script>
    
    <script src="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.js"></script>
    <script src="./js/app.js"></script>
</body>

</html>
<?php /**PATH D:\2025-instidla\resources\views/Frontend/Layouts/app.blade.php ENDPATH**/ ?>