<!DOCTYPE html>
<html>

<head>
    <title>Konfirmasi Pendaftaran</title>
</head>

<body>
    <p><b>Kepada Yth Calon Mahasiswa di Tempat,</b></p>
    <p>Terima kasih Anda telah melakukan Pendaftaran Online di situs kami dengan data berikut:</p>
    <p>Nomor Pendaftaran: <b><?php echo e($data['no_daftar']); ?></b><br>
        Perguruan Tinggi: <b>STMIK PGRI ARUNGBINANG</b><br>
        Jurusan: <?php echo e($data['jurusan']); ?><br>
        Wawancara Via: Telepon (di <?php echo e($data['no_wa']); ?>)</p>

    <p><b><u>DATA PRIBADI</u></b></p>
    <ul>
        <li>Nama: <?php echo e($data['nama_leng']); ?></li>
        <li>Jenis Kelamin: <?php echo e($data['jk']); ?></li>
        <li>Tempat Lahir: <?php echo e($data['tmpt_lahir']); ?></li>
        <li>Tanggal Lahir: <?php echo e($data['tgl_lahir']); ?></li>
        <li>Email: <?php echo e($data['email']); ?></li>
        <li>No HP/WA: <?php echo e($data['no_hp']); ?></li>
    </ul>
    <p>Setelah melakukan pembayaran, konfirmasi dapat dilakukan melalui WA ke: <a
            href="https://api.whatsapp.com/send?phone=6287890198284&text=Halo%20Admin%20Saya%20Sudah%20Daftar%20Online%20di%20STMIK PGRI ARUNGBINANG.">6287890198284</a>.
    </p>
</body>

</html>
<?php /**PATH /home/u4591423/public_html/PUBLIC_DOMAIN/2025_STMIK-PGRI_ARUNGBINANG/resources/views/emails/registration.blade.php ENDPATH**/ ?>