<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="utf-8">
    <meta name="description" content="Universitas Islam Depok (UID) adalah salah satu perguruan tinggi swasta terbaik di Depok yang menawarkan pendidikan berkualitas dengan biaya yang sangat terjangkau, mulai dari Rp 550.000 per bulan. UID hadir untuk memenuhi kebutuhan masyarakat akan pendidikan tinggi Islami dengan berbagai program studi unggulan S1 Perbankan Syariah,S1 Manajemen Pendidikan Islam,S1 Ekonomi Syariah,S1 Hukum Keluarga Islam,S1 Hukum Ekonomi Syariah,S1 Pendidikan Agama Islam,S2 Pendidikan Agama Islam" />
    <meta name="keywords" content="Universitas Indonesia,kampus UI, Gunadarma, Universitas Gunadarma,Universitas pancasila, Kelas karyawan, Kuliah karyawan, Universitas Islam Depok , kampus Universitas Islam di  Depok , biaya kuliah kampus UID Depok , biaya kuliah, kelas sabtu, akreditasi UID Depok , kelas karyawan terjangkau Depok, S1 Perbankan Syariah, S1 Manajemen Pendidikan Islam, S1 Ekonomi Syariah, S1 Hukum Keluarga Islam, S1 Hukum Ekonomi Syariah, S1 Pendidikan Agama Islam, S2 Pendidikan Agama Islam, kampus murah, kampus Depok , Universitas Islam Depok , kampus  Universitas Islam Depok  Depok , biaya kuliah kampus UID Depok , biaya kuliah, kelas sabtu, akreditasi UID Depok
    Kampus Universitas Islam Depok, Biaya Kuliah Universitas Islam Depok, Kampus Terjangkau di Depok, Kelas Karyawan Universitas Islam Depok, Kuliah Sabtu-Minggu di Depok, Universitas dengan Akreditasi Baik di Depok, Universitas Islam Terbaik di Depok, S1 Perbankan Syariah di Depok, S1 Ekonomi Syariah Depok, S1 Pendidikan Agama Islam Depok, S1 Manajemen Pendidikan Islam Depok, S1 Hukum Keluarga Islam Depok, S1 Hukum Ekonomi Syariah Depok, S2 Pendidikan Agama Islam Depok, Kuliah untuk Karyawan di Depok, Kelas Karyawan Terjangkau di Depok, Biaya Kuliah Kelas Karyawan Depok, Universitas dengan Kelas Sabtu-Minggu di Depok, 
    Kuliah S1 untuk Karyawan Depok, Kuliah S2 untuk Karyawan Depok, Biaya Kuliah UID Depok 2025, Universitas Islam Depok dengan Biaya Murah, Akreditasi Universitas Islam Depok, Universitas Akreditasi Baik dengan Biaya Murah di Depok, Kampus Murah di Depok, Universitas Islam di Depok, Kampus Depok yang Terjangkau, Universitas Terbaik di Depok, Kampus Depok untuk Program Sarjana dan Magister, Kuliah Karyawan Murah di Depok dengan Akreditasi Baik, Universitas Islam Depok dengan Biaya Kuliah Terjangkau, Kuliah Sabtu-Minggu UID Depok, Program Studi Ekonomi Syariah Terbaik Depok, S2 Pendidikan Agama Islam Biaya Terjangkau Depok" />
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
    
    <title>STMIK PGRI ARUNGBINANG  (Kelas Karyawan)</title>
    <meta property="og:title" content="Universitas Islam Depok  (Kelas Karyawan)">
    <meta property="og:type" content="website">
    <meta property="og:url" content="muliadarma.info">
    <meta property="og:image" content="https://stie.muliadarma.info/images/banner-slider/Banner-stiemuliadarma.png">
    <meta property="og:image:width" content="1200" />
    <meta property="og:image:height" content="630" />
    <meta property="og:description" content="UniversitasUniversitas Islam Depok (UID) adalah salah satu perguruan tinggi swasta terbaik di Depok yang berkomitmen memberikan pendidikan berkualitas dengan nilai-nilai Islami. Sebagai kampus modern yang relevan dengan kebutuhan zaman, UID menyediakan berbagai program studi unggulan untuk jenjang Sarjana (S1) dan Magister (S2), dengan fokus pada pengembangan kompetensi akademik, spiritual, dan profesional. UID dikenal sebagai pilihan utama bagi masyarakat Depok dan sekitarnya yang mencari pendidikan tinggi dengan biaya terjangkau. Dengan biaya kuliah mulai dari Rp 550.000 per bulan, UID menawarkan fleksibilitas pembiayaan sehingga terjangkau oleh berbagai kalangan, termasuk karyawan yang ingin melanjutkan pendidikan melalui program Kelas Karyawan.">
    <meta name="twitter:card" content="summary_large_image">
    <meta name="twitter:creator" content="@_kuliahkaryawan">
    <meta name="twitter:site" content="@_kuliahkaryawan">
    <meta name="twitter:title" content="Universitas Islam Depok  (Kelas Karyawan)">
    <meta name="twitter:description" content="Kelas Karyawan Universitas Islam Depok (UID) adalah solusi terbaik bagi para profesional yang ingin melanjutkan pendidikan tanpa meninggalkan pekerjaan. Program ini dirancang khusus untuk memberikan fleksibilitas waktu kuliah sehingga mahasiswa dapat mengatur jadwal antara pekerjaan, keluarga, dan studi dengan lebih mudah. Dengan biaya yang terjangkau, mulai dari Rp 550.000 per bulan, Kelas Karyawan UID memberikan akses kepada pendidikan berkualitas tinggi dengan pendekatan Islami. Program ini cocok untuk karyawan, wirausahawan, dan masyarakat umum yang memiliki keterbatasan waktu pada hari kerja.">
    <meta name="twitter:domain" content="muliadarma.info">
    <meta name="twitter:image:src" content="https://testing.iaidepok.info/images/banner-slider/banner-uid.png">
    <meta name="author" content="Kuliah Karyawan Team" />
    <meta http-equiv="cache-control" content="public" />
    <meta name="application-name" content="Universitas Islam Depok  | Kuliah Karyawan (K2)" />
    
    <link rel="apple-touch-icon" sizes="57x57" href="/images/favicons/apple-icon-57x57.png">
    <link rel="apple-touch-icon" sizes="60x60" href="/images/favicons/apple-icon-60x60.png">
    <link rel="apple-touch-icon" sizes="72x72" href="/images/favicons/apple-icon-72x72.png">
    <link rel="apple-touch-icon" sizes="76x76" href="/images/favicons/apple-icon-76x76.png">
    <link rel="apple-touch-icon" sizes="114x114" href="/images/favicons/apple-icon-114x114.png">
    <link rel="apple-touch-icon" sizes="120x120" href="/images/favicons/apple-icon-120x120.png">
    <link rel="apple-touch-icon" sizes="144x144" href="/images/favicons/apple-icon-144x144.png">
    <link rel="apple-touch-icon" sizes="152x152" href="/images/favicons/apple-icon-152x152.png">
    <link rel="apple-touch-icon" sizes="180x180" href="/images/favicons/apple-icon-180x180.png">
    <link rel="icon" type="image/png" sizes="192x192"  href="/images/favicons/android-icon-192x192.png">
    <link rel="icon" type="image/png" sizes="32x32" href="/images/favicons/favicon-32x32.png">
    <link rel="icon" type="image/png" sizes="96x96" href="/images/favicons/favicon-96x96.png">
    <link rel="icon" type="image/png" sizes="16x16" href="/images/favicons/favicon-16x16.png">
    <link rel="manifest" href="/images/favicons/manifest.json">
    <meta name="msapplication-TileColor" content="#ffffff">
    <meta name="msapplication-TileImage" content="/images/favicons/ms-icon-144x144.png">
    <meta name="theme-color" content="#ffffff">
    
    <link href="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.css" rel="stylesheet" />

    <!-- Add Poppins font -->
    <link rel="preconnect" href="https://fonts.googleapis.com">
    <link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
    <link
        href="https://fonts.googleapis.com/css2?family=Poppins:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900&display=swap"
        rel="stylesheet">

    <script src="https://cdn.tailwindcss.com?plugins=forms,typography,aspect-ratio,line-clamp,container-queries"></script>
</head>

<body class="font-poppins h-screen flex items-center justify-center bg-cover bg-center">
    <?php echo $__env->yieldContent('content'); ?>

    
    <script src="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.js"></script>
    <!-- Font Awesome for icons (used for Twitter icon) -->
    <script src="https://kit.fontawesome.com/a076d05399.js" crossorigin="anonymous"></script>

    
    <?php echo $__env->yieldPushContent('scripts'); ?>
</body>

</html>
<?php /**PATH /home/u4591423/public_html/PUBLIC_DOMAIN/2025_STIMIK-PGR_ARUNGBINANG/resources/views/auth/app.blade.php ENDPATH**/ ?>