<?php $__env->startSection('title', 'Detail Data Pendaftaran'); ?>

<?php $__env->startSection('content'); ?>
<?=
$no_wa = $daftar->no_wa; // Ambil nilai dari array $res
        $no_wa_replaced = preg_replace('/^08/', '628', $no_wa); // Ganti "08" hanya di awal string
        echo $no_wa_replaced;
?>
    <div class="page-content">
        <div class="row">
            <div class="col-md-12 grid-margin stretch-card">
                <div class="card">
                    <div class="card-body">
                        <div class="panel-heading">
                            <h3 class="panel-title mb-4">Informasi Pendaftar</h3>
                        </div>
                        <div class="panel-body">
                            <table class="table table-hover">
                                <tbody>
                                    <tr>
                                        <td>Nomor Pendaftaran</td>
                                        <td>PO_<?php echo e($daftar->daftar_id); ?></td>
                                    </tr>
                                    <tr>
                                        <td>Nama Lengkap</td>
                                        <td><?php echo e($daftar->nama_leng); ?></td>
                                    </tr>
                                    <tr>
                                        <td>No KTP</td>
                                        <td><?php echo e($daftar->no_ktp); ?></td>
                                    </tr>
                                    <tr>
                                        <td>Pilihan Kampus</td>
                                        <td><?php echo e($daftar->kampus); ?></td>
                                    </tr>
                                    <tr>
                                        <td>Jurusan yang diambil</td>
                                        <td><?php echo e($daftar->jurusan); ?></td>
                                    </tr>
                                    <tr>
                                        <td>Lulusan</td>
                                        <td><?php echo e($daftar->lulusan); ?></td>
                                    </tr>
                                    <tr>
                                        <td>Tempat Tgl Lahir</td>
                                        <td><?php echo e($daftar->tmpt_lahir); ?>, <?php echo e(tanggal_indonesia($daftar->tgl_lahir)); ?></td>
                                    </tr>
                                    <tr>
                                        <td>Jenis Kelamin</td>
                                        <td><?php echo e($daftar->j_kel == 'L' ? 'Laki-Laki' : 'Perempuan'); ?></td>
                                    </tr <tr>
                                    <td>Agama</td>
                                    <td><?php echo e($daftar->agama); ?></td>
                                    </tr>
                                    <tr>
                                        <td>Alamat KTP</td>
                                        <td><?php echo e($daftar->al_ktp); ?></td>
                                    </tr>
                                    <tr>
                                        <td>Alamat Domisili</td>
                                        <td><?php echo e($daftar->al_dom); ?></td>
                                    </tr>
                                    <tr>
                                        <td>NO HP</td>
                                        <td><?php echo e($daftar->no_hp); ?></td>
                                    </tr>
                                    <tr>
                                        <td>NO WA</td>
                                        <td><?php echo e($daftar->no_wa); ?></td>
                                    </tr>
                                    <tr>
                                        <td>Email</td>
                                        <td><?php echo e($daftar->email); ?></td>
                                    </tr>
                                    <tr>
                                        <td>Nama Ayah</td>
                                        <td><?php echo e($daftar->ayah); ?></td>
                                    </tr>
                                    <tr>
                                        <td>Nama Ibu</td>
                                        <td><?php echo e($daftar->ibu); ?></td>
                                    </tr>
                                    <tr>
                                        <td>Lulusan</td>
                                        <td><?php echo e($daftar->lulusan); ?></td>
                                    </tr>
                                    <tr>
                                        <td>Asal Sekolah</td>
                                        <td><?php echo e($daftar->sekolah); ?></td>
                                    </tr>
                                    <tr>
                                        <td>Biaya</td>
                                        <td><?php echo e($daftar->biaya); ?></td>
                                    </tr>
                                    <tr>
                                        <td>Sumber Informasi</td>
                                        <td><?php echo e($daftar->info); ?></td>
                                    </tr>

                                    <!-- Add remaining fields -->
                                </tbody>
                            </table>
                        </div>
                        <div>
                            <div class="panel-heading">
                                <h3 class="panel-title mt-4 mb-2">NOTE :</h3>
                            </div>
                            <p class="mb-2">untuk semua marketing dapat memfollow up langsung pendaftar melalu button wa
                                di bawah ini :
                            </p>
                            <a href="https://wa.me/<?php echo e($no_wa_replaced); ?>?text=<?php echo e(rawurlencode("Terimakasih sudah melakukan pendaftaran online di kampus *" . $daftar->kampus . "* dengan data:\n\n- No.PO : *" . $daftar->daftar_id . "*\n- Nama : *" . $daftar->nama_leng . "*\n- Jurusan : *" . $daftar->jurusan . "*\n- NIK : *" . $daftar->no_ktp . "*\n\nData sudah kami terima, kapan dapat melakukan pembayaran biaya pendaftaran?")); ?>"
                                target="_blank" rel="noopener noreferrer" class="btn btn-info">
                                Follow Up Cok !
                            </a>

                        </div>
                        <div class="mt-3">
                            <button onclick="window.history.go(-1); return false;" class="btn btn-danger">Kembali</button>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <?php
            function tanggal_indonesia($tanggal)
            {
                if (empty($tanggal)) {
                    return 'Tanggal Tidak Diketahui'; // Jika tanggal kosong
                }

                // Pastikan tanggal dalam format yang benar (YYYY-MM-DD)
                $pecahkan = explode('-', $tanggal);

                // Validasi apakah hasil explode() memiliki tiga komponen
                if (count($pecahkan) == 3) {
                    $bulan = [
                        1 => 'Januari',
                        'Februari',
                        'Maret',
                        'April',
                        'Mei',
                        'Juni',
                        'Juli',
                        'Agustus',
                        'September',
                        'Oktober',
                        'November',
                        'Desember',
                    ];

                    return $pecahkan[2] . ' ' . $bulan[(int) $pecahkan[1]] . ' ' . $pecahkan[0];
                }

                // Jika format tanggal tidak valid
                return 'Tanggal Tidak Valid';
            }
        ?>

    <?php $__env->stopSection(); ?>

<?php echo $__env->make('dashboard.app', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH D:\2025-ITBBANTEN\resources\views/admin/detil.blade.php ENDPATH**/ ?>