<div class="flex flex-row justify-start items-center gap-x-4">
    <div class="border-[1px] rounded-full border-[custom-gradient-text] w-[25px] md:w-[50px] my-[15px] md:my-[25px]">
    </div>
    <h1 class="font-dmsans text-xl font" style="color: <?php echo e($subtextColor); ?>;"><?php echo e($subtext); ?></h1>
</div>
<h1 class="font-Anek text-[18px] md:text-[32px] font-semibold mb-4 uppercase text-center font-poppins md:text-start w-[700px]"
    style="color: <?php echo e($titleColor); ?>;">
    <?php echo e($title); ?>

</h1>
<?php /**PATH /home/u4591423/public_html/PUBLIC_DOMAIN/2025_UIMA/resources/views/components/header-section.blade.php ENDPATH**/ ?>