<footer
    class="footer d-flex flex-column flex-md-row align-items-center justify-content-between px-4 py-3 border-top small">
    <p class="text-muted mb-1 mb-md-0">Copyright © 2024 <a href="#" target="_blank">Kuliah Karyawan (K2)</a>.</p>
    <p class="text-muted">Created By <i class="mb-1 text-primary ms-1 icon-sm">Abdillah & Ilham</i></p>
</footer>
<?php /**PATH D:\2025-ITBSWADARMA\resources\views/dashboard/footer.blade.php ENDPATH**/ ?>