<?php $__env->startSection('content'); ?>
    <?php if (isset($component)) { $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\HeaderSectionPage::class, ['title' => ''.e($berita->judul).'','breadcrumbHome' => 'Home','breadcrumbCurrent' => 'berita']); ?>
<?php $component->withName('header-section-page'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df)): ?>
<?php $component = $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df; ?>
<?php unset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df); ?>
<?php endif; ?>
    <div class="bg-gray-50 rounded-lg p-6 shadow-md mt-8 md:mx-[50px] " data-aos="fade-up" >
        <img src="<?php echo e(asset('./storage/berita/' . $berita->file_foto)); ?>"
            class="rounded-lg w-full h-auto object-cover object-center" alt="<?php echo e($berita->judul); ?>" style="width:500px; margin-left: auto; margin-right: auto; display: block;"">
        <p class="mt-8 font-dmsans text-[14px] md:text-[16px] lg:text-[18px] " style="text-indent: 30px;" data-aos="fade-up">
            <?php echo e(strip_tags($berita->content)); ?>

        </p>
        <div data-aos="fade-up" class="flex items-center flex-col pt-10">
            <div data-aos="fade-up" class="w-full h-[1px] bg-blue-900 my-4"></div>
            <h1 data-aos="fade-up" class="text-center font-poppins text-[20px] md:text-[30px] font-bold text-primary">
                DAFTAR SEKARANG
            </h1>
            <p data-aos="fade-up" class="text-center mb-5 text-[12px] md:text-[14px] lg:text-[16px]">
                Wujudkan impian masa depan dengan pendidikan berkualitas di STMIK PGRI Arungbinang yang sudah teruji. STMIK PGRI Arungbinang hadir
                dengan program studi terbaik, dosen profesional, dan fasilitas modern yang mendukung kemajuan akademik Anda.
            </p>
            <?php if (isset($component)) { $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940 = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\Button::class, ['url' => '/pendaftaran']); ?>
<?php $component->withName('button'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>DAFTAR SEKARANG <?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940)): ?>
<?php $component = $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940; ?>
<?php unset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940); ?>
<?php endif; ?>
        </div>
    </div>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('Frontend.Layouts.app2', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH /home/u4591423/public_html/PUBLIC_DOMAIN/2025_STMIK-PGRI_ARUNGBINANG/resources/views/Frontend/detail-berita.blade.php ENDPATH**/ ?>