<?php $__env->startSection('content'); ?>
    <?php if (isset($component)) { $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\HeaderSectionPage::class, ['title' => 'Visi Misi Universitas Indonesia Maju','breadcrumbHome' => 'Home','breadcrumbCurrent' => 'Visi Misi']); ?>
<?php $component->withName('header-section-page'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df)): ?>
<?php $component = $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df; ?>
<?php unset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df); ?>
<?php endif; ?>

    <!-- Content Section -->
    <div class=" py-10 ">
        <div data-aos="fade-up" class="container mx-auto px-4 lg:px-16 space-y-12">
            <!-- Visi -->
            <div data-aos="fade-up" class="bg-white shadow-xl shadow rounded-lg p-6">
                <h2 data-aos="fade-up" class="text-xl font-poppins font-semibold text-primary mb-3">Visi</h2>
                <p data-aos="fade-up" class="text-gray-700 font-dmsans">
                Pada tahun 2041, UIMA menjadi universitas yang berdaya saing nasional dalam pengembangan ilmu pengetahuan dan teknologi melalui pengembangan masyarakat.
                </p>
            </div>

            <!-- Misi -->
            <div data-aos="fade-up" class="bg-white shadow-xl shadow rounded-lg p-6">
                <h2 data-aos="fade-up" class="text-xl font-poppins font-semibold text-primary mb-3">Misi</h2>
                <ul data-aos="fade-up" class="list-disc pl-5 space-y-3 text-gray-700 font-dmsans">
                <li>
                    Menyelenggarakan dan mengembangkan pendidikan akademik, vokasi dan profesi yang berdaya saing melalui pengembangan Masyarakat
                </li>
                <li>
                    Menyelenggarakan pengabdian kepada masyarakat yang bermutu untuk menunjang kemandirian bangsa melalui pengabdian Masyarakat
                </li>
                 <li>
                    Usaha-usaha inovatif yang berkaitan dengan core bussines UIMA yang dapat meningkatkan revenue
                </li>
                <li>
                Menyelenggarakan dan mengembangkan penelitian dasar dan terapan dalam pengembangan masyarakat yang berkontribusi pada ilmu pengetahuan dan teknologi
                </li>
                <li>
                Menyelenggarakan kemitraan yang produktif dan berkelanjutan dengan kelembagaan pendidikan, pemerintahan dan dunia usaha ditingkat daerah, nasional dan internasional
                </li>
                </ul>
            </div>

            <!-- Call to Action -->
            <div data-aos="fade-up" class="text-center shadow-xl">
                <div data-aos="fade-up" class="bg-accent py-8 rounded-lg">
                    <h2 data-aos="fade-up" class="text-xl font-poppins font-bold text-white mb-3">Jadilah bagian dari Universitas Indonesia Maju dan capai potensi terbaikmu!
                    </h2>
                    <p data-aos="fade-up" class="text-white font-dmsans mb-5">Ciptakan perjalanan akademik yang sukses dan masa depan gemilang di Universitas Indonesia Maju.</p>
                    <a href="/pendaftaran" data-aos="fade-up"
                        class="bg-white text-primary font-poppins font-medium py-2 px-6 rounded-full shadow-md hover:bg-gray-100 transition">
                        Daftar Sekarang
                    </a>
                </div>
            </div>
        </div>
    </div>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('Frontend.Layouts.app2', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH D:\2025_UIMA\resources\views/Frontend/visimisi.blade.php ENDPATH**/ ?>