<div class="md:h-[827px] h-auto flex flex-col items-center md:flex-row justify-center md:gap-x-[100px] py-[100px] md:py-[100px] px-4 md:px-0 bg-cover bg-no-repeat bg-right md:bg-center"
    style="background-image: url('<?php echo e(asset('./images/background/bg-sambutan.png')); ?>');">
    <div class="flex justify-center md:justify-start w-full md:w-auto flex-col items-center">
    <img src="<?php echo e(asset('./images/sambutan/ketua-FATAHILLAH.png')); ?>" data-aos="fade-up"
        class="h-auto md:w-[1000px] w-[300px] md:h-[500px] max-w-[450px]" style="border-radius:25px;" alt="KETUA STAI FATAHILLAH">
    <p style="padding-top: 20px; font-size: 14px; color: #fff; text-align: center; font-family: 'Poppins', sans-serif;">
        <!-- <b>Dendi Afrizal, S.AB., M.Ak, </b> -->
    </p>
</div>
    <div class="flex flex-col md:items-start justify-center items-center w-full md:w-[40%] w-[100%] mt-4 md:mt-0"
        data-aos="fade-up">
        <?php if (isset($component)) { $__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\HeaderSection::class, ['subtext' => ' SAMBUTAN KETUA STAI FATAHILLAH','subtextColor' => '#fff','title' => '','titleColor' => '#fff']); ?>
<?php $component->withName('header-section'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe)): ?>
<?php $component = $__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe; ?>
<?php unset($__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe); ?>
<?php endif; ?>
        <p class="text-justify font-dmsans mb-4 font-inter text-sm md:text-base  normal-case w-[80%]" style="color:#fff" >
        Assalamualaikum Warahmatullahi Wabarakatuh, Salam sejahtera bagi kita semua, semoga rahmat dan berkah Allah SWT senantiasa mengiringi setiap langkah perjalanan kita. Saya dengan rendah hati, sebagai Rektor STAI Fatahillah Serpong, mengucapkan selamat datang di website resmi kampus kita. STAI Fatahillah Serpong adalah lembaga pendidikan tinggi yang berdedikasi untuk menciptakan lingkungan pembelajaran yang bermutu, inovatif, dan mendalam, sekaligus mendorong pertumbuhan spiritual dan moral. Kami memandang pendidikan sebagai tonggak penting dalam membangun masa depan yang lebih baik, dan kami berkomitmen untuk memberikan pendidikan yang berkualitas, relevan, dan berlandaskan pada nilai-nilai Islam. Melalui website ini, kami ingin memberikan akses yang lebih mudah bagi semua pihak untuk mendapatkan informasi mengenai program akademik yang kami tawarkan, kegiatan kampus, pengembangan kurikulum, serta pencapaian dan berita terkini dari STAI Fatahillah Serpong. Kami juga berharap website ini menjadi wadah bagi mahasiswa, dosen, staf, calon mahasiswa, dan masyarakat umum dalam berinteraksi, berbagi ide, dan membangun sinergi yang positif Kampus ini bukan sekadar tempat untuk mencari gelar akademik, tetapi juga tempat untuk meraih pengalaman berharga, mengembangkan kepekaan sosial, dan memperkuat keterampilan kepemimpinan. Kami memberikan perhatian khusus pada pengembangan karakter, etika, dan tanggung jawab sosial, agar setiap lulusan STAI Fatahillah Serpong menjadi insan yang berkualitas dan mampu memberikan kontribusi nyata bagi masyarakat dan bangsa.Sekali lagi, selamat datang di website resmi STAI Fatahillah Serpong. Mari kita bergandengan tangan membangun masa depan yang lebih gemilang, bermanfaat, dan bermakna. Wassalamualaikum Warahmatullahi Wabarakatuh.
</p>
        
        <?php if (isset($component)) { $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940 = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\Button::class, ['url' => '/sejarah-singkat']); ?>
<?php $component->withName('button'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>BACA SELENGKAPNYA <?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940)): ?>
<?php $component = $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940; ?>
<?php unset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940); ?>
<?php endif; ?>
    </div>
</div>
<?php /**PATH D:\2025-STAI-Fatahillah\resources\views/Frontend/landingpage/sambutan-section.blade.php ENDPATH**/ ?>