

<?php $__env->startSection('title', 'Data Pendaftaran'); ?>

<?php $__env->startSection('content'); ?>
    <div class="page-content">
        <nav class="page-breadcrumb">
            <ol class="breadcrumb">
                <li class="breadcrumb-item"><a href="<?php echo e(route('dashboard')); ?>">Dashboard</a></li>
                <li class="breadcrumb-item active" aria-current="page">Data Pendaftaran</li>
            </ol>
        </nav>

        <?php if(session('success')): ?>
            <div class="alert alert-success alert-dismissible fade show" role="alert">
                <?php echo e(session('success')); ?>

                <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
            </div>
        <?php endif; ?>

        <?php if(session('error')): ?>
            <div class="alert alert-danger alert-dismissible fade show" role="alert">
                <?php echo e(session('error')); ?>

                <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
            </div>
        <?php endif; ?>

        <div class="row">
            <div class="col-md-12 grid-margin stretch-card">
                <div class="card">
                    <div class="card-body">
                        <form method="GET" action="<?php echo e(route('daftar')); ?>" class="mb-3">
                            <div class="d-flex flex-wrap align-items-center gap-2 mb-3">
                                <input type="date" name="start_date" class="form-control w-auto" placeholder="Tanggal Awal">
                                <span>s.d</span>
                                <input type="date" name="end_date" class="form-control w-auto" placeholder="Tanggal Akhir">
                                <button type="submit" class="btn btn-primary btn-sm mt-2 mt-md-0">
                                    <i class="fa fa-filter"></i> Filter
                                </button>
                            </div>
                            <div class="d-flex flex-wrap align-items-center gap-2">
                                <input type="text" name="search" class="form-control w-auto" placeholder="Cari Data">
                                <button type="submit" class="btn btn-primary btn-sm mt-2 mt-md-0">
                                    <i class="fa fa-search"></i> Cari
                                </button>
                            </div>
                        </form>

                        <div class="table-responsive">
                            <table class="table table-hover" id="dataTables-example">
                                <thead>
                                    <tr>
                                        <th>Tanggal</th>
                                        <th>Nama</th>
                                        <th>No</th>
                                        <th>Email</th>
                                        <th>JK</th>
                                        <th>Kota</th>
                                        <th>Kelas</th>
                                        <th>Aksi</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php $__currentLoopData = $daftars; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $daftar): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                                        <tr>
                                            <td><?php echo e(\Carbon\Carbon::parse($daftar->created_at)->format('Y-m-d')); ?></td>
                                            <td><?php echo e($daftar->nama_leng); ?></td>
                                            <td><?php echo e($daftar->no_hp); ?></td>
                                            <td><?php echo e($daftar->email); ?></td>
                                            <td><?php echo e($daftar->j_kel); ?></td>
                                            <td><?php echo e($daftar->kampus); ?></td>
                                            <td><?php echo e($daftar->kelas); ?></td>
                                            <td>
                                                <a href="<?php echo e(route('daftar.detil', $daftar->daftar_id)); ?>" class="btn btn-primary btn-sm">
                                                    <i class="fa fa-info"></i>
                                                </a>
                                                <a href="<?php echo e(route('daftar.hapus', $daftar->daftar_id)); ?>" onclick="return confirm('Apa Anda yakin melakukan ini?')" class="btn btn-danger btn-sm">
                                                    <i class="fa fa-close"></i>
                                                </a>
                                            </td>
                                        </tr>
                                    <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                                </tbody>
                            </table>
                        </div>

                        <div class="mt-3">
                            <button id="exportButton" class="btn btn-success btn-sm">Export to Excel</button>
                        </div>
                        <div class="d-flex justify-content-start mt-4">
                            <?php echo e($daftars->links('vendor.pagination.simple-bootstrap-5')); ?>

                        </div>

                    </div>
                </div>
            </div>
        </div>
    </div>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('dashboard.app', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH D:\2025-STAI-Fatahillah\resources\views/admin/daftar.blade.php ENDPATH**/ ?>