<?php $__env->startSection('title', 'Sejarah'); ?>


<?php $__env->startSection('content'); ?>
    <?php if (isset($component)) { $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\HeaderSectionPage::class, ['title' => 'Sejarah STIKES PEMBINA PALEMBANG','breadcrumbHome' => 'Home','breadcrumbCurrent' => 'Sejarah Singkat']); ?>
<?php $component->withName('header-section-page'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df)): ?>
<?php $component = $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df; ?>
<?php unset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df); ?>
<?php endif; ?>

    <div data-aos="fade-up" class=" flex flex-col my-6 md:my-10 px-4 md:px-20 lg:px-32 xl:px-60">
        <!-- Gambar -->
        

        <!-- Konten Teks -->
        <div data-aos="fade-up" class="flex flex-col space-y-4 text-justify font-dmsans text-[14px] md:text-[16px]">
            <p>
            Dalam rangka menghadapi tantangan Zaman yang semakin berat serta menghadapi masyarakat yang semakin kritis sehingga diperlukan usaha untuk meningkatkan mutu pelayanan kesehatan sesuai dengan kebutuhan dan perkembangan masyarakat maka perlu ditingkatkan jenjang pendidikan kesehatan yaitu program studi D-III Kebidanan dan S-I Kesehatan masyarakat. Sekolah Tinggi Ilmu Kesehatan (STIKES) Pembina Palembang diselenggarakan Berdasarkan Surat Rekomendasi dari Dinas Kesehatan Propinsi Sumatera Selatan No. SK Mendiknas/No.98/D/O/2005 tanggal 18 Juli 2005, yang berisikan pembentukan Program Studi (S-I) Kesehatan Masyarakat dan (D-III) Kebidanan tersebut dimulai tahun Akademik 2005/2006. Sekolah Tinggi Ilmu Kesehatan (STIKES) Pembina Palembang telah terakreditasi oleh Lembaga Akreditasi Mandiri Perguruan Tinggi Kesehatan (LAMPT Kes). Dengan Surat Keputusan Nomor : 0930/ LAM-PTKes/Akr/Dip/X/2016 
             </p>
            

            
        </div>

        <!-- Bagian Ajakan -->
        <div data-aos="fade-up" class="flex items-center flex-col pt-10">
            <div data-aos="fade-up" class="w-full h-[1px] bg-blue-900 my-4"></div>
            <h1 data-aos="fade-up" class="text-center font-poppins text-[20px] md:text-[30px] font-bold text-primary">
                SEGERA DAFTAR
                </h1>
            <p data-aos="fade-up" class="text-center mb-5 text-[12px] md:text-[14px] lg:text-[16px]">
            Bergabunglah bersama STIKES PEMBINA PALEMBANG dan jadilah inspirasi dengan Ilmu, Membimbing dengan Iman!
        </p>
            <?php if (isset($component)) { $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940 = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\Button::class, ['url' => '/pendaftaran']); ?>
<?php $component->withName('button'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>DAFTAR SEKARANG <?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940)): ?>
<?php $component = $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940; ?>
<?php unset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940); ?>
<?php endif; ?>
        </div>
    </div>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('Frontend.Layouts.app2', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH D:\2025-STIKES-PEMBINA\resources\views/Frontend/sejarah.blade.php ENDPATH**/ ?>