@keyframes slideTextUp {
    0% {
        transform: translateY(0%);
        opacity: 1;
    }
    50% {
        opacity: 0;
        transform: translateY(100%);
    }
    51% {
        transform: translateY(-100%);
        opacity: 0;
    }
    100% {
        transform: translateY(0%);
        opacity: 1;
    }
}

.slide-text {
    animation: slideTextUp 5s infinite;
}
