<?php $__env->startSection('title', 'Sejarah'); ?>


<?php $__env->startSection('content'); ?>
    <?php if (isset($component)) { $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\HeaderSectionPage::class, ['title' => 'Sejarah Institut Banten','breadcrumbHome' => 'Home','breadcrumbCurrent' => 'Sejarah Singkat']); ?>
<?php $component->withName('header-section-page'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df)): ?>
<?php $component = $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df; ?>
<?php unset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df); ?>
<?php endif; ?>

    <div data-aos="fade-up" class=" flex flex-col my-6 md:my-10 px-4 md:px-20 lg:px-32 xl:px-60">
        <!-- Gambar -->
        

        <!-- Konten Teks -->
        <div data-aos="fade-up" class="flex flex-col space-y-4 text-justify font-dmsans text-[14px] md:text-[16px]">
            <p>
            
Institut Teknologi dan Bisnis Banten (Institut Banten) mempunyai sejarah yang cukup panjang, Berawal dari Akademi Akuntansi Keuangan dan Perbankan Iindonesia (AAKPI) berdiri pada tanggal 8 Agustus 2000 berdasarkan Keputusan Direktur Jenderal Pendidikan Tinggi Depatemen Pendidikan Nasional Republik Indonesia nomor: 253/DIKTI/Kep/2000. Akademi Akuntansi Keuangan dan Perbankan Indonesia (AAKPI) saat ini berada di bawah pengelolaan Yayasan Lingkar Banten berdasarkan akta serah terima antara Yayasan  Pendidikan Pusaka Nusantara dan Yayasan Lingkar Banten pada tanggal 18 Desember 2008. Dengan pengalihan ini tanggung jawab institusi Akademi Akuntansi Keuangan dan Perbankan Indonesia (AAKPI) menjadi tanggung jawab Yayasan Lingkar Banten, yang otomatis terjadi perubahan alamat dan domisili institusi
             </p>
            
            <p>
            Pada tanggal 18 Februari 2010 terbitlah Surat Keputusan Menteri Pendidikan Nasional Republik Indonesia nomor: 13/D/O/2010 tentang Pendirian dan izin Opersional Akademi Akuntansi Keuangan dan Perbankan Indnesia di Serang, yang terdiri dari dua program studi, yaitu: Progam Akuntansi dan Program Studi Keuangan  dan Perbankan. Masing-masing Program Studi saat ini sudah Terakreditasi BAN-PT.
            </p>
            <p>
            Pada tanggal 8 Juni 2022 Surat Keputusan Menteri Pendidikan, Kebudayaan, Riset, dan Teknologi Republik Indonesia Nomor : 408/E/0/2022 Tentang Izin Perubahan Bentuk Akademi Akuntansi Keuangan dan Perbankan Indonesia di Kota Serang Menjadi institut Teknologi dan Bisnis Banten yang diselenggarakan Oleh Yayasan Linkar Banten. Saat ini institut Teknologi dan Bisnis Banten berkedudukan dan berdomisili di Jl. TB. Suwandi Lingkar Selatan No. 99 Simpang Lima Ciracas – Kota Serang Banten 42116

            </p>
            
        </div>

        <!-- Bagian Ajakan -->
        <div data-aos="fade-up" class="flex items-center flex-col pt-10">
            <div data-aos="fade-up" class="w-full h-[1px] bg-blue-900 my-4"></div>
            <h1 data-aos="fade-up" class="text-center font-poppins text-[20px] md:text-[30px] font-bold text-primary">
                SEGERA DAFTAR
                </h1>
            <p data-aos="fade-up" class="text-center mb-5 text-[12px] md:text-[14px] lg:text-[16px]">
            Bersama Institut Teknologi dan Bisnis Banten, jadilah ahli teknologi dan manajemen yang siap bersaing di era digital!
        </p>
            <?php if (isset($component)) { $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940 = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\Button::class, ['url' => '/pendaftaran']); ?>
<?php $component->withName('button'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>DAFTAR SEKARANG <?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940)): ?>
<?php $component = $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940; ?>
<?php unset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940); ?>
<?php endif; ?>
        </div>
    </div>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('Frontend.Layouts.app2', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH D:\2025-ITBBANTEN\resources\views/Frontend/sejarah.blade.php ENDPATH**/ ?>