@section('title', 'Sejarah')

@extends('Frontend.Layouts.app2')
@section('content')
    <x-header-section-page title="Sejarah STISIP IMAM BONJOL" breadcrumb-home="Home" breadcrumb-current="Sejarah Singkat" />

    <div data-aos="fade-up" class=" flex flex-col my-6 md:my-10 px-4 md:px-20 lg:px-32 xl:px-60">
        <!-- Gambar -->
        {{-- <img src="{{ asset('./images/sambutan/petinggi.png') }}" data-aos="fade-up" class=" mb-5 w-full" alt=""> --}}

        <!-- Konten Teks -->
        <div data-aos="fade-up" class="flex flex-col space-y-4 text-justify font-dmsans text-[14px] md:text-[16px]">
            <p>
            Sekolah Tinggi Ilmu Sosial dan Ilmu Politik Imam Bonjol Padang berada dibawah naungan Yayasan Imam Bonjol Padang.<br>

Pada mulanya Yayasan ini menaungi  :<br>

Fakultas Tarbiyah, 2. Fakultas Syari’ah, 3. Fakultas Adab, Fakultas Usuludin, 5. Fakultas Teknik dengan 2 Jurusan yaitu Sipil dan Arsitektur, 6.Fakultas Sosial dan Politik. Keenam fakultas tergabung dalam Satu Universitas, bernama universitas Imam Bonjol. Pimpinan Universitas Imam Bonjol langsung dipegang oleh Drs. H. Azhari. Pada akhirnya 4 Fakultas Agama Islam tersebut diatas dinegerikan menjadi IAIN Imam Bonjol sedangkan Fakultas Teknik menggabungkan diri dengan Universitas Bung Hatta, sehingga yang tetap dalam Universitas Imam Bonjol hanya Fakultas Sosial Politik saja. Adapun Fakultas Sosial Politik yang didirikan pada tanggal 5 Juli 1962 dengan status terdaftar di Direktorat Perguruan Tinggi Swasta Departemen Pendidikan dan Kebudayaan mengalami berkali-kali perubahan terdaftar antara lain : <br>
Terdaftar No. 129/B-SWT/P/1962<br>
Terdaftar No. 39/DPT/B/1976<br>
Terdaftar No. 392/ DPT/B/1976<br>
Sampai dengan tingkat Sarjana Lengkap, setelah melasanakan bekali-kali Ujian Sarjana Muda dan Sarjana Lengkap , pada tahun 1973. kegiatan status terdaftar diatas dicabut dengan SK Menteri P dan K RI No.0168/ 0/1973. Oleh karena Universitas dibubarkan dan diganti dengan Sekolah Tinggi.<br>

Kemudian dengan Kopertis wilayah I Medan pada tahun 1975 diadakan perubahan nama menjadi Sekolah Tinggi Ilmu Sosial dan Ilmu Politik Imam Bonjol Padang. Status terdaftar No. 29 tahun 1975 diganti dengan status tedaftar No. 08 tahun 1980 kemudian diganti lagi dengan status terdaftar  No. 018/0/1981. Selanjutnya dirobah lagi dengan Surat Keputusan  Mendikbud No.0607/0/1984 tanggal 29 Nopember 1984 untuk Jurusan Ilmu Administrasi.


            

            
        </div>

        <!-- Bagian Ajakan -->
        <div data-aos="fade-up" class="flex items-center flex-col pt-10">
            <div data-aos="fade-up" class="w-full h-[1px] bg-blue-900 my-4"></div>
            <h1 data-aos="fade-up" class="text-center font-poppins text-[20px] md:text-[30px] font-bold text-primary">
                SEGERA DAFTAR
                </h1>
            <p data-aos="fade-up" class="text-center mb-5 text-[12px] md:text-[14px] lg:text-[16px]">
            Bergabunglah bersama STISIP IMAM BONJOL dan Bangun Wawasan, Bentuk Karakter, Jadilah Pembawa Perubahan!
        </p>
            <x-button url="/pendaftaran">DAFTAR SEKARANG</x-button>
        </div>
    </div>
@endsection
