<div class="flex flex-col bg-contain bg-no-repeat bg bg-center justify-center px-4 md:px-[200px] my-[80px]"
    style="background-image: url('<?php echo e(asset('./images/background/bg-grey1.png')); ?>');">
    <div class="  flex flex-col md:items-start justify-center items-center w-full md:w-[40%] w-[100%] mt-4 md:mt-0"
        data-aos="fade-up">

        <?php if (isset($component)) { $__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\HeaderSection::class, ['subtext' => 'BERITA STMIK PGRI ARUNGBINANG','subtextColor' => '#1f181a','title' => ' ','titleColor' => '#1f181a']); ?>
<?php $component->withName('header-section'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe)): ?>
<?php $component = $__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe; ?>
<?php unset($__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe); ?>
<?php endif; ?>
        <div class="swiper mySwiper my-[50px] md:w-[1300px] w-full">
            <div class="swiper-wrapper md:space-x-[10px] px-8 pb-8">
                <?php $__currentLoopData = $berita; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $index => $project): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                    <div class="swiper-slide">
                        <div class="relative bg-[#F9F9F9]/30 shadow-xl rounded-lg  w-[400px] sm:w-[300px] md:w-[350px]">
                            <img src="<?php echo e(asset('./storage/berita/' . $project->file_foto)); ?>"
                                class=" rounded-t-lg h-[175px] w-full object-cover object-center" alt="">
                            <h1
                                class="absolute right-1 top-1 bg-accent p-1 w-[100px] rounded-full font-dmsans font-semibold text-[11px]" style="color:#fff;">
                                <?php echo e($project->tanggal_berita); ?>

                            </h1>
                            <div class="px-[20px] flex flex-col gap-y-3 pt-[10px] pb-[20px]">
                                <div class="flex flex-row justify-between gap-x-2 items-center">
                                    <h1 class="font-poppins text-primary font-bold text-[20px] uppercase">
                                        <?php echo e($project->judul); ?>

                                    </h1>
                                </div>
                                <p class="font-dmsans text-black font-light text-start">
                                    <?php echo e(Str::limit(strip_tags($project->content), 150)); ?>...</p>
                                <div class="my-3 flex justify-start">
                                    <a href="<?php echo e(route('fe-detailberita', $project->id_berita)); ?>"
                                        class="text-accent hover:text-white w-[140px] text-[9px] md:text-[11px] duration-200 md:w-[150px] border border-[2px] border-accent hover:border hover:border-[#F9F9F9]/15 hover:rounded-full hover:border-[2px] font-Anek hover:bg-accent hover:border-accent font-bold rounded-full  px-4 md:px-2 md:py-[7px] py-2.5 text-center me-2 mb-4 md:mb-2">
                                        BACA SELENGKAPNYA
                                    </a>
                                </div>
                            </div>
                        </div>
                    </div>
                <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
            </div>
            <div class="swiper-pagination"></div>
        </div>
    </div>
</div>
<?php /**PATH /home/u4591423/public_html/PUBLIC_DOMAIN/2025_STMIK-PGRI_ARUNGBINANG/resources/views/Frontend/landingpage/berita-section.blade.php ENDPATH**/ ?>